
#delimit ;
*** ;
set more off ;

*****Ilyana's version of restricted-access results [CODE IS SPECIFIC TO MY DESKTOP] ;

****Preliminaries;

clear all ;

cd ;
cd "Dropbox/southern_strategy/gallup&GSS" ;

global main "~/Dropbox/southern_strategy" ;
global figures "~/Dropbox/southern_strategy/paper_for_publication/Figures" ;
global tables "~/Dropbox/southern_strategy/paper_for_publication/Tables" ;

******************************************************************************* ;

****************READ GSS, MERGE GEO-CODES, WEIGHT GALLUP, APPEND GALLUP ******* ;

******************************************************************************* ;


***First, reshape the GSS and keep relevent variables [NOT RESTRICTED ACCESS] ;

run Shaping_GSS.do ;

do Do_files_for_geocoded_data/Adding_location_to_GSS.do ;


***Ditto for the next do file -- we again save the output as a tempfile ;
***This final do file makes the data ready for the Gallup-and-GSS regressions in the main table ;

do Do_files_for_geocoded_data/Appending_Gallup_GSSgeo.do ;

****This actually uses the restricted-access data (it merges it with the public-use data) ;

use gallup_and_GSSgeo, clear ;


****ONLY KEEP Whites ;

keep if race==1 ;

***Weight the Gallup data to match Census [this is very inelegantly coded] ;
***Temporarily drop GSS & then append them back in ;

preserve ;

keep if svy_type==1 ;
keep if svy_blkPres == 1 ;
run make_gallup_cen_wgts ;

tempfile gallup_wgts ;
save `gallup_wgts' ;

restore ;

***Now, drop gallup, keep GSS, and append back in weighted Gallup temp-file ;

keep if svy_type==2 ;
append using `gallup_wgts' ;

***Drop GSS vars that do no have black president Q ;
drop if blkPresident==. & svy_type==2 ;

**************************************************************************** ;

****************GSS AND (WEIGHTED!) GALLUP ARE NOW APPENDED TOGETHER ******* ;

**************************************************************************** ;

***Create & label the key interaction terms ;

gen aft = svy_year >= 1963 if!missing(svy_year) ;
gen conf_aft = (confed == 1 & aft == 1) if !missing(confed) & !missing(aft) ;
gen noprez = blkPresident != 1 if !missing(blkPresident) ;
foreach var of varlist noprez { ;
	gen conf_`var' = confed*`var' if !missing(confed) & !missing(`var') ;
	gen `var'_aft = aft*`var' if !missing(aft) & !missing(`var') ;
	gen conf_`var'_aft = confed*`var'*aft if !missing(confed) & !missing(`var') & !missing(aft) ;
} ;

lab var confed "South" ;
lab var conf_aft "South x Aft" ;
lab var noprez "No Bl prez" ;
lab var conf_noprez "South x No Bl prez" ;
lab var noprez_aft "No Bl prez x Aft" ;
lab var conf_noprez_aft "South x No Bl prez x Aft" ;

****Little program to capture dept. var. mean for reg tables ;
capture program drop meanvar ;
program meanvar ;
	sum `e(depvar)' if e(sample)==1 [aw `e(wexp)'] ;
	estadd scalar dvar=`r(mean)' ;
end ;


****Create additional interactions for robustness checks ;
rename city_dummy citysize ;
foreach var of varlist /* noprez noprezhat */ age citysize highschool{ ;
	gen conf_`var' = confed*`var' if !missing(confed) & !missing(`var') ;
	gen `var'_aft = aft*`var' if !missing(aft) & !missing(`var') ;
	gen conf_`var'_aft = confed*`var'*aft if !missing(confed) & !missing(`var') & !missing(aft) ;
} ;

eststo clear ; 

cap log close ;

log using prez_analysis.log, replace ;

****Cleanup GSS presidential intention questions ;
****Note that, conveniently, every year they code the Dem as 1 ;
****Note that, in some surveys, people are asked about *two* past elections ;
****To keep things simple (so that everyone in the GSS gets assignd to one election, I only keep people who were asked about their vote within 4 years of the election;
****We will also a two-party vote (_2p) which codes as missing any vote for someone outside Dem and Rep ;

gen gss_vote_dem=pres68==1 if pres68<. & svy_type==2 ;
gen gss_vote_dem_2p=pres68==1 if pres68<3 & svy_type==2 ;
forval y=72(4)84 { ;
replace gss_vote_dem=1 if pres`y'==1 & year<19`y'+5  & svy_type==2 ;
replace gss_vote_dem=0 if pres`y'>1 & pres`y'<5 & year<19`y'+5  & svy_type==2 ;
replace gss_vote_dem_2p=1 if pres`y'==1 & year<19`y'+5  & svy_type==2 ;
replace gss_vote_dem_2p=0 if pres`y'>1 & pres`y'<3 & year<19`y'+5  & svy_type==2 ;
} ;

label var gss_vote_dem "Reported Dem vote in the past election within 4 years of survey (non-voters = missing)" ;

****Crate a two-party version of the GALLUP prez election variable ;
****The Dem-v-all version was already created earlier ;

gen voted_dem_2p=1 if voteSteve==1 ;
replace voted_dem_2p=0 if voteSteve==2 ;
replace voted_dem_2p=1 if voteNixonK==1 ;
replace voted_dem_2p=0 if voteNixonK==2 ;
replace voted_dem_2p=1 if voteGoldwaterJ==1 ;
replace voted_dem_2p=0 if voteGoldwaterJ==2 ;
***Note that the Dem=2 for the variable below ;
replace voted_dem_2p=1 if voteNixonHu==2 ;
replace voted_dem_2p=0 if voteNixonHu==1 ;

tab year, sum(gss_vote_dem) ;

gen voted_dem=gss_vote_dem ;
replace voted_dem=voteddemo if previouselection<4 ;
replace voted_dem_2p=gss_vote_dem_2p if svy_type==2 ;

**Rename GSS "year" svy_year to match Gallup ;

replace svy_year=year if svy_type==2 ;

tab svy_year, sum(voted_dem) ;

***For the presential-election analysis, generate "election year immediately before interview" ;

gen elex_yr=4*floor(svy_year/4) ;

***This is slightly wrong when the year and the elex_yr are equal (will depend on the month of interview) ;
***In our regression sample, this only happens in 1972 and 1984 ;

tab svy_year if svy_year==elex_yr & noprez<. & voted_dem<. ;

****This survey took place in march, so it woudl have actually been referring to the 1968 election ;

tab svy_mo if svy_year==1972 & noprez<. & voted_dem<. ;

***So, recode it to 1968 ;

replace elex_yr=1968 if svy_year==1972 & noprez<. & voted_dem<. ;

****Ditto for 1984 ;

tab svy_m if svy_year==1984 & noprez<. ;

****Recode to 1980 ;

replace elex_yr=1980 if svy_year==1984 & noprez<. ;

****Generate interactiosn with elex_yr in place of svy_year ;

gen conf_aft_elex=confed*(elex_yr>1962) if elex_yr<. ;
gen noprez_aft_elex=noprez*(elex_yr>1962) if elex_yr<. ;
gen conf_noprez_aft_elex=confed*noprez_aft_elex ;

***Generate a common weight variable [census weights for gallup, survey weights for GSS] ;

gen wgt_comb=cen2_wgt if svy_type==1 ;
replace wgt_comb=wtssall*oversamp if svy_type==2 ;
*replace wgt_comb=wtssall if svy_type==2 ;

***Each year mean shoudl roughly be one ;
tab svy_year, sum(wgt_comb) ;

*** Change to svy_date fixed effects ;
summ svy_date ;
gen i_svy_date = svy_date - `r(min)' ;

egen tag_svy_date=tag(svy_date) ;
egen tag_elex_yr=tag(elex_yr) ;


******Presidential analysis table & graphs ;

eststo clear ;

****Two versions (based on election year & based on interview year) ;

foreach cat in  date  elex   { ;

if "`cat'"=="date" { ;
	local year_tab "i_svy_date"  ;
} ;


if "`cat'"=="elex" { ;
	local tab "_elex" ;
	local year_tab "elex_yr" ;
} ;

eststo clear ;


eststo: areg voted_dem conf_aft`tab' i.i_svy_date if race==1 & svy_year<1984 [pw=wgt_comb], cl(state) abs(state) ;

predict predict1`tab' if e(sample)==1 ;

eststo: areg voted_dem_2p conf_aft`tab' i.i_svy_date if race==1 & svy_year<1984 [pw=wgt_comb], cl(state) abs(state) ;

eststo: areg voted_dem conf_aft`tab' noprez noprez_aft`tab' conf_noprez conf_noprez_aft`tab'  i.`year_tab' if race==1 & svy_year<1984 [pw=wgt_comb], cl(state) abs(state) ;

predict predict2`tab' if e(sample)==1 ;

eststo: areg voted_dem_2p conf_aft`tab' noprez noprez_aft`tab' conf_noprez conf_noprez_aft`tab'  i.`year_tab' if race==1 & svy_year<1984 [pw=wgt_comb], cl(state) abs(state) ;

} ;

eststo clear ;

****Re-do in a user-frinedly table ;

foreach var of varlist voted_dem_2p voted_dem  { ;

foreach spec in date elex { ;

if "`spec'"=="date" { ;
	local year_tab "i_svy_date"  ;
	local tab "" ;
} ;


else if "`spec'"=="elex" { ;
	local tab "_elex" ;
	local year_tab "elex_yr" ;
} ;

eststo: areg `var' conf_aft`tab' i.i_svy_date if race==1 & svy_year<1984 [pw=wgt_comb], cl(state) abs(state) ;
meanvar ;

eststo: areg `var' conf_aft`tab' noprez noprez_aft`tab' conf_noprez conf_noprez_aft`tab'  i.i_svy_date if race==1 & svy_year<1984 [pw=wgt_comb], cl(state) abs(state) ;
meanvar ;

} ;
} ;

*****Now, we are going to add Congressional preferences to this same appendix table ;

gen cong_dem=partyCD==2 | partyCD==5 if partyCD<. ;

eststo: areg cong_dem conf_aft i.i_svy_date if race==1 & svy_year<1984 [pw=wgt_comb], cl(state) abs(state) ;
meanvar ;

eststo: areg cong_dem conf_aft noprez noprez_aft conf_noprez conf_noprez_aft  i.i_svy_date if race==1 & svy_year<1984 [pw=wgt_comb], cl(state) abs(state) ;
meanvar ;

***Temporarily re-label variables ;

preserve ;

label var conf_aft "South x Surveyed after" ;
label var noprez_aft "No prez x Surveyed after" ;
label var conf_noprez_aft "South x No prez x Surveyed after" ;

label var conf_aft_elex "South x Election after" ;
label var noprez_aft_elex "No prez x Election after" ;
label var conf_noprez_aft_elex "South x No prez x Election after" ;

esttab using "$tables/prez_table.tex", replace booktabs fragment keep(conf_aft* *noprez*) label varwidth(20) wrap se brackets nostar
mgroups("Voted Dem, Prez. (D. \& R. voters)" "Voted Dem, Prez. (all voters)" "Prefers Dem, Cong.", pattern( 1 0 0 0    1 0 0 0   1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
stats(dvar N, label("Mean, dept. var." "Observations"))  nomtitles   ;

***Go back to standard labeling ;

restore ;

****Event-time graph ;

foreach var of varlist voted_dem_2p cong_dem { ;

foreach spec in date elex  { ;

if "`spec'"=="date" { ;
	local year_tab "i_svy_date"  ;
	local tab "" ;
} ;


else if "`spec'"=="elex" { ;
	local tab "_elex" ;
	local year_tab "elex_yr" ;
} ;

tab `year_tab' if `var'<. & noprez<. & state<. & svy_year<1984, matrow(yrs_in_samp) ;
local max=`r(r)' ;
forval x=1/`max' { ;
local y=yrs_in_samp[`x', 1] ;
gen noprez_date_`y'=noprez*(`year_tab'==`y') ;
} ;

forval c=0/1 { ;
gen conf`c'_coeff=. ;
areg `var' noprez noprez_date_* i.`year_tab' if race==1 & svy_year<1984 & confed==`c' [pw=wgt_comb], cl(state) abs(state) ;
forval x=1/`max' { ;
local y=yrs_in_samp[`x', 1] ;
replace conf`c'_coeff=_b[noprez_date_`y'] if `year_tab'==`y' ;
} ;
} ;

sort `year_tab' ;

format svy_date %tdMonCCYY ;

if "`var'"== "voted_dem_2p" local end_date=1984 ;
else if "`var'"== "cong_dem" local end_date=1964 ;

if "`spec'"=="date" twoway (connect conf1_coeff svy_date ) (connect conf0_coeff svy_date) if tag_svy_date==1 & svy_date<8700 & svy_year<`end_date', xti("") xline(1216)
legend(ring(0) pos(2) label(1 "Southern states") label(2 "Non-Southern states") rows(2));

if "`spec'"=="elex" twoway (connect conf1_coeff elex_yr ) (connect conf0_coeff elex_yr) if tag_elex_yr==1 & elex_yr<`end_date', xti("") xline(1963.3)  
legend(ring(0) pos(2) label(1 "Southern states") label(2 "Non-Southern states") rows(2));

graph export "$figures/`var'_event_time_`spec'.pdf", replace ;

drop conf*coeff ;
drop noprez_date* ;

} ;
} ;

*exit ;


****************************************************** ;

*******State-level prediction and counterfactual data ;

****************************************************** ;

areg voted_dem_2p conf_aft_elex noprez noprez_aft_elex conf_noprez conf_noprez_aft_elex  i.elex_yr if race==1 & svy_year<1985 & elex_yr~=1968 [pw=wgt_comb], cl(state) abs(state) ;

****Note below that we are allowing the prediction to go out of sample (because there are lots of observations for which we have the RHS vars but not the LHS, prez voting) ;

predict predict_2p ;
sum svy_year if predict_2p<. ;

***Below we substract off \beta*conf-noprez-aft-elex at the individual level ;

gen predict_2p_cf=predict_2p-_b[conf_noprez_aft_elex]*conf_noprez_aft_elex ;

****We can also pool all the post-perio & pre-period for each state to avg noprez (otherwise a ton of noise) ;

cap drop temp ;

egen temp=mean(noprez) if elex_yr>1962 & elex_yr<., by(state) ;
egen noprez_st_conf_post=mean(temp), by(state) ;
drop temp ;
egen temp=mean(noprez) if elex_yr<1962 & elex_yr<., by(state) ;
egen noprez_st_conf_pre=mean(temp) , by(state) ;
drop temp ;

foreach p in pre post { ;
gen predict_2p_cf_pool_`p' = predict_2p ;
****Now, subtract off the triple interaction term multiplied by the share saying noprez==1, but only for observations in the South in the post-period ;
replace predict_2p_cf_pool_`p'=predict_2p_cf_pool_`p'-_b[conf_noprez_aft_elex]*noprez_st_conf_`p' if conf_aft_elex==1  ;
} ;

****Finally, assume no one white in the South actually changed their views, and instead of the observed noprez you tell us, we are going to just use the pre-period avg. from your state ;
***Already created this var, noprez_st_conf_pre ;
***Predicted is: pred-dem = x*\gamma + \beta*Conf_Aft_NoPrez, where x is all other controls except triple interaction ;
***Predicted using pre-period no-prez is thus: pred-dem-pre=pred-dem + \beta*[no_prez_st_conf_pre - No Prez) for confed==1 & elex_year>1962 (for all other will be the same). ;
***Note in fact that \beta<0, but formula above is correct. ;

gen predict_2p_pre=predict_2p ;
replace predict_2p_pre = predict_2p_pre + _b[conf_noprez_aft_elex]*(noprez_st_conf_pre - noprez) if confed==1 & elex_yr>1962 ;

***Create vars at the state/election-year level ;

egen temp=mean(voted_dem_2p), by(state elex_yr) ;
egen act_st_yr=mean(temp), by(state elex_yr) ;
drop temp ;

foreach var of varlist noprez predict_2p predict_2p_cf predict_2p_cf_pool_post predict_2p_cf_pool_pre predict_2p_pre { ;

*egen temp=mean(`var'), by(state elex_yr) ;
egen `var'_st_yr=mean(`var'), by(state elex_yr) ;
*drop temp ;
} ;

***Get a sense of sample size ;

egen count_st_yr=sum(race==1 & noprez<. & voted_dem_2p<.), by(state elex_yr) ;

preserve ;

drop if elex_yr>1980 ;
egen tag_st_yr=tag(state elex_yr) ;
keep if tag_st_yr==1 ;
keep state elex_yr act_st_yr predict*st_yr count_st_yr noprez_st_yr ;

save prediction_st_elex_yr_cells, replace ;

sort state elex_yr ;

list, ab(18) head(7) ;

log close ;

/****Prediction cells for simulation ;


forval x=1/2 { ;
 
egen temp=mean(predict`x'`stub'), by(state svy_year) ;
egen predict_st_yr_`x'`stub'=mean(temp), by(state svy_year) ;
drop temp ;
} ;
} ;

egen tag_st_yr=tag(state svy_year) ;

preserve ;

keep if tag_st_yr==1 ;
keep state svy_year predict_st_yr* ;
save for_simulation, replace ;

****/ ;

restore ;

****** ;

************************************************************************************;

*******    MAIN TABLE IN PAPER ;

************************************************************************************;

eststo clear ;

****No State FE ; 
eststo: reg dem confed conf_aft i.i_svy_date  if race==1 & svy_year<=1980 & noprez~=. & svy_type==1 [pw= wgt_comb], cl(state) ;
	meanvar ;
	estadd local gss "No" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "No" ;

eststo: reg dem  confed conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.i_svy_date  if race==1 & svy_year<=1980 & svy_type==1 [pw= wgt_comb], cl(state) ;
	meanvar;
	estadd local gss "No" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "No" ;
		
***Adding state FE ;
eststo: reg dem conf_aft i.i_svy_date i.state if race==1 & svy_year<=1980 & noprez~=. & svy_type==1 [pw= wgt_comb], cl(state) ;
	meanvar;
	estadd local gss "No" ;
	estadd local interact "No" ;
	estadd local Controls "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;

eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.i_svy_date i.state if race==1 & svy_year<=1980 & svy_type==1 [pw= wgt_comb], cl(state) ;
	meanvar;
	estadd local gss "No" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;

****Adding controls ;
eststo: reg dem conf_aft i.age_decile female i.eduHarmonized i.citySize i.i_svy_date i.state if race==1 & svy_year<=1980 & noprez~=. & svy_type==1 [pw= wgt_comb], cl(state) ;
	meanvar ;
	estadd local Controls "Yes" ;
	estadd local gss "No" ;
	estadd local interact "No" ; 
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;
	
eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.age_decile female i.eduHarmonized i.citySize i.occupation i.i_svy_date i.state if race==1 & svy_year<=1980 & svy_type==1 [pw= wgt_comb], cl(state) ;
	meanvar ;	
	estadd local Controls "Yes" ;
	estadd local gss "No" ;
	estadd local interact "No" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;

*****ADD SEVERAL CLASS-BASED INTERACTIONS ;		
	
	/*** ;
eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.i_svy_date i.state female age i.eduHarm i.citySize conf_age age_aft conf_age_aft highschool conf_highschool highschool_aft conf_highschool_aft 
		citysize conf_citysize citysize_aft conf_citysize_aft if race==1 & svy_year<=1980 & svy_type==1 [pw= wgt_comb], cl(state) ;
	meanvar ;
	estadd local Controls "Yes" ;
	estadd local gss "No" ;
	estadd local interact "Yes" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;

****/ ;	
	
gen hi_occ=	occupation==2 | occupation==10 if occupation<. ;
gen big_city=citysize==3 if citysize<. ;
gen farmwork=occupation==1 | occupation==8 if occupation<. ;

label var hi_occ "High-skill occup." ;
label var big_city "City pop at least 50,000" ;
label var farmwork "Farmer or farm laborer" ;

foreach var of varlist hi_occ big_city farmwork { ;
local varl: var l `var' ;
gen `var'_conf=`var'*confed ;
label var `var'_conf "`varl' x South" ;
gen `var'_aft=`var'*aft ;
label var `var'_aft "`varl' x Aft" ;
gen `var'_conf_aft=`var'*confed*aft ;
label var `var'_conf_aft "`varl' x South x Aft" ;
} ;

***Label other interactions too ;

label var age "Age" ;
label var highschool "HS grad" ;

foreach var of varlist age highschool { ;
local varl: var l `var' ;
label var `var'_aft "`varl' x Aft" ;
label var conf_`var' "South x `varl'" ;
label var conf_`var'_aft "South x `varl' x Aft" ;
} ;


eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.i_svy_date i.state female age i.eduHarm i.citySize i.occupation conf_age age_aft conf_age_aft highschool conf_highschool highschool_aft conf_highschool_aft 
		big_city big_city_* hi_occ hi_occ_* farmwork farmwork_* if race==1 & svy_year<=1980 & svy_type==1 [pw= wgt_comb], cl(state) ;
	meanvar ;
	estadd local Controls "Yes" ;
	estadd local gss "No" ;
	estadd local interact "Yes" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;

***State FE, no controls, add GSS ;
eststo: reg dem conf_aft i.i_svy_date i.state if race==1 & svy_year<=1980 & noprez~=.  [pw= wgt_comb], cl(state) ;
	meanvar;
	estadd local state_fe "Yes" ;
	estadd local gss "Yes" ;
	estadd local interact "No" ;
	estadd local Controls "No" ;
	estadd local max_yr "1980" ;

eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.i_svy_date i.state if race==1 & svy_year<=1980  [pw= wgt_comb], cl(state) ;
	meanvar;
	estadd local state_fe "Yes" ;
	estadd local gss "Yes" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;	
	estadd local max_yr "1980" ;

/*** ;	
***State FE, no controls, add GSS, extend through 2000 ;
eststo: reg dem conf_aft i.i_svy_date i.state if race==1 & svy_year<=2000 & noprez~=.  [pw= wgt_comb], cl(state) ;
	meanvar;
	estadd local gss "Yes" ;
	estadd local interact "No" ;
	estadd local Controls "No" ;
	estadd local max_yr "2000" ;
	estadd local state_fe "Yes" ;

eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.i_svy_date i.state if race==1 & svy_year<=2000  [pw= wgt_comb], cl(state) ;
	meanvar;
	estadd local gss "Yes" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;		
	estadd local max_yr "2000" ;
	estadd local state_fe "Yes" ;
*****/ ;	
	
esttab  using "$tables/main_table.tex",  keep(confed conf_aft noprez conf_noprez noprez_aft conf_noprez_aft) nostar se brackets nomtitles fragment replace 
stats(dvar state_fe Controls interact gss N, label("Mean, dep. var." "State FE?" "Controls?" "Interactions?" "GSS?" "Observations"))
label wrap varwidth(24) ;
 
****One referee wanted to see all the interaction coefficients in Col. (7) ; 
/* 
esttab est7 using ../Draft_paper/graphs/show_interactions.tex, replace fragment booktabs 
keep(conf_noprez_aft conf_highschool highschool_aft conf_highschool_aft conf_age age_aft conf_age_aft hi_occ_* big_city_* farmwork_*) 
star(* .1 ** .05 *** .01) se brackets nomtitles label varwidth(26) wrap  ;
 */ 
    

****Now, we want to show these results graphically ;
***** ;

format svy_date %tdMon_YY ;

** Fabiola's note: ;
// Editor wants t=-1 set to zero? 
 
****Event-time graph ;
gen event_time=_n-1000 ;

cap drop date_* ;
cap drop coeff* ci_lower* ci_upper* ;

format event_time %tdMon._CCYY ;

tab svy_date if svy_year<1990 & noprez<. & dem<. & state<. & wgt_comb<. , matrow(dates) ;
local numrows=`r(r)' ;

forval d=1/`numrows' { ;
	gen date_dum_`d'=svy_date==dates[`d', 1] ;
	gen date_dum_noprez_`d'=noprez*date_dum_`d' ;
	} ;

forval x=0/1 { ;
****For cosmetic reasons, offset one of the series so they are both visible on the graph ;
if `x'==1 local offset = 0 ;
else if `x'==0 local offset = 120 ;
gen coeff_`x'=. ;
gen ci_lower_`x'=. ;
gen ci_upper_`x'=. ;
reg dem date_dum_* if confed==`x' & race==1 & svy_year<1990 & tag_dups==1 [pw= wgt_comb] , cl(state) ;
forval d=1/`numrows' { ;
replace coeff_`x'=_b[date_dum_noprez_`d'] if event_time==dates[`d', 1] + `offset' ;
replace ci_upper_`x'=_b[date_dum_noprez_`d'] + 2*_se[date_dum_noprez_`d'] if event_time==dates[`d', 1] + `offset' ;
replace ci_lower_`x'=_b[date_dum_noprez_`d'] - 2*_se[date_dum_noprez_`d'] if event_time==dates[`d', 1] + `offset' ;
} ;
} ;

*egen tag_date=tag(event_time) ;

*** ;

twoway (scatter coeff_1 event_time, mc(red) mlw(vthin) msize(small)) (rcap ci_upper_1 ci_lower_1 event_time, lc(red) lw(vthin)) 
(scatter coeff_0 event_time, mc(blue) mlw(vthin) msize(small) )  (rcap ci_upper_0 ci_lower_0 event_time, lc(blue) lw(vthin)) 
if event_time<11000 & event_time>-600, 
yline(0, lw(vthin) lc(gray)) xti("") yti("Coefficient value") xlabel(#10, angle(45)) xline(1257, lw(vthin) lc(gray))
legend(on rows(2) ring(0) pos(2) order(1 3) label(1 "Southern states") label(3 "Non-Southern states"))
scheme(aspen) ;

graph export "$figures/event_time_temp_cen2_wgts.pdf", replace ;

exit ;


************************************************************************************;
******Do main table with a variety of linear time trends, economic controls, etc. (Appendix Table) ;
************************************************************************************;

eststo clear ;

***Repeat standard definition ;

***State FE, no controls, add GSS ;
eststo: reg dem conf_aft i.i_svy_date i.state if race==1 & svy_year<=1980 & noprez~=.  [pw= wgt_comb], cl(state) ;
	meanvar;
	estadd local state_fe "Yes" ;
	estadd local gss "Yes" ;
	estadd local interact "No" ;
	estadd local Controls "No" ;
	estadd local max_yr "1980" ;
	estadd local state_yr "No" ;
	estadd local oth_yr "No" ;
	estadd local yr_intx "No" ;
	estadd local econ_st_yr "No" ;
	estadd local dem_st_yr "No" ;
	
	
eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.i_svy_date i.state if race==1 & svy_year<=1980  [pw= wgt_comb], cl(state) ;
	meanvar;
	estadd local state_fe "Yes" ;
	estadd local gss "Yes" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;	
	estadd local max_yr "1980" ;
	estadd local state_yr "No" ;
	estadd local oth_yr "No" ;
	estadd local yr_intx "No" ;
	estadd local econ_st_yr "No" ;
	estadd local dem_st_yr "No" ;
	
	
***Gallup are missing FIPS codes ;
***Merge with crosswalk (first re-name fipsstat so that merge works) ;

rename fipsstat fipsstat_gss ;	
	
sort state svy_year ;	

merge state using $main/gallup_fips_state_code_xwalk ;

tab _merge ;
drop _merge ;

sort fipsstat svy_year ;

preserve ;

use $main/aer_revision/Simon/State_Year/merged_state_year.dta, clear ;

sort fipsstat svy_year ;

tempfile st_yr ;
save `st_yr' ;

restore;

merge fipsstat svy_year using `st_yr' ;

tab _merge ;
drop _merge ;

****Add some additional state-level economic controls & interactions ;

preserve ;


***Download state population data ;

use $main/cencounts_nber, clear ;
**Drop US total ;
drop if fips=="00000" ;
**Only keep states (drop counties) ;
keep if substr(fips, 3, .)=="000" ;
drop pop1900-pop1940 ;

forval x=1/9 { ;
forval y=50(10)80 { ;
local y_1 = `y'+10 ;
local z=`y' + `x' ;
gen pop19`z'=pop19`y'*(10-`x')/10 + pop19`y_1'*(`x'/10) ;
} ;
} ;

reshape long pop, i(fips) j(year) ;
replace fips=substr(fips, 1, 2) ;
destring fips, replace ;
ren fips fipsstat ;
ren year svy_year ;
sort fipsstat svy_year ;
tempfile state_yr_pop ;
save `state_yr_pop' ;

****Add state-year employment ;

use $main/FRED_tot_emp_st_yr, clear ;
ren statefips fipsstat ;
ren year svy_year ;
sort fipsstat svy_year ;
tempfile fred_emp ;
save `fred_emp' ;


***Go back to main data set ;
restore ;

cap drop _merge ;

sort fipsstat svy_year ;

merge fipsstat svy_year using `state_yr_pop' ;
drop _merge ;

sort fipsstat svy_year ;
merge fipsstat svy_year using `fred_emp' ;

**Gen emp to pop ;
gen epop=total_non/pop ;


**Note missings are generaly from pre-1958 and post-1990 ;
	
*****/ ;	
	
***Create interactions ;

foreach var of varlist College HighSchool Gini AvgInc percent_black AGI Top10_adj N_TaxUnit Top1_adj pop epop  { ;
gen `var'_aft=`var'*aft ;
gen `var'_conf=`var'*confed ;
gen `var'_conf_aft=`var'*confed*aft ;	
} ;
	
tab svy_date, gen(sss) ;	
	
*** ;	
	
/**** ;	
eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft sss* i.state female age i.eduHarm /* i.citySize conf_age age_aft conf_age_aft highschool conf_highschool highschool_aft conf_highschool_aft 
		citysize conf_citysize citysize_aft conf_citysize_aft  highschool* age_aft-age_conf_aft citySize_aft - citySize_conf_aft */ AvgInc* Gini* College* percent_black* pop pop_aft - pop_conf_aft epop*  if race==1 & svy_year<=1980 [pw= wgt_comb], cl(state) ;
	meanvar ;
	estadd local Controls "Yes" ;
	estadd local gss "No" ;
	estadd local interact "Yes" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;
	

****/ ;			
	
	eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft sss* i.state female age i.eduHarm /* conf_age age_aft conf_age_aft highschool conf_highschool highschool_aft conf_highschool_aft 
		citysize conf_citysize citysize_aft conf_citysize_aft */ AvgInc Gini pop percent_black epop if race==1 & svy_year<=1980 [pw= wgt_comb], cl(state) ;
	meanvar ;
	estadd local Controls "Yes" ;
	estadd local gss "No" ;
	estadd local interact "Yes" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;
	estadd local econ_st_yr "Yes" ;
	estadd local dem_st_yr "No" ;
	estadd local state_yr "No" ;
	estadd local oth_yr "No" ;
	estadd local yr_intx "No" ;

	eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft sss* i.state female age i.eduHarm /* conf_age age_aft conf_age_aft highschool conf_highschool highschool_aft conf_highschool_aft 
		citysize conf_citysize citysize_aft conf_citysize_aft */ AvgInc Gini epop percent_black College pop if race==1 & svy_year<=1980  [pw= wgt_comb], cl(state) ;
	meanvar ;
	estadd local Controls "Yes" ;
	estadd local gss "No" ;
	estadd local interact "Yes" ;
	estadd local max_yr "1980" ;
	estadd local state_fe "Yes" ;	
	estadd local econ_st_yr "Yes" ;
	estadd local dem_st_yr "Yes" ;
	estadd local state_yr "No" ;
	estadd local oth_yr "No" ;
	estadd local yr_intx "No" ;
	

***** State linear time trends ;
xi i.state|i_svy_date ;
***Drop the state FE that are created (we already have them) ;
drop _Istate_* ;


eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft i.i_svy_date _IstaX* i.state if race==1 & svy_year<=1980  [pw= wgt_comb], cl(state) ;
	meanvar;
	estadd local state_fe "Yes" ;
	estadd local gss "Yes" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;	
	estadd local max_yr "1980" ;
	estadd local state_yr "Yes" ;
	estadd local oth_yr "No" ;
	estadd local yr_intx "No" ;
	estadd local econ_st_yr "No" ;
	estadd local dem_st_yr "No" ;
	
****Add confederate linear time trend , noprez linear time trend, and conf*noprez linear time trend ;	
	
	
gen conf_year=confed*i_svy_date ;
gen noprez_year=noprez*i_svy_date ;
gen conf_noprez_year=confed*noprez*i_svy_date ;	
			
	
eststo: reg dem conf_aft noprez conf_noprez noprez_aft conf_noprez_aft conf_year noprez_year conf_noprez_year i.i_svy_date  i.state if race==1 & svy_year<=1980  [pw= wgt_comb], cl(state) ;
	meanvar;
	estadd local state_fe "Yes" ;
	estadd local gss "Yes" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;	
	estadd local max_yr "1980" ;
	estadd local state_yr "No" ;
	estadd local oth_yr "Yes" ;
	estadd local yr_intx "No" ;
	estadd local econ_st_yr "No" ;
	estadd local dem_st_yr "No" ;

***Other interactions by survey date ;
****Add Conf X Date FE, NoPrez X Date FE ;
***these will absord Conf X Aft, NoPrez X After ;

xi i.confed*i.i_svy_date, pre(_A) ;
***Drop the main effects as we already have them ;
drop _Aconfed* _Ai_svy_dat* ;
xi i.noprez*i.i_svy_date, pre(_B) ;
****Drop the main effects ;
drop _Bnoprez* _Bi_svy_dat* ;

eststo: reg dem noprez conf_noprez  conf_noprez_aft _A* _B* i.i_svy_date  i.state if race==1 & svy_year<=1980  [pw= wgt_comb], cl(state) ;
	meanvar;
	estadd local state_fe "Yes" ;
	estadd local gss "Yes" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;	
	estadd local max_yr "1980" ;
	estadd local state_yr "No" ;
	estadd local oth_yr "No" ;
	estadd local yr_intx "Yes" ;
	estadd local econ_st_yr "No" ;
	estadd local dem_st_yr "No" ;
	
***Separate post-periods ;
***Keep Conf X Date FE and NoPrez x Date FE ;

gen conf_noprez_aft5=confed*noprez*(svy_year>1962 & svy_year<1968) ;
gen conf_noprez_aft10=confed*noprez*(svy_year>1967 & svy_year<1973) ;
gen conf_noprez_aft15=confed*noprez*(svy_year>1972 & svy_year<1978) ;
gen conf_noprez_aft20=confed*noprez*(svy_year>1977 & svy_year<1983) ;

	
eststo: reg dem  noprez conf_noprez conf_noprez_aft5 conf_noprez_aft10 conf_noprez_aft15 conf_noprez_aft20   _A* _B* i.i_svy_date  i.state if race==1 & svy_year<=1982  [pw= wgt_comb], cl(state) ;
	meanvar;
	estadd local state_fe "Yes" ;
	estadd local gss "Yes" ;
	estadd local Controls "No" ;
	estadd local interact "No" ;	
	estadd local max_yr "1982" ;	
	estadd local state_yr "No" ;
	estadd local oth_yr "No" ;
	estadd local yr_intx "Yes" ;
	estadd local econ_st_yr "No" ;
	estadd local dem_st_yr "No" ;
	
test 	conf_noprez_aft5 = conf_noprez_aft10 ;
test 	conf_noprez_aft5 = conf_noprez_aft15 ;
test 	conf_noprez_aft5 = conf_noprez_aft20 ;
test    conf_noprez_aft10 =  conf_noprez_aft15 ;
test 	conf_noprez_aft10 = conf_noprez_aft20 ;
test	conf_noprez_aft15 = conf_noprez_aft20 ;
	
label var conf_noprez_aft5 "South x NoPrez x 1963-1967" ;
label var conf_noprez_aft10 "South x NoPrez x 1968-1972" ;
label var conf_noprez_aft15 "South x NoPrez x 1973-1977" ;
label var conf_noprez_aft20 "South x NoPrez x 1978-1982" ;


esttab using "$tables/main_table_time.tex", replace fragment booktabs keep(noprez conf_aft noprez_aft conf_noprez conf_noprez_aft conf_noprez_aft5 conf_noprez_aft10 conf_noprez_aft15 conf_noprez_aft20) 
stats(dvar econ_st_yr dem_st_yr state_yr dummy oth_yr yr_intx  max_yr N, label("Mean, dep. var." "State-year econ controls?" "State-year demog. controls?" "State-spec. trends?" "South-, Noprez-," "S x Noprez - spec. trends?" "South x Date, NoPrez x Date FE?"
"Max year in sample" "Observations")) nostar se brackets nomtitles wrap varwidth(30) label
mgroups("Dept. variable: Respondent identifies as a Democrat (0/1)", pattern(1 0 0   0 0 0   0 0  ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  ;




************************************************************************************;

*** Prejudice appendix table (GSS ONLY) ;

************************************************************************************;

eststo clear ;

gen dontpush=racpush<2 if racpush<. ;

gen toomuch=natrace==3 if natrace<. ;

ge sepschools=racschol==2 if racschol<. ;

gen nomar=racmar==1 if racmar<. ;

gen nodinner=racdin<3 if racdin<. ;

gen nobusing=busing==2 if busing<. ;

gen obj_afew=racfew_gss==1 if racfew_gss<. ;

local racist_vars "dontpush toomuch nobusing sepschools obj_afew nomar nodinner" ;

label var dontpush "--Strongly agree that blacks shouldn't push themselves where they are not wanted" ;
label var toomuch `"--Agree that government does too much to improve condition of blacks"' ;
label var nodinner "--Would object to family member bringing black friend for dinner" ;
label var nobusing "--Against busing of black and white school children from one district to another" ;
label var obj_afew "--Object to sending children to a school where a few of the children are black?" ;
label var sepschools "--Agree that white and black children should go to separate schools" ;
label var nomar "--Favors laws against marriages between blacks and whites" ;

gen south_noblkp=confed*noprez ;

local label_list="" ;

foreach var of varlist  `racist_vars' { ;
eststo: reg `var' noprez confed south_noblkp  if race==1 & year<1981 & svy_type==2 [aw=wtss] ;
****Extract label of depvar ;
local temp: var label `var' ;
local label_list `" `label_list' `e(_estimates_name)'  "`temp'" "' ;
} ;

esttab, se nostar keep(noprez confed south_noblkp)  ;

matrix C = r(coefs) ;

		
***Rename rownames ;

eststo clear ;

local rnames : rownames C ;

 local models : coleq C ;

 local models : list uniq models ;

 local i 0 ;

 foreach name of local rnames { ;
		
       local ++i ;
       local j 0 ;
       capture matrix drop b ;
       capture matrix drop se ;
       foreach model of local models { ;
           local ++j ;
           matrix tmp = C[`i', 2*`j'-1] ;
           if tmp[1,1]<. { ;
              matrix colnames tmp = `model' ;
              matrix b = nullmat(b), tmp ;
              matrix tmp[1,1] = C[`i', 2*`j'] ;
              matrix se = nullmat(se), tmp ;
          } ;
		  
      } ;
      ereturn post b ;
      quietly estadd matrix se ;
	  *estadd matrix mean_ind=`name'_N ;
      eststo `name' ;
	  local counter=`counter'+1 ;
	  di `counter' ;
		estadd local covar "No" ;
	 
	  ;
  } ;

  
  
/** ; 
esttab ,  cells(b(star fmt(a3)) se(par([ ])) )
star(* .1 ** .05 *** .01)   varlabel(`label_list')
mlabels("No black prez." "South" "South x No bl. prez") 
/* mgroups("Anti-negro view" "Anti-negro / No Gov. role" "Anti-negro / No Fed. role",  
pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  */
varwidth(28) wrap label collabels(none) noobs  ;
    
	
***/ ;	
		
esttab using $tables/gss_prejudice_regs.tex, fragment replace booktabs cells(b( fmt(a3)) se(par([ ])) )
nostar  varlabel(`label_list')
mlabels("No black prez." "South" "South x No bl. prez", lhs("Dependent variable")) 
/* mgroups("Anti-negro view" "Anti-negro / No Gov. role" "Anti-negro / No Fed. role",  
pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  */
varwidth(40) wrap label collabels(none) noobs nonum  ;
		
				






/****** ;

forval s=1/2 { ;
tab svy_date if noprez~=. & svy_type==`s' & svy_date~=4443, matrow(bodie) ;
local max=`r(r)' ;
if `s'==1 local survey "gallup" ;
else if `s'==2 local survey "gss" ;
forval c=0/1 { ;
gen coeff_`survey'_confed`c'=. ;
forval x=1/`max' { ;
qui reg dem noprez if confed==`c' & svy_date==bodie[`x', 1] & race==1 [pw=weight_scaled] ;
replace coeff_`survey'_confed`c'=_b[noprez] if svy_date==bodie[`x', 1] ;
} ;
} ;
matrix drop bodie ;
} ;


egen tag=tag(svy_date) ;

forval x=0/1 { ;
gen coeff_both_confed`x' = coeff_gallup_confed`x' ;
replace coeff_both_confed`x' = coeff_gss_confed`x' if coeff_both_confed`x'==. ;
} ;

sort svy_date ;

twoway (scatter coeff_gallup* coeff_gss* svy_date, m(circle_hollow circle_hollow triangle_hollow triangle_hollow) mlw (thin thin thin thin) msize(medium medium medium medium) mc(blue red blue red)) 
(line coeff_both* svy_date, lc(blue red) lp(solid dash)) if tag==1 & svy_year<1985 , 
legend(on order(6 5) label(5 "Non-South") label(6 "South") ring(0) position(2) rows(2) region(lp(blank)) ) xti("") yti("Coefficient value") xline(1216) scale(1.2) scheme(aspen) ;

graph export ../Draft_paper/Graphs/main_graph.png, replace ;

******/ ;



***** ;

**** JS Added 12/17/15 -- Adding CI to main_graph.png. Might still have bugs in the code ; 
***** ;

forval s=1/2 { ;
tab svy_date if noprez~=. & svy_type==`s' & svy_date~=4443, matrow(bodie) ;
local max=`r(r)' ;
if `s'==1 local survey "gallup" ;
else if `s'==2 local survey "gss" ;
forval c=0/1 { ;
gen coeff_`survey'_confed`c'=. ;
gen ci_lo_`survey'_confed`c'=.;
gen ci_hi_`survey'_confed`c'=.;
forval x=1/`max' { ;
qui reg dem noprez if confed==`c' & svy_date==bodie[`x', 1] & race==1 [pw=weight_scaled] ;
replace coeff_`survey'_confed`c'=_b[noprez] if svy_date==bodie[`x', 1] ;
replace ci_lo_`survey'_confed`c' = _b[noprez] - 1.96*_se[noprez] if svy_date==bodie[`x', 1];
replace ci_hi_`survey'_confed`c' = _b[noprez] + 1.96*_se[noprez] if svy_date==bodie[`x', 1];
} ;
} ;
matrix drop bodie ;
} ;

egen tag=tag(svy_date) ;

forval x=0/1 { ;

* coeffs; 
gen coeff_both_confed`x' = coeff_gallup_confed`x' ;
replace coeff_both_confed`x' = coeff_gss_confed`x' if coeff_both_confed`x'==. ;

* ci's; 
gen ci_lo_both_confed`x' = ci_lo_gallup_confed`x' ;
replace ci_lo_both_confed`x' = ci_lo_gss_confed`x' if ci_lo_both_confed`x'==. ;
gen ci_hi_both_confed`x' = ci_hi_gallup_confed`x' ;
replace ci_hi_both_confed`x' = ci_hi_gss_confed`x' if ci_hi_both_confed`x'==. ;

} ;

sort svy_date ;

twoway

 (rarea ci_lo_both_confed1 ci_hi_both_confed1 svy_date, fcolor(red*0.25) lcolor(red*.25) lw(thin)) 

 (rarea ci_lo_both_confed0 ci_hi_both_confed0 svy_date, fcolor(blue*0.25) lcolor(blue*.25) lw(thin))

 (scatter coeff_gallup* coeff_gss* svy_date, m(circle_hollow circle_hollow triangle_hollow triangle_hollow) mlw (thin thin thin thin) msize(medium medium medium medium) mc(blue red blue red)) 
 
 ( line coeff_both* svy_date, lc(blue red) lp(solid dash))
 
 if tag==1 & svy_year<1985 , 
legend(on order(8 7) label(7 "Non-South") label(8 "South") ring(0) position(2) rows(2) region(lp(blank)) ) xti("") yti("Coefficient value") xline(1216) scale(1.2) scheme(aspen) ;

graph export "$figures/main_graph_ci.pdf", replace ;




***** ;


************************************************************** ;
************************************************************** ;

**** SHARE OF WHITES OK WITH BLACK PREZ OVER TIME (GALLUP AND GSS) ;

************************************************************** ;

format svy_date %tdMon_YY ;

preserve ;

keep if race==1 ;

gen prez=1-noprez ;

egen prez_means=wtmean(prez), weight(weight_scaled) by(confed svy_date) ;

cap drop tag ;

egen tag=tag(confed svy_date) ;

keep if tag==1 ;

sort svy_date confed ;

bys svy_date: gen diff=prez_means[2] - prez_means[1] ;

gen y_line=0 ;

twoway (connect prez_means svy_date if confed==1, yaxis(1) mc(red) lc(red) m(th) mlw(thin) lw(thin) lp(dash)) (connect prez_means svy_date if confed==0, yaxis(1) mc(blue) lc(blue) mlw(thin) lw(thin) lp(dash) m(oh)) 
(line diff svy_date if confed==1, yaxis(2) lw(medthin) lc(green))
(line y_line svy_date if confed==1, yaxis(2) lp(dash) lc(gray) lw(thin)),
scheme(aspen) xti("") yti("Share willing", axis(1)) yti("Difference (South minus non-South)", axis(2))
legend(on label(1 "South") label(2 "Non-South") label(3 "South minus Non-South") order( 1 2 3) ring(0) pos(4) rows(3) region(lstyle(none)) symx(*.75)) 
scale(1.2) xlabel(#11, angle(35)) xsize(6) ;

graph export "$figures/fig_blkprez.pdf", replace ;


restore ;
 
*****DELETE TEMPORARY RESTRICTED-ACCESS DATASETS ;

rm GSS_keyvar_geo.dta ;
rm gallup_and_GSSgeo.dta ;





exit ;
