
*********************************************************************************************************
// Why did the Democrats Lose the South? Bringing New Data to an Old Debate, Kuziemko & Washington (2018)
// This do file cleans the GSS Raw Data


/* SHAPING GSS SURVEYS */

/*
This do file uses a cumulative dataset of 29 GSS surveys from 1972-2012 (GSS7212_R6.dta)
downloaded from the GSS website. It extracts key variables later used in the analysis,
and reshapes them for harmonization with Gallup polls.
*/

clear matrix
clear mata
set more off
set maxvar 32767


else if "`c(username)'"=="kuziemko"  {
cap cd ~/Dropbox/southern_strategy
global path ~/Dropbox/southern_strategy/Replication
global output "$path/Output"
global input "$path/Input/"
global do "$path/DoFiles"

}

else if "`c(username)'"=="fvivar" { 
cap cd ~/Dropbox/southern_strategy
global path ~/Dropbox/southern_strategy/Replication
global output "$path/Output"
global input "$path/Input"
global do "$path/DoFiles"

}


set maxvar 6000

use "$input/GSS7212_R6.dta", clear

keep id partyid racpres age educ degree sex xnorcsiz size vote* pres* if*who ///
	comtype res16 year race region kid5up racfew rachaf ///
	racmost prespop income* coninc oversam sample wtssall dateintv attend ///
	racpush natrace racschol racdin racmar busing 
	
gen racfew_gss = racfew
	
ren attend attend_gss	
	
tostring year, gen(svy)
replace svy = svy + "-GSS"
lab var svy "SURVEY CODE"

clonevar svy_year = year
lab var svy_year "SURVEY YEAR"

gen svy_month = ""
lab var svy_month "SURVEY MONTH(S)"
replace svy_month = "March (February-May)" if svy_year <= 1976 | svy_year == 1989 ///
	| svy_year == 1991
replace svy_month = "March (February-April)" if (svy_year >= 1977 & svy_year <= 1978) ///
	| (svy_year >= 1982 & svy_year <= 1986) | svy_year == 1988 | svy_year == 1990 ///
	| svy_year == 1993
replace svy_month = "March (January-May)" if svy_year == 1980 | svy_year == 1996
replace svy_month = "March (January-April)" if svy_year == 1987
replace svy_month = "March (January-June)" if svy_year == 1994
replace svy_month = "March (February-June)" if svy_year >= 1998 & svy_year <= 2002
replace svy_month = "September (January-December)" if svy_year == 2004
replace svy_month = "May (March-August)" if svy_year == 2006 | svy_year == 2010
replace svy_month = "May (April-September)" if svy_year == 2008
replace svy_month = "May (March-September)" if svy_year == 2012

label variable age "AGE OF THE RESPONDENT"

label variable sex "GENDER OF THE RESPONDENT"
label drop SEX
label define lb_sex 1 "MALE" 2 "FEMALE"
label values sex lb_sex

label variable race "RACE OF THE RESPONDENT"
label drop RACE
label define lb_race 1 "WHITE" 2 "BLACK" 3 "OTHER"
label values race lb_race

gen raceSex = .
replace raceSex = 1 if race == 1 & sex == 1
replace raceSex = 2 if race == 1 & sex == 2
replace raceSex = 3 if race == 2 & sex == 1
replace raceSex = 4 if race == 2 & sex == 2
replace raceSex = 5 if race == 3 & sex == 1
replace raceSex = 6 if race == 3 & sex == 2
label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN"
label values raceSex lb_raceSex

rename region region_old
gen region = .
replace region = 1 if region_old == 1 | region_old == 2
replace region = 2 if region_old == 3 | region_old == 4
replace region = 3 if region_old == 5 | region_old == 6 | region_old == 7
replace region = 4 if region_old == 8 | region_old == 9
lab var region "REGION THE RESPONDENT LIVES IN"
lab def lb_region 1 "Northeast" 2 "Midwest" 3 "South" 4 "West"
lab val region lb_region

rename coninc incomeHHharmonized
label variable incomeHHharmonized "TOTAL ANNUAL HH INCOME PRE-TAXES IN 2013 DOLLARS [USING BRACKET MIDPOINTS]"
merge m:1 svy_year using cpi_1913-2014.dta, keepusing(cpi_annual)
gen temp = cpi_annual if svy_year == 2013 //2013 = reference year
egen cpi_2013 = max(temp)
label variable cpi_2013 "2013 US Consumer Price Index (all items, all urban consumers, 1982-84 = 100)"
drop if _merge == 2
drop _merge temp
gen temp = cpi_annual if svy_year == 2000 //original GSS coninc expressed in 2000 dollars
egen cpi_2000 = max(temp)
replace incomeHHharmonized = incomeHHharmonized*cpi_2013/cpi_2000 if incomeHHharmonized != .
drop temp cpi_2000

gen poliPartyID = .
replace poliPartyID = 1 if partyid == 5 | partyid == 6
replace poliPartyID = 2 if partyid == 0 | partyid == 1
replace poliPartyID = 3 if partyid == 2 | partyid == 3 | partyid == 4
replace poliPartyID = 4 if partyid == 7
label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define  lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

rename racpres blkPresident
label variable blkPresident "IF YOUR PARTY NOMINATED A QUALIFIED BLACK FOR PRESIDENT, WOULD YOU VOTE FOR HIM"

rename racfew fewMixedSchool
rename rachaf halfMixedSchool
rename racmost halfPlusMixedSchool
label variable fewMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH A FEW BLACK CHILDREN"
label variable halfMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH HALF BLACK CHILDREN"
label variable halfPlusMixedSchool "OBJECTION TO SENDING CHILDREN TO A SCHOOL WITH MORE THAN HALF BLACK CHILDREN"

recode blkPresident fewMixedSchool halfMixedSchool halfPlusMixedSchool (.d=3)
label define lb_yesNoNoOp 1 "Yes" 2 "No" 3 "No Opinion" 9 "INAPPLICABLE"
label values blkPresident fewMixedSchool halfMixedSchool halfPlusMixedSchool lb_yesNoNoOp

rename prespop presApprovala
label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
recode presApprovala (.d=3)
label define lb_presApproval 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION"
label values presApprovala lb_presApproval

gen eduHarmonized = .
replace eduHarmonized = 1 if educ >= 0 & educ <= 8
replace eduHarmonized = 4 if educ >= 9 & educ <= 11
replace eduHarmonized = 5 if educ == 12
replace eduHarmonized = 7 if educ >= 13 & educ <= 15
replace eduHarmonized = 8 if educ >= 16 & educ <= 20
label variable eduHarmonized "LAST GRADE OR CLASS COMPLETED IN SCHOOL [HARMONIZED LABELS ACROSS SURVEYS]"
label define lb_eduHarmonized 1 "NONE, OR GRADES 1-8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE"
label values eduHarmonized lb_eduHarmonized

drop partyid res16 region_old kid5up income* dateintv

*converting all extended missing values (.*) to sysmiss (.)
recode age educ degree fewMixedSchool halfMixedSchool halfPlusMixedSchool blkPresident presApprovala comtype (missing=.)

saveold "$input/GSS_keyvar.dta", replace
