/*
File name: gallup_gss_add_truman_svy_dates.do

Description:
	- adds in missing svy_date observations for truman-era gallup svys
	- excel sheet with dates was manually taken from the iPoll website
	
Uses data:
	- gallup&gss/gallup_gss_svys_missing_dates_1944_to_1953.xlsx
	
*/

*** Import data
import excel gallup_gss_svys_missing_dates_1944_to_1953.xlsx, clear firstrow

*** Create date variable

** Extract year
split date, p(",")
rename date2 year

** Extract month and date
split date1, p("-")

* start date
split date11, p(" ")
rename date111 start_month
rename date112 start_day

* end date
split date12, p(" ")
// surveys that start & end in same month
gen end_month = start_month
gen end_day = date121 if missing(date122)

// surveys that start in one month and end in the next
replace end_month = date121 if !missing(date122)
replace end_day = date122 if !missing(date122)

*** Put everything together
gen start_date = start_month + " " + start_day + "," + year
gen end_date = end_month + " " + end_day + "," + year
gen svy_date = round((date(start_date,"MDY") + date(end_date,"MDY"))/2)

* Keep variables of interest
keep svy_date svy

*** Save
save gallup_gss_truman_dates.dta, replace



