
set more off

*Change directory so others can use the do file
cd "/Users/`c(username)'/Dropbox/southern_strategy/Gallup&GSS/PartyID_1963-1970"

log using PartyID_1963-1970.6.18.2016.log, replace

*FILE NOTE 1: We include presidential approval here for the Johnson Administration surveys only, i.e., USAIPO1963-0681 (December 5, 1963 - December 10, 1963) through USAIPO1969-0773 (January 1, 1969 - January 6, 1969). Note that survey number USAIPO1969-0774 (January 23, 1969 - January 28, 1969) has the approval question for Nixon, not Johnson. Of the available (i.e., non-binary) surveys over the Johnson Administration, five do not contain the presidential approval question, as documented in each "APPROVAL OF CURRENT PRESIDENT (presApprovala)" Harmonization Plan.

*FILE NOTE 2: The PARTY ID IN POLITICS TODAY variable (poliPartyID) is not available in USAIPO1967-0739 (January 7, 1967 - January 12, 1967).

*FILE NOTE 3: We include the opinion question on the speed of racial integration for the Johnson Administration surveys only, i.e., USAIPO1963-0681 (December 5, 1963 - December 10, 1963) through USAIPO1969-0773 (January 1, 1969 - January 6, 1969). The harmonization plan(s) for this variable, "OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)," details the surveys in which the question was asked during the Johnson years.

********VARIABLE CREATION, ADJUSTMENT, AND HARMONIZATION********
****USAIPO1963-0681****

clear

*Read in dictionary file for USAIPO1963-0681; December 5, 1963 - December 10, 1963)
infile using DictionaryFiles\aipo1963-0681.dct

*The sample size in the codebook - 4,425 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1963-0681"

*Create a variable for survey year
gen svy_yr = 1963

*Create a variable for survey month
gen svy_month = "December"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 6
replace partyCD = 6 if partyCD_orig == 7
replace partyCD = 7 if partyCD_orig == 4 | partyCD_orig == 8 | partyCD_orig == 9


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterJohnson = goldwaterJohnson_orig

*Replace values
replace goldwaterJohnson = 4 if goldwaterJohnson_orig == 7


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is not available in this file.


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1963-0681.dta, replace

clear


****USAIPO1963-0682****

*Read in dictionary file for USAIPO1963-0682; December 12, 1963 - December 17, 1963)
*Note that there are two observations in the party variable that contain odd characters. Since no other variable has this problem, and it is limited to two observations, we do not necessarily assume this is a binary file that requires exclusion. Rather, to address the issue, we read in the party variable in the dictionary file as a string, and in the harmonization section below, we set the two observations to missing and then convert the variable to numeric.
infile using DictionaryFiles\aipo1963-0682.dct

*The sample size in the codebook - 4,126 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1963-0682"

*Create a variable for survey year
gen svy_yr = 1963

*Create a variable for survey month
gen svy_month = "December"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Prior to checking the variable, we address the two observations with odd characters by setting those observations to missing and then converting the variable to numeric

*Set observations with odd characters to missing
replace poliPartyID_orig = "" if poliPartyID_orig == ":"

*Convert the variable to numeric
destring poliPartyID_orig, replace

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook; the two observations in the "blank" column likely correspond to the two observations with odd characters that we set to missing.

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 5


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is not available in this file


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterJohnson_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterJohnson = goldwaterJohnson_orig

*Replace values
replace goldwaterJohnson = 4 if goldwaterJohnson_orig == 7


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerJohnson_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerJohnson = rockefellerJohnson_orig

*Replace values
replace rockefellerJohnson = 4 if rockefellerJohnson_orig == 7


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*With the exception of two states -- California and Tennessee -- the frequency distribution displayed next to the variable in the codebook matches the tabulated variable; compare the variable to frequency table in the back of the codebook to ensure that the dictionary file was read in correctly.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1963-0682.dta, replace

clear


****USAIPO1964-0683****

*Read in dictionary file for USAIPO1964-0683; January 2, 1964 - January 7, 1964)
infile using DictionaryFiles\aipo1964-0683.dct


*The sample size in the codebook - 4,138 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1964-0683"

*Create a variable for survey year
gen svy_yr = 1964

*Create a variable for survey month
gen svy_month = "January"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 5


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is not available in this file


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterJohnson = goldwaterJohnson_orig

*Replace values
replace goldwaterJohnson = 4 if goldwaterJohnson_orig == 7


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerJohnson = rockefellerJohnson_orig

*Replace values
replace rockefellerJohnson = 4 if rockefellerJohnson_orig == 7


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1964-0683.dta, replace

clear


****USAIPO1964-0684****

*Read in dictionary file for USAIPO1964-0684; January 30, 1964 - February 5, 1964)
infile using DictionaryFiles\aipo1964-0684.dct

*The sample size in the codebook - 3,109 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1964-0684"

*Create a variable for survey year
gen svy_yr = 1964

*Create a variable for survey month
gen svy_month = "January-February"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 6
replace partyCD = 6 if partyCD_orig == 7
replace partyCD = 7 if partyCD_orig == 4 | partyCD_orig == 8 | partyCD_orig == 9


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterJohnson = goldwaterJohnson_orig

*Replace values
replace goldwaterJohnson = 4 if goldwaterJohnson_orig == 7


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerJohnson = rockefellerJohnson_orig

*Replace values
replace rockefellerJohnson = 4 if rockefellerJohnson_orig == 7


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab region_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen region = region_orig


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab integrationRate_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen integrationRate = integrationRate_orig


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1964-0684.dta, replace

clear


****USAIPO1964-0686****

*Read in dictionary file for USAIPO1964-0686; February 28, 1964 - March 5, 1964)
infile using DictionaryFiles\aipo1964-0686.dct

*The sample size in the codebook - 3,503 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1964-0686"

*Create a variable for survey year
gen svy_yr = 1964

*Create a variable for survey month
gen svy_month = "February-March"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 6
replace partyCD = 6 if partyCD_orig == 7
replace partyCD = 7 if partyCD_orig == 4 | partyCD_orig == 8 | partyCD_orig == 9


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterJohnson = goldwaterJohnson_orig

*Replace values
replace goldwaterJohnson = 4 if goldwaterJohnson_orig == 7


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerJohnson = rockefellerJohnson_orig

*Replace values
replace rockefellerJohnson = 4 if rockefellerJohnson_orig == 7


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab region_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen region = region_orig


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab fedIncomeTax_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen fedIncomeTax = fedIncomeTax_orig

*Replace values
replace fedIncomeTax = 4 if fedIncomeTax_orig == 5
replace fedIncomeTax = 0 if fedIncomeTax_orig == 4


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1964-0686.dta, replace

clear


****USAIPO1964-0687****

*Read in dictionary file for USAIPO1964-0687; March 13, 1964 - March 17, 1964)
infile using DictionaryFiles\aipo1964-0687.dct

*The sample size in the codebook - 3,520 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1964-0687"

*Create a variable for survey year
gen svy_yr = 1964

*Create a variable for survey month
gen svy_month = "March"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 6
replace partyCD = 6 if partyCD_orig == 7
replace partyCD = 7 if partyCD_orig == 4 | partyCD_orig == 8 | partyCD_orig == 9


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterJohnson = goldwaterJohnson_orig

*Replace values
replace goldwaterJohnson = 4 if goldwaterJohnson_orig == 7


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerJohnson = rockefellerJohnson_orig

*Replace values
replace rockefellerJohnson = 4 if rockefellerJohnson_orig == 7


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1964-0687.dta, replace

clear


****USAIPO1964-0688****

*Read in dictionary file for USAIPO1964-0688; March 27, 1964 - April 2, 1964); note that the usage notes on the first page of the codebook do not state that there are two records per respondent, but this is indicated elsewhere in the codebook.
infile using DictionaryFiles\aipo1964-0688.dct

*The sample size in the codebook - 3,539 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1964-0688"

*Create a variable for survey year
gen svy_yr = 1964

*Create a variable for survey month
gen svy_month = "March-April"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 6
replace partyCD = 6 if partyCD_orig == 7
replace partyCD = 7 if partyCD_orig == 4 | partyCD_orig == 8 | partyCD_orig == 9


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterJohnson = goldwaterJohnson_orig

*Replace values
replace goldwaterJohnson = 4 if goldwaterJohnson_orig == 7


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerJohnson = rockefellerJohnson_orig

*Replace values
replace rockefellerJohnson = 4 if rockefellerJohnson_orig == 7


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1964-0688.dta, replace

clear


****USAIPO1964-0689****

*Read in dictionary file for USAIPO1964-0689; April 24, 1964 - April 29, 1964); note that the usage notes on the first page of the codebook do not state that there are two records per respondent, but this is indicated elsewhere in the codebook.
infile using DictionaryFiles\aipo1964-0689.dct

*The sample size in the codebook - 3,509 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1964-0689"

*Create a variable for survey year
gen svy_yr = 1964

*Create a variable for survey month
gen svy_month = "April"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is not available in this file


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterJohnson = goldwaterJohnson_orig

*Replace values
replace goldwaterJohnson = 4 if goldwaterJohnson_orig == 7


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab rockefellerJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen rockefellerJohnson = rockefellerJohnson_orig

*Replace values
replace rockefellerJohnson = 4 if rockefellerJohnson_orig == 7


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab mostImpProbCivRights_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen mostImpProbCivRights = mostImpProbCivRights_orig


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1964-0689.dta, replace

clear


****USAIPO1964-0693****

*Read in dictionary file for USAIPO1964-0693; June 11, 1964 - June 16, 1964)
infile using DictionaryFiles\aipo1964-0693.dct

*The sample size in the codebook - 3,521 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1964-0693"

*Create a variable for survey year
gen svy_yr = 1964

*Create a variable for survey month
gen svy_month = "June"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig>=4 & poliPartyID<=7
replace poliPartyID = 4 if poliPartyID_orig == 8


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 5
replace partyCD = 5 if partyCD_orig == 4
replace partyCD = 7 if partyCD_orig == 7 | partyCD_orig == 8 | partyCD_orig == 9


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterJohnson = goldwaterJohnson_orig

*Replace values
replace goldwaterJohnson = 3 if goldwaterJohnson_orig == 6
replace goldwaterJohnson = 5 if goldwaterJohnson_orig == 3
replace goldwaterJohnson = 6 if goldwaterJohnson_orig == 4
replace goldwaterJohnson = 4 if goldwaterJohnson_orig == 5 | goldwaterJohnson_orig == 7


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is not available in this file.


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1964-0693.dta, replace

clear


****USAIPO1964-0694****

*Read in dictionary file for USAIPO1964-0694; June 25, 1964 - June 30, 1964)
infile using DictionaryFiles\aipo1964-0694.dct

*The sample size in the codebook - 3,506 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1964-0694"

*Create a variable for survey year
gen svy_yr = 1964

*Create a variable for survey month
gen svy_month = "June"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig>=5 & poliPartyID<=8


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 6
replace partyCD = 6 if partyCD_orig == 7
replace partyCD = 7 if partyCD_orig == 4 | partyCD_orig == 8 | partyCD_orig == 9


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

*Replace values
replace presApprovala = 3 if presApprovala_orig == 4
replace presApprovala = 4 if presApprovala_orig == 3


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab goldwaterJohnson_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen goldwaterJohnson = goldwaterJohnson_orig

*Replace values
replace goldwaterJohnson = 4 if goldwaterJohnson_orig == 7


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is not available in this file.


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab mostImpProbCivRights_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen mostImpProbCivRights = mostImpProbCivRights_orig


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1964-0694.dta, replace

clear


****USAIPO1964-0699****

*Read in dictionary file for USAIPO1964-0699; October 8, 1964 - October 13, 1964)
infile using DictionaryFiles\aipo1964-0699.dct

*The sample size in the codebook - 3,503 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1964-0699"

*Create a variable for survey year
gen svy_yr = 1964

*Create a variable for survey month
gen svy_month = "October"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 5
replace partyCD = 5 if partyCD_orig == 4
replace partyCD = 7 if partyCD_orig == 7 | partyCD_orig == 8 | partyCD_orig == 9


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*N/A: This variable is not available in USAIPO1964-0699


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file.


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is not available in this file.


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab region_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen region = region_orig

*Replace values
replace region = 6 if region_orig == 7
replace region = 7 if region_orig == 8
replace region = 8 if region_orig == 6


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1964-0699.dta, replace

clear


****USAIPO1964-0701****

*Read in dictionary file for USAIPO1964-0701; November 6, 1964 - November 11, 1964)
infile using DictionaryFiles\aipo1964-0701.dct

*The sample size in the codebook - 3,435 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1964-0701"

*Create a variable for survey year
gen svy_yr = 1964

*Create a variable for survey month
gen svy_month = "November"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 6
replace partyCD = 6 if partyCD_orig == 7
replace partyCD = 7 if partyCD_orig == 4 | partyCD_orig == 8 | partyCD_orig == 9


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*N/A: This variable is not available in USAIPO1964-0701


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file.


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is not available in this file.


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1964-0701.dta, replace

clear


****USAIPO1964-0702****

*Read in dictionary file for USAIPO1964-0702; November 20, 1964 - November 25, 1964)
infile using DictionaryFiles\aipo1964-0702.dct

*The sample size in the codebook - 3,531 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1964-0702"

*Create a variable for survey year
gen svy_yr = 1964

*Create a variable for survey month
gen svy_month = "November"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab partyCD_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen partyCD = partyCD_orig

*Replace values
replace partyCD = 1 if partyCD_orig == 2
replace partyCD = 2 if partyCD_orig == 1
replace partyCD = 4 if partyCD_orig == 6
replace partyCD = 6 if partyCD_orig == 7
replace partyCD = 7 if partyCD_orig == 4 | partyCD_orig == 8 | partyCD_orig == 9


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file.


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is not available in this file.


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab welfSpend_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen welfSpend = welfSpend_orig

*Replace values
replace welfSpend = 2 if welfSpend_orig == 3
replace welfSpend = 3 if welfSpend_orig == 2


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1964-0702.dta, replace

clear


****USAIPO1965-0704****

*Read in dictionary file for USAIPO1965-0704; January 7, 1965 - January 12, 1965)
infile using DictionaryFiles\aipo1965-0704.dct

*The sample size in the codebook - 3,492 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1965-0704"

*Create a variable for survey year
gen svy_yr = 1965

*Create a variable for survey month
gen svy_month = "January"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1965-0704.dta, replace

clear


****USAIPO1965-0705****

*Read in dictionary file for USAIPO1965-0705; January 28, 1965 - February 2, 1965)
infile using DictionaryFiles\aipo1965-0705.dct

*The sample size in the codebook - 3,508 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1965-0705"

*Create a variable for survey year
gen svy_yr = 1965

*Create a variable for survey month
gen svy_month = "January-February"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1965-0705.dta, replace

clear


****USAIPO1965-0706****

*Read in dictionary file for USAIPO1965-0706; February 19, 1965 - February 24, 1965)
infile using DictionaryFiles\aipo1965-0706.dct

*The sample size in the codebook - 3,505 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1965-0706"

*Create a variable for survey year
gen svy_yr = 1965

*Create a variable for survey month
gen svy_month = "February"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1965-0706.dta, replace

clear


****USAIPO1965-0709****

*Read in dictionary file for USAIPO1965-0709; April 2, 1965 - April 7, 1965)
infile using DictionaryFiles\aipo1965-0709.dct

*The sample size in the codebook - 3,532 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1965-0709"

*Create a variable for survey year
gen svy_yr = 1965

*Create a variable for survey month
gen svy_month = "April"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*With the exception of two states -- Pennsyvlania and West Virginia -- the frequency distribution displayed next to the variable in the codebook matches the tabulated variable. As there is no frequency table in the back of the codebook, we cannot double-check the variable by identifying frequencies by column and then comparing against the table.

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab integrationRate_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen integrationRate = integrationRate_orig


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1965-0709.dta, replace

clear


****USAIPO1965-0711****

*Read in dictionary file for USAIPO1965-0711; May 13, 1965 - May 18, 1965)
infile using DictionaryFiles\aipo1965-0711.dct

*The sample size in the codebook - 3,546 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1965-0711"

*Create a variable for survey year
gen svy_yr = 1965

*Create a variable for survey month
gen svy_month = "May"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1965-0711.dta, replace

clear


****USAIPO1965-0713****

*Read in dictionary file for USAIPO1965-0713; June 24, 1965 - June 29, 1965)
infile using DictionaryFiles\aipo1965-0713.dct

*The sample size in the codebook - 3,536 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1965-0713"

*Create a variable for survey year
gen svy_yr = 1965

*Create a variable for survey month
gen svy_month = "June"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab integrationRate_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen integrationRate = integrationRate_orig


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1965-0713.dta, replace

clear


****USAIPO1965-0715****

*Read in dictionary file for USAIPO1965-0715; August 5, 1965 - August 10, 1965)
infile using DictionaryFiles\aipo1965-0715.dct

*The sample size shown on the front page of the codebook - 3,528 - does not match the number of observations read into Stata (3,527). However, the sample size indicated on page 2 of the codebook (i.e., 2 of 26 in the PDF) matches the number of observations read into Stata.

*Create a variable for survey code
gen svy = "1965-0715"

*Create a variable for survey year
gen svy_yr = 1965

*Create a variable for survey month
gen svy_month = "August"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1965-0715.dta, replace

clear


****USAIPO1965-0716****

*Read in dictionary file for USAIPO1965-0716; August 27, 1965 - September 1, 1965)
infile using DictionaryFiles\aipo1965-0716.dct

*The sample size in the codebook - 3,525 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1965-0716"

*Create a variable for survey year
gen svy_yr = 1965

*Create a variable for survey month
gen svy_month = "August-September"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The age distribution table displayed in the codebook does not match the tabulated variable; compare the variable to frequency table in the back of the codebook to ensure that the dictionary file was read in correctly.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*With the exception of six states -- Illinois, New Jersey, New York, Oregon, Pennsyvlania, and Wisconsin -- the frequency distribution displayed next to the variable in the codebook matches the tabulated variable; compare the variable to frequency table in the back of the codebook to ensure that the dictionary file was read in correctly.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab integrationRate_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen integrationRate = integrationRate_orig


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1965-0716.dta, replace

clear


****USAIPO1965-0717****

*Read in dictionary file for USAIPO1965-0717; September 16, 1965 - September 21, 1965)
infile using DictionaryFiles\aipo1965-0717.dct

*The sample size in the codebook - 3,555 - does not match the number of observations read into Stata

*Create a variable for survey code
gen svy = "1965-0717"

*Create a variable for survey year
gen svy_yr = 1965

*Create a variable for survey month
gen svy_month = "September"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, as there is no frequency table in the back of the codebook, we cannot double-check the variable.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. As there is no frequency table in the back of the codebook, we cannot double-check the variable by identifying frequencies by column and then comparing against the table.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. As there is no frequency table in the back of the codebook, we cannot double-check the variable by identifying frequencies by column and then comparing against the table.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The age distribution table displayed in the codebook does not match the tabulated variable. As there is no frequency table in the back of the codebook, we cannot double-check the variable by identifying frequencies by column and then comparing against the table.

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*With the exception of four states -- Illinois, Indiana, Kansas, and Nebraska -- the frequency distribution displayed next to the variable in the codebook matches the tabulated variable. As there is no frequency table in the back of the codebook, we cannot double-check the variable by identifying frequencies by column and then comparing against the table. 

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1965-0717.dta, replace

clear


****USAIPO1965-0718****

*Read in dictionary file for USAIPO1965-0718; October 8, 1965 - October 13, 1965)
infile using DictionaryFiles\aipo1965-0718.dct

*The sample size in the codebook - 3,520 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1965-0718"

*Create a variable for survey year
gen svy_yr = 1965

*Create a variable for survey month
gen svy_month = "October"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1965-0718.dta, replace

clear


****USAIPO1965-0719****

*Read in dictionary file for USAIPO1965-0719; October 29, 1965 - November 2, 1965)
infile using DictionaryFiles\aipo1965-0719.dct

*The sample size in the codebook - 3,525 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1965-0719"

*Create a variable for survey year
gen svy_yr = 1965

*Create a variable for survey month
gen svy_month = "October-November"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1965-0719.dta, replace

clear


****USAIPO1965-0721****

*Read in dictionary file for USAIPO1965-0721; December 11, 1965 - December 16, 1965)
infile using DictionaryFiles\aipo1965-0721.dct

*The sample size in the codebook - 3,532 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1965-0721"

*Create a variable for survey year
gen svy_yr = 1965

*Create a variable for survey month
gen svy_month = "December"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1965-0721.dta, replace

clear


****USAIPO1966-0722****

*Read in dictionary file for USAIPO1966-0722; December 31, 1965 - January 5, 1966)
infile using DictionaryFiles\aipo1966-0722.dct

*The sample size in the codebook - 3,530 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1966-0722"

*Create a variable for survey year
gen svy_yr = 1966

*Create a variable for survey month
gen svy_month = "December-January"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1966-0722.dta, replace

clear


****USAIPO1966-0723****

*Read in dictionary file for USAIPO1966-0723; January 21, 1966 - January 26, 1966)
infile using DictionaryFiles\aipo1966-0723.dct

*The sample size in the codebook - 3,508 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1966-0723"

*Create a variable for survey year
gen svy_yr = 1966

*Create a variable for survey month
gen svy_month = "January"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1966-0723.dta, replace

clear


****USAIPO1966-0724****

*Read in dictionary file for USAIPO1966-0724; February 10, 1966 - February 15, 1966)
infile using DictionaryFiles\aipo1966-0724.dct

*The sample size in the codebook - 3,517 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1966-0724"

*Create a variable for survey year
gen svy_yr = 1966

*Create a variable for survey month
gen svy_month = "February"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab fedIncomeTax_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen fedIncomeTax = fedIncomeTax_orig


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1966-0724.dta, replace

clear


****USAIPO1966-0727****

*Read in dictionary file for USAIPO1966-0727; April 14, 1966 - April 19, 1966)
infile using DictionaryFiles\aipo1966-0727.dct

*The sample size in the codebook - 3,539 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1966-0727"

*Create a variable for survey year
gen svy_yr = 1966

*Create a variable for survey month
gen svy_month = "April"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1966-0727.dta, replace

clear


****USAIPO1966-0731****

*Read in dictionary file for USAIPO1966-0731; July 8, 1966 - July 13, 1966)
infile using DictionaryFiles\aipo1966-0731.dct

*The sample size in the codebook - 3,549 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1966-0731"

*Create a variable for survey year
gen svy_yr = 1966

*Create a variable for survey month
gen svy_month = "July"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1966-0731.dta, replace

clear


****USAIPO1966-0732****

*Read in dictionary file for USAIPO1966-0732; July 29, 1966 - August 3, 1966)
infile using DictionaryFiles\aipo1966-0732.dct

*The sample size in the codebook - 3,516 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1966-0732"

*Create a variable for survey year
gen svy_yr = 1966

*Create a variable for survey month
gen svy_month = "July-August"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1966-0732.dta, replace

clear


****USAIPO1966-0733****

*Read in dictionary file for USAIPO1966-0733; August 18, 1966 - August 23, 1966)
infile using DictionaryFiles\aipo1966-0733.dct

*The sample size in the codebook - 3,541 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1966-0733"

*Create a variable for survey year
gen svy_yr = 1966

*Create a variable for survey month
gen svy_month = "August"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1966-0733.dta, replace

clear


****USAIPO1966-0734****

*Read in dictionary file for USAIPO1966-0734; September 8, 1966 - September 13, 1966)
infile using DictionaryFiles\aipo1966-0734.dct

*The sample size in the codebook - 3,532 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1966-0734"

*Create a variable for survey year
gen svy_yr = 1966

*Create a variable for survey month
gen svy_month = "September"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab integrationRate_orig

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen integrationRate = integrationRate_orig


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1966-0734.dta, replace

clear


****USAIPO1966-0735****

*Read in dictionary file for USAIPO1966-0735; October 1, 1966 - October 6, 1966)
infile using DictionaryFiles\aipo1966-0735.dct

*The sample size shown on the front page of the codebook - 3,532 - does not match the number of observations read into Stata (3,531). However, the sample size indicated on page 2 of the codebook (i.e., 2 of 41 in the PDF) matches the number of observations read into Stata.

*Create a variable for survey code
gen svy = "1966-0735"

*Create a variable for survey year
gen svy_yr = 1966

*Create a variable for survey month
gen svy_month = "October"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1966-0735.dta, replace

clear


****USAIPO1966-0736****

*Read in dictionary file for USAIPO1966-0736; October 21, 1966 - October 26, 1966)
infile using DictionaryFiles\aipo1966-0736.dct

*The sample size in the codebook - 3,510 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1966-0736"

*Create a variable for survey year
gen svy_yr = 1966

*Create a variable for survey month
gen svy_month = "October"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab integrationRate_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen integrationRate = integrationRate_orig


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1966-0736.dta, replace

clear


****USAIPO1966-0737****

*Read in dictionary file for USAIPO1966-0737; November 10, 1966 - November 15, 1966)
infile using DictionaryFiles\aipo1966-0737.dct

*The sample size in the codebook - 3,525 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1966-0737"

*Create a variable for survey year
gen svy_yr = 1966

*Create a variable for survey month
gen svy_month = "November"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1966-0737.dta, replace

clear


****USAIPO1966-0738****

*Read in dictionary file for USAIPO1966-0738; December 8, 1966 - December 13, 1966)
infile using DictionaryFiles\aipo1966-0738.dct

*The sample size in the codebook - 3,542 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1966-0738"

*Create a variable for survey year
gen svy_yr = 1966

*Create a variable for survey month
gen svy_month = "December"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1966-0738.dta, replace

clear


****USAIPO1967-0739****

*Read in dictionary file for USAIPO1967-0739; January 7, 1967 - January 12, 1967)
infile using DictionaryFiles\aipo1967-0739.dct

*The sample size in the codebook - 3,519 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0739"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "January"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*N/A: This variable is not available in this file


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1967-0739.dta, replace

clear


****USAIPO1967-0740****

*Read in dictionary file for USAIPO1967-0740; January 26, 1967 - January 31, 1967)
infile using DictionaryFiles\aipo1967-0740.dct

*The sample size in the codebook - 3,491 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0740"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "January"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1967-0740.dta, replace

clear


****USAIPO1967-0741****

*Read in dictionary file for USAIPO1967-0741; February 16, 1967 - February 21, 1967)
infile using DictionaryFiles\aipo1967-0741.dct

*The sample size in the codebook - 3,509 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0741"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "February"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1967-0741.dta, replace

clear


****USAIPO1967-0742****

*Read in dictionary file for USAIPO1967-0742; March 9, 1967 - March 14, 1967)
infile using DictionaryFiles\aipo1967-0742.dct

*The sample size in the codebook - 3,522 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0742"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "March"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab fedIncomeTax_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen fedIncomeTax = fedIncomeTax_orig


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1967-0742.dta, replace

clear


****USAIPO1967-0743****

*Read in dictionary file for USAIPO1967-0743; March 30, 1967 - April 4, 1967)
infile using DictionaryFiles\aipo1967-0743.dct

*The sample size in the codebook - 3,504 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0743"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "March-April"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1967-0743.dta, replace

clear


****USAIPO1967-0745****

*Read in dictionary file for USAIPO1967-0745; May 11, 1967 - May 16, 1967)
infile using DictionaryFiles\aipo1967-0745.dct

*The sample size in the codebook - 3,078 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0745"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "May"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1967-0745.dta, replace

clear


****USAIPO1967-0746****

*Read in dictionary file for USAIPO1967-0746; June 2, 1967 - June 7, 1967)
infile using DictionaryFiles\aipo1967-0746.dct

*The sample size in the codebook - 3,383 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0746"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "June"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1967-0746.dta, replace

clear


****USAIPO1967-0747****

*Read in dictionary file for USAIPO1967-0747; June 22, 1967 - June 27, 1967)
infile using DictionaryFiles\aipo1967-0747.dct

*The sample size in the codebook - 3,783 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0747"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "June"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1967-0747.dta, replace

clear


****USAIPO1967-0748****

*Read in dictionary file for USAIPO1967-0748; July 13, 1967 - July 18, 1967)
infile using DictionaryFiles\aipo1967-0748.dct

*The sample size in the codebook - 1,518 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0748"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "July"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab integrationRate_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen integrationRate = integrationRate_orig


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1967-0748.dta, replace

clear


****USAIPO1967-0750****

*Read in dictionary file for USAIPO1967-0750; August 24, 1967 - August 29, 1967)
infile using DictionaryFiles\aipo1967-0750.dct

*The sample size in the codebook - 3,138 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0750"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "August"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1967-0750.dta, replace

clear


****USAIPO1967-0751****

*Read in dictionary file for USAIPO1967-0751; September 14, 1967 - September 19, 1967)
infile using DictionaryFiles\aipo1967-0751.dct

*The sample size in the codebook - 3,948 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0751"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "September"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1967-0751.dta, replace

clear


****USAIPO1967-0752****

*Read in dictionary file for USAIPO1967-0752; October 6, 1967 - October 11, 1967)
infile using DictionaryFiles\aipo1967-0752.dct

*The sample size in the codebook - 1,585 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0752"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "October"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1967-0752.dta, replace

clear


****USAIPO1967-0753****

*Read in dictionary file for USAIPO1967-0753; October 27, 1967 - November 1, 1967)
infile using DictionaryFiles\aipo1967-0753.dct

*The sample size in the codebook - 1,648 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0753"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "October-November"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1967-0753.dta, replace

clear


****USAIPO1967-0754****

*Read in dictionary file for USAIPO1967-0754; November 16, 1967 - November 21, 1967)
infile using DictionaryFiles\aipo1967-0754.dct

*The sample size in the codebook - 1,583 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0754"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "November"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*N/A: This variable is not available in this file


*Save the data
saveold FormattedData\1967-0754.dta, replace

clear


****USAIPO1967-0755****

*Read in dictionary file for USAIPO1967-0755; December 7, 1967 - December 12, 1967); note that the usage notes on the first page of the codebook do not state that there are two records per respondent, but this is indicated elsewhere in the codebook.
infile using DictionaryFiles\aipo1967-0755.dct

*The sample size in the codebook - 1,549 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1967-0755"

*Create a variable for survey year
gen svy_yr = 1967

*Create a variable for survey month
gen svy_month = "December"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1967-0755.dta, replace

clear


****USAIPO1968-0756****

*Read in dictionary file for USAIPO1968-0756; January 4, 1968 - January 9, 1968)
infile using DictionaryFiles\aipo1968-0756.dct

*The sample size in the codebook - 1,502 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0756"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "January"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1968-0756.dta, replace

clear


****USAIPO1968-0757****

*Read in dictionary file for USAIPO1968-0757; February 1, 1968 - February 6, 1968)
infile using DictionaryFiles\aipo1968-0757.dct

*The sample size in the codebook - 1,500 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0757"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "February"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1968-0757.dta, replace

clear


****USAIPO1968-0758****

*Read in dictionary file for USAIPO1968-0758; February 22, 1968 - February 27, 1968)
infile using DictionaryFiles\aipo1968-0758.dct

*The sample size in the codebook - 1,501 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0758"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "February"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1968-0758.dta, replace

clear


****USAIPO1968-0760****

*Read in dictionary file for USAIPO1968-0760; April 4, 1968 - April 9, 1968)
infile using DictionaryFiles\aipo1968-0760.dct

*The sample size in the codebook - 1,504 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0760"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "April"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab integrationRate_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen integrationRate = integrationRate_orig

*Replace values
replace integrationRate = 2 if integrationRate_orig == 3
replace integrationRate = 3 if integrationRate_orig == 2


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1968-0760.dta, replace

clear


****USAIPO1968-0762****

*Read in dictionary file for USAIPO1968-0762; May 23, 1968 - May 28, 1968)
infile using DictionaryFiles\aipo1968-0762.dct

*The sample size in the codebook - 1,570 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0762"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "May"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1968-0762.dta, replace

clear


****USAIPO1968-0763****

*Read in dictionary file for USAIPO1968-0763; June 13, 1968 - June 18, 1968)
infile using DictionaryFiles\aipo1968-0763.dct

*The sample size in the codebook - 1,536 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0763"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "June"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1968-0763.dta, replace

clear


****USAIPO1968-0764****

*Read in dictionary file for USAIPO1968-0764; June 26, 1968 - July 1, 1968)
infile using DictionaryFiles\aipo1968-0764.dct

*The sample size in the codebook - 1,536 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0764"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "June-July"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1968-0764.dta, replace

clear


****USAIPO1968-0765****

*Read in dictionary file for USAIPO1968-0765; July 18, 1968 - July 23, 1968); note that this is a multi-form file, but since there is a single data file, the form variable is not used
infile using DictionaryFiles\aipo1968-0765.dct

*The sample size in the codebook - 1,526 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0765"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "July"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the decile age variable (VAR 82) in the codebook
*20-29 years
tab age_orig if age_orig>19 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with the frequency table in the codebook (there is no frequency distribution displayed next to the variable in the codebook)
tab wgt

*The frequencies in the tabulated variable match those in the frequency table in the back of the codebook


*Save the data
saveold FormattedData\1968-0765.dta, replace

clear


****USAIPO1968-0766****

*Read in dictionary file for USAIPO1968-0766; August 7, 1968 - August 12, 1968)
infile using DictionaryFiles\aipo1968-0766.dct

*The sample size in the codebook - 1,526 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0766"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "August"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1968-0766.dta, replace

clear


****USAIPO1968-0767****

*Read in dictionary file for USAIPO1968-0767; September 1, 1968 - September 6, 1968); note that this is a multi-form file, but since there is a single data file, the form variable is not used
infile using DictionaryFiles\aipo1968-0767.dct

*The sample size in the codebook - 1,507 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0767"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "September"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*N/A: This variable is not available in USAIPO1968-0767


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the decile age variable (VAR 86) in the codebook
*20-29 years
tab age_orig if age_orig>19 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The age decile variable does not match the tabulated variable; tab the variable to check for unexpected observations and compare the variable to frequency table in the back of the codebook to ensure that the dictionary file was read in correctly.
tab age_orig

*When we tab the variable, we find an observation that is set to 2, which is not correct, given the possible ages of Gallup respondents

*Compare the variable to frequency table in the back of the codebook to ensure that the dictionary file was read in correctly.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables and set observation to zero where it is set to two in age_orig
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig

*Replace values
replace age = . if age_orig == 2


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with the frequency table in the codebook (there is no frequency distribution displayed next to the variable in the codebook)
tab wgt

*The frequencies in the tabulated variable match those in the frequency table in the back of the codebook


*Save the data
saveold FormattedData\1968-0767.dta, replace

clear


****USAIPO1968-0768****

*Read in dictionary file for USAIPO1968-0768; September 19, 1968 - September 24, 1968)
infile using DictionaryFiles\aipo1968-0768.dct

*The sample size in the codebook - 1,504 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0768"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "September"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*N/A: This variable is not available in USAIPO1968-0768


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1968-0768.dta, replace

clear


****USAIPO1968-0769****

*Read in dictionary file for USAIPO1968-0769; September 26, 1968 - October 1, 1968); note that this is a multi-form file, but since there is a single data file, the form variable is not used
infile using DictionaryFiles\aipo1968-0769.dct

*The sample size in the codebook - 1,500 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0769"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "September-October"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab integrationRate_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen integrationRate = integrationRate_orig


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1968-0769.dta, replace

clear


****USAIPO1968-0770****

*Read in dictionary file for USAIPO1968-0770; October 17, 1968 - October 22, 1968)
infile using DictionaryFiles\aipo1968-0770.dct

*The sample size in the codebook - 1,605 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0770"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "October"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*N/A: This variable is not available in USAIPO1968-0770


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1968-0770.dta, replace

clear


****USAIPO1968-0771****

*Read in dictionary file for USAIPO1968-0771; November 9, 1968 - November 14, 1968)
infile using DictionaryFiles\aipo1968-0771.dct

*The sample size in the codebook - 1,530 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0771"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "November"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1968-0771.dta, replace

clear


****USAIPO1968-0772****

*Read in dictionary file for USAIPO1968-0772; December 5, 1968 - December 10, 1968)
infile using DictionaryFiles\aipo1968-0772.dct

*The sample size in the codebook - 1,497 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1968-0772"

*Create a variable for survey year
gen svy_yr = 1968

*Create a variable for survey month
gen svy_month = "December"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1968-0772.dta, replace

clear


****USAIPO1969-0773****

*Read in dictionary file for USAIPO1969-0773; January 1, 1969 - January 6, 1969)
infile using DictionaryFiles\aipo1969-0773.dct

*The sample size in the codebook - 1,461 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0773"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "January"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*PREFERRED PARTY FOR CONGRESSCONGRESSIONAL DISTRICT (partyCD)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER." Note that these variables are only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0693 (June 11, 1964 - June 16, 1964), USAIPO1964-0694 (June 25, 1964 - June 30, 1964), USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), and USAIPO1964-0702 (November 20, 1964 - November 25, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*APPROVAL OF CURRENT PRESIDENT (presApprovala)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1964-0699 (October 8, 1964 - October 13, 1964), USAIPO1964-0701 (November 6, 1964 - November 11, 1964), USAIPO1968-0767 (September 1, 1968 - September 6, 1968), USAIPO1968-0768 (September 19, 1968 - September 24, 1968), and USAIPO1968-0770 (October 17, 1968 - October 22, 1968).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON (goldwaterJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for ten of the thirteen (non-binary) surveys in those years: USAIPO1963-0681 (December 5, 1963 - December 10, 1963), USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964, USAIPO1964-0689 (April 24, 1964 - April 29, 1964), USAIPO1964-0693 (June 11, 1964 - June 16, 1964), and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*PRESIDENTIAL ELECTION CHOICE: ROCKEFELLER VS JOHNSON (rockefellerJohnson)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA." Note that this variable is only included for surveys conducted in 1963 and 1964 and is available for seven of the thirteen (non-binary) surveys in those years: USAIPO1963-0682 (December 12, 1963 - December 17, 1963), USAIPO1964-0683 (January 2, 1964 - January 7, 1964), USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1964-0687 (March 13, 1964 - March 17, 1964), USAIPO1964-0688 (March 27, 1964 - April 2, 1964), and USAIPO1964-0689 (April 24, 1964 - April 29, 1964).

*N/A: This variable is only included for (non-binary) LBJ-era surveys conducted in 1963 and 1964 and only if available in those years


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The age distribution table displayed in the codebook does not match the tabulated variable. As there is no frequency table in the back of the codebook, we cannot double-check the variable by identifying frequencies.

*Tab the variable to check for unexpected observations
tab age_orig

*There are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*OPINION: SPEED OF RACIAL INTEGRATION (integrationRate)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA." Note that this variable is available in fourteen surveys over the Johnson years. Nine surveys with this variable are included in this dataset: USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1965-0709 (April 2, 1965 - April 7, 1965), USAIPO1965-0713 (June 24, 1965 -June 29, 1965), USAIPO1965-0716 (August 27, 1965 - September 1, 1965), USAIPO1966-0734 (September 8, 1966 - September 13, 1966), USAIPO1966-0736 (October 21, 1966 - October 26, 1966), USAIPO1967-0748 (July 13, 1967 - July 18, 1967), USAIPO1968-0760 (April 4, 1968 - April 9, 1968), and USAIPO1968-0769 (September 26, 1968 - October 1, 1968). Four surveys with this variable were read into Stata separately as part of the racial tolerance study: USAIPO1965-0714 (July 16, 1965 - July 21, 1965), USAIPO1966-0730 (June 16, 1966 - June 21, 1966), USAIPO1967-0749 (August 3, 1967 - August 8, 1967), and USAIPO1968-0761 (May 2, 1968 - May 7, 1968). And one survey containing this variable is in a binary file and thus could not be read in: USAIPO1965-0708 (March 18, 1965 - March 23, 1965). Note that in USAIPO1967-0748 (July 13, 1967 - July 18, 1967), category 3 is given in the codebook as "JUST ABOUT RIGHT," though we allowed it to have the value label "ABOUT RIGHT" in order to minimize potential confusion; and in USAIPO1967-0749 (August 3, 1967 - August 8, 1967), category 2 is given in the codebook as "NOT ENOUGH," though we allowed it to have the value label "NOT FAST ENOUGH," also to minimize potential confusion.

*N/A: This variable is not available in this file.


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0773.dta, replace

clear


****USAIPO1969-0774****

*Read in dictionary file for USAIPO1969-0774; January 23, 1969 - January 28, 1969); note that this is a multi-form file with two data files (and two sections in the codebook). We examined both files and determined that the second one -- labeled supplementary file -- appears to be a duplicate of the first. Thus, we exclude the second file, and the form variable is not used (i.e., given that we write in only the main data file).
infile using DictionaryFiles\aipo1969-0774.dct

*The sample size in the codebook - 1,503 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0774"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "January"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0774.dta, replace

clear


****USAIPO1969-0775****

*Read in dictionary file for USAIPO1969-0775; February 20, 1969 - February 25, 1969)
infile using DictionaryFiles\aipo1969-0775.dct

*The sample size in the codebook - 1,575 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0775"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "February"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 0 if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0775.dta, replace

clear


****USAIPO1969-0777****

*Read in dictionary file for USAIPO1969-0777; March 27, 1969 - April 1, 1969)
infile using DictionaryFiles\aipo1969-0777.dct

*The sample size in the codebook - 1,502 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0777"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "March-April"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0777.dta, replace

clear


****USAIPO1969-0778****

*Read in dictionary file for USAIPO1969-0778; April 10, 1969 - April 15, 1969)
infile using DictionaryFiles\aipo1969-0778.dct

*The sample size in the codebook - 1,607 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0778"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "April"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0778.dta, replace

clear


****USAIPO1969-0779****

*Read in dictionary file for USAIPO1969-0779; May 1, 1969 - May 6, 1969)
infile using DictionaryFiles\aipo1969-0779.dct

*The sample size in the codebook - 1,481 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0779"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "May"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0779.dta, replace

clear


****USAIPO1969-0780****

*Read in dictionary file for USAIPO1969-0780; May 15, 1969 - May 20, 1969)
infile using DictionaryFiles\aipo1969-0780.dct

*The sample size in the codebook - 1,523 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0780"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "May"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0780.dta, replace

clear


****USAIPO1969-0781****

*Read in dictionary file for USAIPO1969-0781; May 22, 1969 - May 27, 1969)
infile using DictionaryFiles\aipo1969-0781.dct

*The sample size in the codebook - 1,539 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0781"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "May"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0781.dta, replace

clear


****USAIPO1969-0783****

*Read in dictionary file for USAIPO1969-0783; June 19, 1969 - June 24, 1969)
infile using DictionaryFiles\aipo1969-0783.dct

*The sample size in the codebook - 1,551 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0783"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "June"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 0 if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0783.dta, replace

clear


****USAIPO1969-0785****

*Read in dictionary file for USAIPO1969-0785; July 24, 1969 - July 29, 1969)
infile using DictionaryFiles\aipo1969-0785.dct

*The sample size in the codebook - 1,555 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0785"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "July"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0785.dta, replace

clear


****USAIPO1969-0786****

*Read in dictionary file for USAIPO1969-0786; August 14, 1969 - August 19, 1969)
infile using DictionaryFiles\aipo1969-0786.dct

*The sample size in the codebook - 1,573 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0786"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "August"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0786.dta, replace

clear


****USAIPO1969-0787****

*Read in dictionary file for USAIPO1969-0787; September 11, 1969 - September 16, 1969)
infile using DictionaryFiles\aipo1969-0787.dct

*The sample size in the codebook - 1,606 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0787"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "September"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0787.dta, replace

clear


****USAIPO1969-0788****

*Read in dictionary file for USAIPO1969-0788; September 17, 1969 - September 22, 1969)
infile using DictionaryFiles\aipo1969-0788.dct

*The sample size in the codebook - 1,560 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0788"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "September"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0788.dta, replace

clear


****USAIPO1969-0789****

*Read in dictionary file for USAIPO1969-0789; October 2, 1969 - October 7, 1969)
infile using DictionaryFiles\aipo1969-0789.dct

*The sample size in the codebook - 1,585 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0789"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "October"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0789.dta, replace

clear


****USAIPO1969-0791****

*Read in dictionary file for USAIPO1969-0791; October 17, 1969 - October 22, 1969)
infile using DictionaryFiles\aipo1969-0791.dct

*The sample size in the codebook - 1,543 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0791"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "October"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution displayed next to the variable in the codebook does not match the tabulated variable. However, the frequencies in the tabulated variable match those in the frequency table in the back of the codebook; the weight of 5, with 15 observations, which is missing in the Stata output, likely corresponds to the 15 observations in the "blank" column in the frequency table.


*Save the data
saveold FormattedData\1969-0791.dta, replace

clear


****USAIPO1969-0792****

*Read in dictionary file for USAIPO1969-0792; October 30, 1969 - November 4, 1969)
infile using DictionaryFiles\aipo1969-0792.dct

*The sample size in the codebook - 1,575 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0792"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "October-November"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0792.dta, replace

clear


****USAIPO1969-0793****

*Read in dictionary file for USAIPO1969-0793; November 12, 1969 - November 17, 1969)
infile using DictionaryFiles\aipo1969-0793.dct

*The sample size in the codebook - 1,537 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0793"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "November"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0793.dta, replace

clear


****USAIPO1969-0794****

*Read in dictionary file for USAIPO1969-0794; December 4, 1969 - December 9, 1969)
infile using DictionaryFiles\aipo1969-0794.dct

*The sample size in the codebook - 1,521 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0794"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "December"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0794.dta, replace

clear


****USAIPO1969-0795****

*Read in dictionary file for USAIPO1969-0795; December 12, 1969 - December 15, 1969)
infile using DictionaryFiles\aipo1969-0795.dct

*The sample size in the codebook - 1,557 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1969-0795"

*Create a variable for survey year
gen svy_yr = 1969

*Create a variable for survey month
gen svy_month = "December"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 0 if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1969-0795.dta, replace

clear


****USAIPO1970-0796****

*Read in dictionary file for USAIPO1970-0796; January 2, 1970 - January 5, 1970)
infile using DictionaryFiles\aipo1970-0796.dct

*The sample size in the codebook - 1,557 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0796"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "January"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0796.dta, replace

clear


****USAIPO1970-0797****

*Read in dictionary file for USAIPO1970-0797; January 15, 1970 - January 20, 1970); note that the usage notes on the first page of the codebook do not state that there are two records per respondent, but this is indicated elsewhere in the codebook.
infile using DictionaryFiles\aipo1970-0797.dct

*The sample size in the codebook - 1,573 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0797"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "January"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0797.dta, replace

clear


****USAIPO1970-0798****

*Read in dictionary file for USAIPO1970-0798; January 30, 1970 - February 2, 1970)
infile using DictionaryFiles\aipo1970-0798.dct

*The sample size in the codebook - 1,541 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0798"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "January-February"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0798.dta, replace

clear


****USAIPO1970-0800****

*Read in dictionary file for USAIPO1970-0800; February 27, 1970 - March 2, 1970)
infile using DictionaryFiles\aipo1970-0800.dct

*The sample size in the codebook - 1,530 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0800"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "February-March"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0800.dta, replace

clear


****USAIPO1970-0802****

*Read in dictionary file for USAIPO1970-0802; March 13, 1970 - March 15, 1970)
infile using DictionaryFiles\aipo1970-0802.dct

*The sample size in the codebook - 1,552 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0802"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "March"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0802.dta, replace

clear


****USAIPO1970-0803****

*Read in dictionary file for USAIPO1970-0803; April 2, 1970 - April 7, 1970)
infile using DictionaryFiles\aipo1970-0803.dct

*The sample size in the codebook - 1,551 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0803"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "April"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0803.dta, replace

clear


****USAIPO1970-0806****

*Read in dictionary file for USAIPO1970-0806; April 29, 1970 - May 3, 1970)
infile using DictionaryFiles\aipo1970-0806.dct

*The sample size in the codebook - 1,506 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0806"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "April-May"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0806.dta, replace

clear


****USAIPO1970-0807****

*Read in dictionary file for USAIPO1970-0807; May 21, 1970 - May 26, 1970)
infile using DictionaryFiles\aipo1970-0807.dct

*The sample size in the codebook - 1,509 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0807"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "May"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0807.dta, replace

clear


****USAIPO1970-0808****

*Read in dictionary file for USAIPO1970-0808; June 4, 1970 - June 9, 1970)
infile using DictionaryFiles\aipo1970-0808.dct

*The sample size in the codebook - 1,525 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0808"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "June"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0808.dta, replace

clear


****USAIPO1970-0809****

*Read in dictionary file for USAIPO1970-0809; June 18, 1970 - June 23, 1970)
infile using DictionaryFiles\aipo1970-0809.dct

*The sample size in the codebook - 1,513 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0809"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "June"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0809.dta, replace

clear


****USAIPO1970-0810****

*Read in dictionary file for USAIPO1970-0810; July 9, 1970 - July 14, 1970)
infile using DictionaryFiles\aipo1970-0810.dct

*The sample size in the codebook - 1,523 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0810"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "July"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0810.dta, replace

clear


****USAIPO1970-0811****

*Read in dictionary file for USAIPO1970-0811; July 31, 1970 - August 2, 1970)
infile using DictionaryFiles\aipo1970-0811.dct

*The sample size in the codebook - 1,500 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0811"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "July-August"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0811.dta, replace

clear


****USAIPO1970-0812****

*Read in dictionary file for USAIPO1970-0812; August 25, 1970 - September 1, 1970)
infile using DictionaryFiles\aipo1970-0812.dct

*The sample size in the codebook - 1,511 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0812"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "August-September"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0812.dta, replace

clear


****USAIPO1970-0813****

*Read in dictionary file for USAIPO1970-0813; September 11, 1970 - September 14, 1970)
infile using DictionaryFiles\aipo1970-0813.dct

*The sample size in the codebook - 1,513 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0813"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "September"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0813.dta, replace

clear


****USAIPO1970-0814****

*Read in dictionary file for USAIPO1970-0814; September 25, 1970 - September 28, 1970)
infile using DictionaryFiles\aipo1970-0814.dct

*The sample size in the codebook - 1,497 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0814"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "September"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0814.dta, replace

clear


****USAIPO1970-0815****

*Read in dictionary file for USAIPO1970-0815; October 9, 1970 - October 14, 1970)
infile using DictionaryFiles\aipo1970-0815.dct

*The sample size in the codebook - 1,507 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0815"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "October"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0815.dta, replace

clear


****USAIPO1970-0816****

*Read in dictionary file for USAIPO1970-0816; October 22, 1970 - October 25, 1970)
infile using DictionaryFiles\aipo1970-0816.dct

*The sample size in the codebook - 1,532 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0816"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "October"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0816.dta, replace

clear


****USAIPO1970-0817****

*Read in dictionary file for USAIPO1970-0817; November 13, 1970 - November 17, 1970)
infile using DictionaryFiles\aipo1970-0817.dct

*The sample size in the codebook - 1,609 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0817"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "November"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0817.dta, replace

clear


****USAIPO1970-0820****

*Read in dictionary file for USAIPO1970-0820; December 3, 1970 - December 8, 1970)
infile using DictionaryFiles\aipo1970-0820.dct

*The sample size in the codebook - 1,546 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1970-0820"

*Create a variable for survey year
gen svy_yr = 1970

*Create a variable for survey month
gen svy_month = "December"

*Begin harmonization of variables


*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if age_orig>17 & age_orig<21
*21-29 years
tab age_orig if age_orig>20 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90 years and over
tab age_orig if age_orig>=90
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA." Note that the state variable is not available for USAIPO1964-0684 (January 30, 1964 - February 5, 1964), USAIPO1964-0686 (February 28, 1964 - March 5, 1964), and USAIPO1964-0699 (October 8, 1964 - October 13, 1964) so we use region instead; a description of the relationship between state and region over time in this set of Gallup polls may be found immediately prior to where the variable is labeled. The label for region will be defined as: 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is included only in USAIPO1964-0686 (February 28, 1964 - March 5, 1964), USAIPO1966-0724 (February 10, 1966 - February 15, 1966), and USAIPO1967-0742 (March 9, 1967 - March 14, 1967) for this batch of files.

*N/A: This variable is not available in this file


*GOVERNMENT WELFARE SPENDING (welfSpend)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW." Note that this variable is available only in USAIPO1964-0702 (November 20, 1964 - November 25, 1964) for this set of polls.

*N/A: This variable is not available in this file


*MOST IMPORTANT PROBLEMCIVIL RIGHTS (mostImpProbCivRights)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO." Note that while this variable is available in multiple polls over the time period 1963-1970, we will use it only for the two polls between September 1963 and August 1964 with the highest civil rights response frequencies (in non-binary files); these polls are USAIPO1964-0689 (April 24, 1964 - April 29, 1964) and USAIPO1964-0694 (June 25, 1964 - June 30, 1964).

*N/A: This variable is not available in this file


*WEIGHT (wgt)

*Harmonization Plan: This variable (in usable form) is available in some files in 1967 -- USAIPO1967-0745 (May 11, 1967 - May 16, 1967), USAIPO1967-0747 (June 22, 1967 - June 27, 1967), and USAIPO1967-0755 (December 7, 1967 - December 12, 1967) -- and in all files dated 1968 or later. For those files in which weight is available, we check the variable to ensure that frequencies match the codebook, but no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab wgt

*The frequency distribution for this variable matches that in the codebook


*Save the data
saveold FormattedData\1970-0820.dta, replace

clear



*********************************************** 
	******Create Weights for Duplicates
*********************************************** 
clear all
/*Here's the main difficulty with this task: each .dat file has a different number of lines.
Thus, whenI import a file, I might end up with each respondent giving anywhere from 1 to 4 rows.
To get around this, I will use the already exported data to get the correct count and then
reshape the imported data using that.*/


forvalues year=1963/1967 {
	forvalues file=681/755 {
		*Skip this iteration of the loop if files don't exist
		capture import delimited ".\RawData\aipo`year'-0`file'.dat", stringcols(_all) clear
		qui count
		if r(N)==0 {
		continue
		}
		
		*Generate id and get a count
		capture use ".\FormattedData/`year'-0`file'.dta", clear
		capture drop i
		capture drop dup_weight tag_dups
		gen i=_n
		qui count
		local c=r(N)
		qui saveold ".\FormattedData/`year'-0`file'.dta", replace
	
		*Generate dup_weights and tag_dups from Raw Data
		capture import delimited ".\RawData\aipo`year'-0`file'.dat", stringcols(_all) clear
		gen length = length(v1)
		drop if length<2 //At least one file has a single character symbol in the last row
		drop length
		qui count
		local g=r(N)/`c'
		 
		egen i = seq(), f(1) b(`g')
		egen j = seq(), f(1) t(`g')
		qui reshape wide v1, i(i) j(j)
		gen svy = "`year'-0`file'"

		egen dup_groups=group(v*)
		bysort dup_group: egen dup_weight=count(dup_group)
		label var dup_weight "Number of duplicate entries in survey"
		sort i
		egen tag_dups=tag(dup_groups)
		label var tag_dups "Only 1 of the duplicates has tag==1"
		drop dup_groups v*
		tempfile temp`year'`file'
		qui save "`temp`year'`file''"
		
		*Merge
		use ".\FormattedData/`year'-0`file'.dta", clear
		qui merge 1:1 i using `temp`year'`file''
	
		*Test
		egen dup_groups=group(*_orig), missing
		egen tag_test=tag(dup_groups)
		count if tag_test==1 & tag_dups==0
		
		*Drop and save
		drop _merge tag_test dup_groups i
		qui saveold ".\FormattedData/`year'-0`file'.dta", replace
		clear
	}
}


********APPEND FILES AND FINALIZE DATASET********

use FormattedData\1963-0681.dta
append using FormattedData\1963-0682.dta
append using FormattedData\1964-0683.dta
append using FormattedData\1964-0684.dta
append using FormattedData\1964-0686.dta
append using FormattedData\1964-0687.dta
append using FormattedData\1964-0688.dta
append using FormattedData\1964-0689.dta
append using FormattedData\1964-0693.dta
append using FormattedData\1964-0694.dta
append using FormattedData\1964-0699.dta
append using FormattedData\1964-0701.dta
append using FormattedData\1964-0702.dta
append using FormattedData\1965-0704.dta
append using FormattedData\1965-0705.dta
append using FormattedData\1965-0706.dta
append using FormattedData\1965-0709.dta
append using FormattedData\1965-0711.dta
append using FormattedData\1965-0713.dta
append using FormattedData\1965-0715.dta
append using FormattedData\1965-0716.dta
append using FormattedData\1965-0717.dta
append using FormattedData\1965-0718.dta
append using FormattedData\1965-0719.dta
append using FormattedData\1965-0721.dta
append using FormattedData\1966-0722.dta
append using FormattedData\1966-0723.dta
append using FormattedData\1966-0724.dta
append using FormattedData\1966-0727.dta
append using FormattedData\1966-0731.dta
append using FormattedData\1966-0732.dta
append using FormattedData\1966-0733.dta
append using FormattedData\1966-0734.dta
append using FormattedData\1966-0735.dta
append using FormattedData\1966-0736.dta
append using FormattedData\1966-0737.dta
append using FormattedData\1966-0738.dta
append using FormattedData\1967-0739.dta
append using FormattedData\1967-0740.dta
append using FormattedData\1967-0741.dta
append using FormattedData\1967-0742.dta
append using FormattedData\1967-0743.dta
append using FormattedData\1967-0745.dta
append using FormattedData\1967-0746.dta
append using FormattedData\1967-0747.dta
append using FormattedData\1967-0748.dta
append using FormattedData\1967-0750.dta
append using FormattedData\1967-0751.dta
append using FormattedData\1967-0752.dta
append using FormattedData\1967-0753.dta
append using FormattedData\1967-0754.dta
append using FormattedData\1967-0755.dta
append using FormattedData\1968-0756.dta
append using FormattedData\1968-0757.dta
append using FormattedData\1968-0758.dta
append using FormattedData\1968-0760.dta
append using FormattedData\1968-0762.dta
append using FormattedData\1968-0763.dta
append using FormattedData\1968-0764.dta
append using FormattedData\1968-0765.dta
append using FormattedData\1968-0766.dta
append using FormattedData\1968-0767.dta
append using FormattedData\1968-0768.dta
append using FormattedData\1968-0769.dta
append using FormattedData\1968-0770.dta
append using FormattedData\1968-0771.dta
append using FormattedData\1968-0772.dta
append using FormattedData\1969-0773.dta
append using FormattedData\1969-0774.dta
append using FormattedData\1969-0775.dta
append using FormattedData\1969-0777.dta
append using FormattedData\1969-0778.dta
append using FormattedData\1969-0779.dta
append using FormattedData\1969-0780.dta
append using FormattedData\1969-0781.dta
append using FormattedData\1969-0783.dta
append using FormattedData\1969-0785.dta
append using FormattedData\1969-0786.dta
append using FormattedData\1969-0787.dta
append using FormattedData\1969-0788.dta
append using FormattedData\1969-0789.dta
append using FormattedData\1969-0791.dta
append using FormattedData\1969-0792.dta
append using FormattedData\1969-0793.dta
append using FormattedData\1969-0794.dta
append using FormattedData\1969-0795.dta
append using FormattedData\1970-0796.dta
append using FormattedData\1970-0797.dta
append using FormattedData\1970-0798.dta
append using FormattedData\1970-0800.dta
append using FormattedData\1970-0802.dta
append using FormattedData\1970-0803.dta
append using FormattedData\1970-0806.dta
append using FormattedData\1970-0807.dta
append using FormattedData\1970-0808.dta
append using FormattedData\1970-0809.dta
append using FormattedData\1970-0810.dta
append using FormattedData\1970-0811.dta
append using FormattedData\1970-0812.dta
append using FormattedData\1970-0813.dta
append using FormattedData\1970-0814.dta
append using FormattedData\1970-0815.dta
append using FormattedData\1970-0816.dta
append using FormattedData\1970-0817.dta
append using FormattedData\1970-0820.dta

*Recode those variables requiring adjustments

*Replace observations set to 0 ("NO CODE OR NO DATA") or 9 ("INAPPLICABLE") with missing values per relevant harmonization plan(s)
replace poliPartyID = . if poliPartyID == 0 | poliPartyID == 9
replace partyCD = . if partyCD == 0 | partyCD == 9
replace presApprovala = . if presApprovala == 0 | presApprovala == 9
replace goldwaterJohnson = . if goldwaterJohnson == 0 | goldwaterJohnson == 9
replace rockefellerJohnson = . if rockefellerJohnson == 0 | rockefellerJohnson == 9
replace raceSex = . if raceSex == 0 | raceSex == 9
replace age = . if age == 0 | age == 9
replace state = . if state == 0 | state == 9
replace region = . if region == 0 | region == 9
replace fedIncomeTax = . if fedIncomeTax == 0 | fedIncomeTax == 9
replace welfSpend = . if welfSpend == 0 | welfSpend == 9
replace mostImpProbCivRights = . if mostImpProbCivRights == 0 | mostImpProbCivRights == 9
replace integrationRate = . if integrationRate == 0 | integrationRate == 9

*Label variables, define values, and assign values to variables

label variable svy "SURVEY CODE"

label variable svy_yr "SURVEY YEAR"

label variable svy_month "SURVEY MONTH(S)"

label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

label variable partyCD "PREFERRED PARTY FOR CONGRESS IN CONGRESSIONAL DISTRICT"
label define lb_partyCD 1 "REPUBLICAN" 2 "DEMOCRATIC" 3 "OTHER PARTY" 4 "UNDECIDED OR REFUSED, LEANS TOWARD REPUBLICAN" 5 "UNDECIDED OR REFUSED, LEANS TOWARD DEMOCRATIC" 6 "UNDECIDED OR REFUSED, LEANS TOWARD OTHER PARTY" 7 "UNDECIDED, REFUSED, OR NO ANSWER"
label values partyCD lb_partyCD

label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApprovala 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH"
label values presApprovala lb_presApprovala

label variable goldwaterJohnson "PRESIDENTIAL ELECTION CHOICE: GOLDWATER VS JOHNSON"
label define lb_goldwaterJohnson 1 "GOLDWATER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD GOLDWATER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA"
label values goldwaterJohnson lb_goldwaterJohnson

label variable rockefellerJohnson "PRESIDENTIAL ELECTION CHOICE: ROCKEFLLER VS JOHNSON"
label define lb_rockefellerJohnson 1 "ROCKEFELLER" 2 "JOHNSON" 3 "OTHER" 4 "UNDECIDED" 5 "UNDECIDED, LEANS TOWARD ROCKEFELLER" 6 "UNDECIDED, LEANS TOWARD JOHNSON" 0 "NO CODE OR NO DATA"
label values rockefellerJohnson lb_rockefellerJohnson

label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"
label values raceSex lb_raceSex

label variable age "AGE OF THE RESPONDENT"

label variable state "STATE THE RESPONDENT LIVES IN"
label define lb_state 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"
label values state lb_state

*The relationship between state and region, as defined in the codebooks, changes somewhat over the time period for the Gallup polls in question. Outside of the South, regional definitions remain constant; both region name and states within regions are fixed. That said, beginning with USAIPO1964-0693 (June 11, 1964 - June 16, 1964), the numerical codes for the Rocky Mountain and Pacific regions increase by one over previous years (from 6 to 7 and 7 to 8, respectively), and the numerical codes for these states increase by ten (e.g., California has a state code of 71 in the second December 1963 poll and a code of 81 in the first June 1964 poll); the last codebook with the old numerical codes is USAIPO1964-0689 (April 24, 1964 - April 29, 1964). For the South, through USAIPO1964-0689, there are thirteen states in what Gallup calls the "Southern" region, with numerical codes of both 5 and 8 used for this region. Beginning with USAIPO1964-0693, the same thirteen states are split into two regions, South (region 5) and Southwest (region 6), with Arkansas, Louisiana, Oklahoma, and Texas in the latter and the other nine states in the former. (Note then that the shifts in numerical codes and definitions occurred sometime between USAIPO1964-0689 and USAIPO1964-0693 [or perhaps beginning with USAIPO1964-0693], but we cannot pinpoint the exact timing of these changes without examining the codebooks for USAIPO1964-0690 [May 6, 1964, - May 11, 1964], USAIPO1964-0691 [May 22, 1964 - May 27, 1964], and USAIPO1964-0692 [June 4, 1964 - June 9, 1964], which are binary files and thus excluded here.)
label variable region "REGION THE RESPONDENT LIVES IN"
label define lb_region 1 "NEW ENGLAND" 2 "MIDDLE ATLANTIC" 3 "EAST CENTRAL" 4 "WEST CENTRAL" 5 "SOUTH" 6 "ROCKY MOUNTAIN" 7 "PACIFIC" 8 "SOUTHWEST"
label values region lb_region

label variable fedIncomeTax "LEVEL OF PERSONAL FEDERAL INCOME TAX"
label define lb_fedIncomeTax 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION"
label values fedIncomeTax lb_fedIncomeTax

label variable welfSpend "GOVERNMENT WELFARE SPENDING"
label define lb_welfSpend 1 "TOO MUCH" 2 "ABOUT RIGHT" 3 "NOT ENOUGH" 4 "DONT KNOW"
label values welfSpend lb_welfSpend

label variable mostImpProbCivRights "RACIAL PROBS, SEGREGATION, INTEGRATION, DISCRIMINATION AS M IMP PROBLEM"
label define lb_mostImpProbCivRights 1 "YES" 2 "NO"
label values mostImpProbCivRights lb_mostImpProbCivRights

label variable integrationRate "OPINION: SPEED OF RACIAL INTEGRATION"
label define lb_integrationRate 1 "TOO FAST" 2 "NOT FAST ENOUGH" 3 "ABOUT RIGHT" 4 "DON'T KNOW/NO OPINION" 0 "NO CODE OR NO DATA"
label values integrationRate lb_integrationRate

gen educ=.
replace educ = 1 if (educ_orig == 1 | educ_orig == 2 | educ_orig == 3) //None or Grade 1-8
replace educ = 4 if (educ_orig == 4) //HS Incomplete
replace educ = 5 if (educ_orig == 5) //HS Grad
replace educ = 6 if (educ_orig == 6) //Technical, Trade or Business
replace educ = 7 if (educ_orig == 7) //College, Uni., Incomplete
replace educ = 8 if (educ_orig == 8) //College, Uni., Graduate
replace educ = 0 if (educ_orig == 0) //No Code
label variable educ "EDUCATION OF THE RESPONDENT"
label define lb_edu 1 "NONE, OR GRADES 1-8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE" 9 "POST-GRAD" 0 "NO CODE OR NO DATA"
label values educ lb_edu

*Check the data

*Count observations in the dataset
count

*Check each variable
bys svy: tab svy_yr
bys svy: tab svy_month
bys svy: tab poliPartyID
bys svy: tab partyCD
bys svy: tab presApprovala
bys svy: tab goldwaterJohnson
bys svy: tab rockefellerJohnson
bys svy: tab raceSex
bys svy: tab age
bys svy: sum age
bys svy: tab state
bys svy: tab region
bys svy: tab fedIncomeTax
bys svy: tab welfSpend
bys svy: tab mostImpProbCivRights
bys svy: tab integrationRate
bys svy: tab wgt

*Sort the data
sort svy

*Order the variables
order svy svy_yr svy_month poliPartyID poliPartyID_orig partyCD partyCD_orig presApprovala presApprovala_orig goldwaterJohnson goldwaterJohnson_orig rockefellerJohnson rockefellerJohnson_orig raceSex raceSex_orig educ educ_orig age age_orig state state_orig region region_orig fedIncomeTax fedIncomeTax_orig welfSpend welfSpend_orig mostImpProbCivRights mostImpProbCivRights_orig integrationRate integrationRate_orig wgt 

*Compress data in memory
compress

*Rename educ so that I can merge it later
rename educ eduHarmonized

*Replace dup_weight=1 if gallup did not duplicate the data
replace dup_weight=1 if svy_yr<1961 | svy_yr>1967

*Save the data
saveold PartyID_1963-1970.6.18.2016.dta, replace

log close

exit, clear
