log using PartyID_1981-2004.11.17.2014.log, replace
set more off

*Change directory so others can use the do file
cd "/Users/`c(username)'/Dropbox/southern_strategy/Gallup&GSS/PartyID_1981-2004"

*File Note: Beginning with survey aipocnus1994-422044, Hispanic is included as a response option in the race variable. Asian is included as a response option in the race variable from survey aipogns1991-222008 through survey aipocnus1994-422027, inclusive, and returns as a response option with all surveys from aipogns2000-49 forward. Native American/American Indian is included as a response option beginning with aipocnus2004-32. In this appended dataset, Hispanic, Asian, and Native American/American Indian are coded together in the "Other" category, but I note it here as a reminder that this information is available, if it becomes necessary for future work.


********VARIABLE CREATION, ADJUSTMENT, AND HARMONIZATION********
****1981 Q1: Gallup Poll # 1167G****

clear

*Read in dictionary file for USAIPO1981-1167; January 9, 1981 - January 12, 1981)
infile using DictionaryFiles\aipo1981-1167.dct

*The sample size in the codebook - 1,540 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1981-1167"

*Create a variable for survey year
gen svy_yr = 1981

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the decile age variable (VAR 94) in the codebook
*18-19 years
tab age_orig if age_orig>17 & age_orig<20
*20-29 years
tab age_orig if age_orig>19 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90-99 years
tab age_orig if age_orig>89 & age_orig<100
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19810101.dta, replace

clear


****1981 Q2: Gallup Poll # 1171G****

*Read in dictionary file for USAIPO1981-1171; April 3, 1981 - April 6, 1981)
infile using DictionaryFiles\aipo1981-1171.dct

*The sample size in the codebook - 1,545 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1981-1171"

*Create a variable for survey year
gen svy_yr = 1981

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, nor does it provide a frequency table in the back of the codebook, so we cannot double-check the variable by identifying frequencies by column and then comparing against the table.

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19810204.dta, replace

clear


****1981 Q3: Gallup Poll # 1180G****

*Read in dictionary file for USAIPO1981-1180; July 31, 1981 - August 3, 1981)
infile using DictionaryFiles\aipo1981-1180.dct

*The sample size in the codebook - 1,516 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1981-1180"

*Create a variable for survey year
gen svy_yr = 1981

*Create a variable for survey month
gen svy_month = "July-August"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the decile age variable (VAR 44) in the codebook
*18-19 years
tab age_orig if age_orig>17 & age_orig<20
*20-29 years
tab age_orig if age_orig>19 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90-99 years
tab age_orig if age_orig>89 & age_orig<100
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19810307-08.dta, replace

clear


****1981 Q4: Gallup Poll # 1183G****

*Read in dictionary file for USAIPO1981-1183; October 2, 1981 - October 5, 1981)
infile using DictionaryFiles\aipo1981-1183.dct

*The sample size in the codebook - 1,508 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1981-1183"

*Create a variable for survey year
gen svy_yr = 1981

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the decile age variable (VAR 112) in the codebook
*18-19 years
tab age_orig if age_orig>17 & age_orig<20
*20-29 years
tab age_orig if age_orig>19 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90-99 years
tab age_orig if age_orig>89 & age_orig<100
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19810410.dta, replace

clear


****1982 Q1: Gallup Poll # 1188G****

*Read in dictionary file for USAIPO1982-1188; January 8, 1982 - January 11, 1982)
infile using DictionaryFiles\aipo1982-1188.dct

*The sample size in the codebook - 1,484 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1982-1188"

*Create a variable for survey year
gen svy_yr = 1982

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the decile age variable (VAR 74) in the codebook
*18-19 years
tab age_orig if age_orig>17 & age_orig<20
*20-29 years
tab age_orig if age_orig>19 & age_orig<30
*30-39 years
tab age_orig if age_orig>29 & age_orig<40
*40-49 years
tab age_orig if age_orig>39 & age_orig<50
*50-59 years
tab age_orig if age_orig>49 & age_orig<60
*60-69 years
tab age_orig if age_orig>59 & age_orig<70
*70-79 years
tab age_orig if age_orig>69 & age_orig<80
*80-89 years
tab age_orig if age_orig>79 & age_orig<90
*90-99 years
tab age_orig if age_orig>89 & age_orig<100
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19820101.dta, replace

clear


****1982 Q2: Gallup Poll # 1192G****

*Read in dictionary file for USAIPO1982-1192; April 2, 1982 - April 5, 1982)
infile using DictionaryFiles\aipo1982-1192.dct

*The sample size in the codebook - 1,543 - does not match the number of observations read into Stata (1,523). However, the frequencies displayed next to variables poliPartyID, raceSex, and state in the codebook sum to total question N's of 1,523 each, as in the Stata output, which suggests that the sample size displayed on the front of the codebook may be incorrect. Note that frequencies not provided in the codebook for age and wgt, so I couldn't confirm total N for each of those variables.

*Create a variable for survey code
gen svy = "1982-1192"

*Create a variable for survey year
gen svy_yr = 1982

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, nor does it provide a frequency table in the back of the codebook, so we cannot double-check the variable by identifying frequencies by column and then comparing against the table.

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19820204.dta, replace

clear


****1982 Q3: Gallup Poll # 1198G****

*Read in data file for USAIPO1982-1192; July 23, 1982 - July 26, 1982)
use RawData\aipo1982-1198.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,518 - matches the number of observations read into Stata

*Keep the relevant variables
keep Q902 Q916 Q914 state weight Q913

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Rename and label the variables

*Education
rename Q913 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename Q902 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE AND GENDER OF THE RESPONDENT (raceSex)
rename Q916 raceSex_orig
label variable raceSex_orig "ORIGINAL RACE AND GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename Q914 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename weight wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "1982-1198"

*Create a variable for survey year
gen svy_yr = 1982

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, nor does it provide a frequency table in the back of the codebook, so we cannot double-check the variable by identifying frequencies by column and then comparing against the table.

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 75 if state_orig == 84
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19820307.dta, replace

clear


****1982 Q4: Gallup Poll # 1982-1203G: Ronald Reagan/Government/Presidential Election****

*Read in dictionary file for USAIPO1982-1203; October 15, 1982 - October 18, 1982)
infile using DictionaryFiles\aipo1982-1203.dct

*The sample size in the codebook - 1,543 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1982-1203"

*Create a variable for survey year
gen svy_yr = 1982

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19820410.dta, replace

clear


****1983 Q2: Gallup Poll # 212G****

*Read in dictionary file for USAIPO1983-1212; April 15, 1983 - April 18, 1983)
infile using DictionaryFiles\aipo1983-1212.dct

*The sample size in the codebook - 1,509 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1983-1212"

*Create a variable for survey year
gen svy_yr = 1983

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, nor does it provide a frequency table in the back of the codebook, so we cannot double-check the variable by identifying frequencies by column and then comparing against the table.

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19830204.dta, replace

clear


****1983 Q3: Gallup Poll # 1218G****

*Read in dictionary file for USAIPO1983-1218; July 22-25, 1983)
infile using DictionaryFiles\aipo1983-1218.dct

*The sample size in the codebook - 1,567 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1983-1218"

*Create a variable for survey year
gen svy_yr = 1983

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, nor does it provide a frequency table in the back of the codebook, so we cannot double-check the variable by identifying frequencies by column and then comparing against the table.

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19830307.dta, replace

clear


****1983 Q4: Gallup Poll # 1225G****

*Read in dictionary file for USAIPO1983-1225; October 7, 1983 - October 10, 1983)
infile using DictionaryFiles\aipo1983-1225.dct

*The sample size in the codebook - 1,503 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1983-1225"

*Create a variable for survey year
gen svy_yr = 1983

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (VAR 110) in the codebook
*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19830410.dta, replace

clear


****1984 Q1: Gallup Poll # 1229G****

*Read in dictionary file for USAIPO1984-1229; January 13, 1984 - January 16, 1984)
infile using DictionaryFiles\aipo1984-1229.dct

*The sample size in the codebook - 1,545 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1984-1229"

*Create a variable for survey year
gen svy_yr = 1984

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age group variable (VAR 67) in the codebook
*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19840101.dta, replace

clear


****1984 Q2: Gallup Poll # 1233G****

*Read in dictionary file for USAIPO1984-1233; April 3, 1984 - April 6, 1984)
infile using DictionaryFiles\aipo1984-1233.dct

*The sample size in the codebook - 1,531 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1984-1233"

*Create a variable for survey year
gen svy_yr = 1984

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (VAR 82) in the codebook
*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19840204.dta, replace

clear


****1984 Q4: Gallup Poll # 1244G****

*Read in dictionary file for USAIPO1984-1244; October 26, 1984 - October 29, 1984)
infile using DictionaryFiles\aipo1984-1244.dct

*The sample size in the codebook - 1,520 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1984-1244"

*Create a variable for survey year
gen svy_yr = 1984

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (VAR 59) in the codebook
*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19840410.dta, replace

clear


****1985 Q1: Gallup Poll # 1249G****

*Read in dictionary file for USAIPO1985-1249; January 25, 1985 - January 28, 1985)
infile using DictionaryFiles\aipo1985-1249.dct

*The sample size in the codebook - 1,528 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1985-1249"

*Create a variable for survey year
gen svy_yr = 1985

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (VAR 53) in the codebook
*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19850101.dta, replace

clear


****1985 Q2: Gallup Poll # 1252G****

*Read in dictionary file for USAIPO1985-1252; April 12, 1985 - April 15, 1985)
infile using DictionaryFiles\aipo1985-1252.dct

*The sample size shown on the front page of the codebook - 1,525 - does not match the number of observations read into Stata (1,523). However, the sample size indicated on page 2 of the codebook (i.e., 2 of 32 in the PDF) matches the number of observations read into Stata.

*Create a variable for survey code
gen svy = "1985-1252"

*Create a variable for survey year
gen svy_yr = 1985

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (VAR 86) in the codebook
*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19850204.dta, replace

clear


****1985 Q3: Gallup Poll # 1255G****

*Read in dictionary file for USAIPO1985-1255; July 12, 1985 - July 15, 1985)
infile using DictionaryFiles\aipo1985-1255.dct

*The sample size in the codebook - 1,536 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1985-1255"

*Create a variable for survey year
gen svy_yr = 1985

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (VAR 117) in the codebook
*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19850307.dta, replace

clear


****1985 Q4: Gallup Poll # 1258G****

*Read in dictionary file for USAIPO1985-1258; October 11, 1985 - October 14, 1985)
infile using DictionaryFiles\aipo1985-1258.dct

*The sample size in the codebook - 1,540 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1985-1258"

*Create a variable for survey year
gen svy_yr = 1985

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (VAR 77) in the codebook
*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19850410.dta, replace

clear


****1986 Q1: Gallup Poll # 1261G****

*Read in dictionary file for USAIPO1986-1261; January 10, 1986 - January 13, 1986)
infile using DictionaryFiles\aipo1986-1261.dct

*The sample size shown on the front page of the codebook - 1,570 - does not match the number of observations read into Stata (1,569). However, the sample size indicated on page 2 of the codebook (i.e., 2 of 48 in the PDF) matches the number of observations read into Stata.

*Create a variable for survey code
gen svy = "1986-1261"

*Create a variable for survey year
gen svy_yr = 1986

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (VAR 146) in the codebook
*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19860101.dta, replace

clear


****1986 Q2: Gallup Poll # 1262G****

*Read in dictionary file for USAIPO1986-1262; April 11, 1986 - April 14, 1986)
infile using DictionaryFiles\aipo1986-1262.dct

*The sample size in the codebook - 1,552 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1986-1262"

*Create a variable for survey year
gen svy_yr = 1986

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (VAR 137) in the codebook
*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19860204.dta, replace

clear


****1986 Q3: Gallup Poll # 1266G****

*Read in dictionary file for USAIPO1986-1266; July 11, 1986 - July 14, 1986)
infile using DictionaryFiles\aipo1986-1266.dct

*The sample size in the codebook - 1,539 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1986-1266"

*Create a variable for survey year
gen svy_yr = 1986

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (VAR 162) in the codebook
*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19860307.dta, replace

clear


****1986 Q4: Gallup Poll # 1269G****

*Read in dictionary file for USAIPO1986-1269; October 24, 1986 - October 27, 1986)
infile using DictionaryFiles\aipo1986-1269.dct

*The sample size in the codebook - 1,559 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1986-1269"

*Create a variable for survey year
gen svy_yr = 1986

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (VAR 125) in the codebook
*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19860410.dta, replace

clear


****1987 Q1: Gallup Poll # 1987-1272G: Reagan/1988 Presidential Election/Political Party/Finances/Federal Spending****

*Read in dictionary file for USAIPO1987-1272; January 16, 1987 - January 19, 1987)
infile using DictionaryFiles\aipo1987-1272.dct

*The sample size in the codebook - 1,562 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1987-1272"

*Create a variable for survey year
gen svy_yr = 1987

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (VAR 119) in the codebook
*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19870101.dta, replace

clear


****1987 Q2: Gallup Poll: Presidential Election/Religion (#1247G)****

*Read in data file for USAIPO1987-1274; April 10, 1987 - April 13, 1987); note that this is a multi-form file, but since there is a single data file, the form variable is not used
use RawData\aipo1987-1274.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,571 - matches the number of observations read into Stata

*Keep the relevant variables
keep VAR137 VAR161 VAR157 VAR170 VAR02 VAR156

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*The variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each (but weight) against the codebook

*Rename and label the variables

*Education
rename VAR156 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename VAR137 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE AND GENDER OF THE RESPONDENT (raceSex)
rename VAR161 raceSex_orig
label variable raceSex_orig "ORIGINAL RACE AND GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename VAR157 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename VAR170 state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename VAR02 wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "1987-1274"

*Create a variable for survey year
gen svy_yr = 1987

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (VAR 158) in the codebook
*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19870204.dta, replace

clear


****1987 Q4: Gallup Poll/Newsweek Poll # 1987-87330: Post-Summit****

*Read in dictionary file for USAIPOSPGONEW1987-87330; December 11, 1987)
infile using DictionaryFiles\aipospgonew1987-87330.dct

*The sample size in the codebook - 507 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1987-87330"

*Create a variable for survey year
gen svy_yr = 1987

*Create a variable for survey month
gen svy_month = "December"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19870412.dta, replace

clear


****1988 Q1: Gallup Poll/Newsweek Poll: Jackson/Trial Heats (1988-88173)****

*Read in data file for USAIPOSPGONEW1988-88173; March 30, 1988 - March 31, 1988)
use RawData\aipospgonew1988-88173.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,004 - matches the number of observations read into Stata

*Keep the relevant variables
keep Q14 Q21 Q23 Q20 state weight Q18

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Rename and label the variables

*Education
rename Q18 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename Q14 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename Q21 race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename Q23 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename Q20 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename weight wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "1988-88173"

*Create a variable for survey year
gen svy_yr = 1988

*Create a variable for survey month
gen svy_month = "March"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19880103.dta, replace

clear


****1988 Q3: Gallup Poll # 1988-874: Government/Alcohol/Tobacco****

*Read in dictionary file for USAIPOSPAI1988-874; July 1, 1988 - July 7, 1988)
infile using DictionaryFiles\aipospai1988-874.dct

*The sample size in the codebook - 1,000 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1988-874"

*Create a variable for survey year
gen svy_yr = 1988

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19880307.dta, replace

clear


****1989 Q1: Gallup Poll # 1989-877: Government/Budget****

*Read in dictionary file for USAIPOSPAI1989-877; January 24, 1989 - January 28, 1989)
infile using DictionaryFiles\aipospai1989-877.dct

*The sample size in the codebook - 1,001 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1989-877"

*Create a variable for survey year
gen svy_yr = 1989

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19890101.dta, replace

clear


****1989 Q2: Newsweek Poll # 1989-89173: Ethics****

*Read in data file for USAIPOSPGONEW1989-89173; June 1, 1989 - June 2, 1989); note that this is a multi-form file, but since there is a single data file, the form variable is not used
use RawData\aipospgonew1989-89173.dta

*Count observations in the dataset
count

*The sample size in the codebook - 750 - matches the number of observations read into Stata

*Keep the relevant variables
keep Q13 Q16 Q18 Q15 state weight Q14

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*The variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each (but weight) against the codebook

*The description shows that each variable -- with the exception of weight -- is stored as a string; convert all, as necessary, to numeric
destring Q13, replace
destring Q16, replace
destring Q18, replace
destring Q15, replace
destring Q14, replace
destring state, replace

*Rename and label the variables

*Education
rename Q14 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename Q13 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename Q16 race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename Q18 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename Q15 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename weight wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "1989-89173"

*Create a variable for survey year
gen svy_yr = 1989

*Create a variable for survey month
gen svy_month = "June"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19890206.dta, replace

clear


****1989 Q3: Gallup News Service Survey: August, 1989 (1989-89137-w1)****

*Read in dictionary file for USAIPOGNS1989-89137-w1; August 10, 1989 - August 13, 1989)
infile using DictionaryFiles\aipogns1989-89137-w1.dct

*The sample size in the codebook - 1,250 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1989-89137-w1"

*Create a variable for survey year
gen svy_yr = 1989

*Create a variable for survey month
gen svy_month = "August"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we check the variable by obtaining its frequencies directly from the Roper site.
tab poliPartyID_orig

*The frequencies displayed on the Roper site -- 32% Republican, 32% Democrat, 32% Independent, 1% Other, 3% Don't Know -- are close to those in the dataset but do not match exactly; the frequencies of the response options in the dataset are: 34% Republican, 31% Democrat, 31% Independent, 2% Other, 3% Don't Know. (Note, too, that the percentages change after appending, i.e., once we set "Don't Know" to missing, but since Roper used "Don't Know" in its total question N, we use the original variable in comparison with the Roper site.)

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check race - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check sex - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab sex_orig

*There are no unexpected response options/observations

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (which is included in the dictionary file -- where available -- only if there are no other means to check the variable, such as a frequency table)
tab age_sum

*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook; drop the age_sum variable -- it is no longer necessary
drop age_sum

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19890308.dta, replace

clear


****1989 Q4: Gallup News Service Survey # 1989-89139-W1: Abortion/Gun Laws****

*Read in dictionary file for USAIPOGNS1989-89139-w1; October 5, 1989 - October 8, 1989)
infile using DictionaryFiles\aipogns1989-89139-w1.dct

*The sample size in the codebook - 1,234 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1989-89139-w1"

*Create a variable for survey year
gen svy_yr = 1989

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19890410.dta, replace

clear


****1990 Q1: Gallup News Service Survey# 1990-922001-W1: National Defense/Illegal Drugs****

*Read in dictionary file for USAIPOGNS1990-922001-w1; January 4, 1990 - January 7, 1990)
infile using DictionaryFiles\aipogns1990-922001-w1.dct

*The sample size in the codebook - 1,226 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1990-922001-w1"

*Create a variable for survey year
gen svy_yr = 1990

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19900101.dta, replace

clear


****1990 Q2: Gallup/Newsweek Poll # 1990-125006: Flag Burning/Obscenity****

*Read in dictionary file for USAIPOSPGONEW1990-125006; June 13, 1990 - June 14, 1990)
infile using DictionaryFiles\aipospgonew1990-125006.dct

*The sample size in the codebook - 604 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1990-125006"

*Create a variable for survey year
gen svy_yr = 1990

*Create a variable for survey month
gen svy_month = "June"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID_orig == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = . if race_orig == 4 | race_orig == 5

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19900206.dta, replace

clear


****1990 Q3: Gallup News Service Survey: Iraqi Invasion of Kuwait****

*Read in dictionary file for USAIPOGNS1990-122002; August 3, 1990 - August 4, 1990)
infile using DictionaryFiles\aipogns1990-122002.dct

*The sample size in the codebook - 810 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1990-122002"

*Create a variable for survey year
gen svy_yr = 1990

*Create a variable for survey month
gen svy_month = "August"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID_orig == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook, though note that the response options for the variable itself show "Don't Know" in 4, rather than 5, as in the frequency table and the data itself

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = . if race_orig == 5

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19900308.dta, replace

clear


****1990 Q4: Gallup News Service Survey: U.S. Troops in the Middle East/Dying and Life After Death****

*Read in dictionary file for USAIPOGNS1990-122008; November 15, 1990 - November 18, 1990)
infile using DictionaryFiles\aipogns1990-122008.dct

*The sample size in the codebook - 1,018 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1990-122008"

*Create a variable for survey year
gen svy_yr = 1990

*Create a variable for survey month
gen svy_month = "November"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID_orig == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = . if race_orig == 4 | race_orig == 5

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19900411.dta, replace

clear


****1991 Q1: Gallup News Service Survey: February Omnibus, Wave 2****

*Read in dictionary file for USAIPOGNS1991-122016; February 7, 1991 - February 10, 1991)
infile using DictionaryFiles\aipogns1991-122016.dct

*The sample size in the codebook - 1,013 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1991-122016"

*Create a variable for survey year
gen svy_yr = 1991

*Create a variable for survey month
gen svy_month = "February"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we check the variable by obtaining its frequencies directly from the Roper site.
tab poliPartyID_orig

*The frequencies displayed on the Roper site -- 32% Republican, 31% Democrat, 32% Independent, 2% Other, 4% Don't Know/Refused -- are close to those in the dataset but do not match exactly; the frequencies of the response options in the dataset are: 33% Republican, 30% Democrat, 31% Independent, 2% Other, 4% Don't Know/Refused. (Note, too, that the percentages change after appending, i.e., once we set "Don't Know" to missing, but since Roper used "Don't Know" in its total question N, we use the original variable in comparison with the Roper site.)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID_orig == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check race - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = . if race_orig == 4 | race_orig == 5

*Check sex - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab sex_orig

*There are no unexpected response options/observations

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (which is included in the dictionary file -- where available -- only if there are no other means to check the variable, such as a frequency table)
tab age_sum

*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook; drop the age_sum variable -- it is no longer necessary
drop age_sum

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19910102.dta, replace

clear


****1991 Q2: Gallup News Service Survey # 1991-122025: Environment/Property Values****

*Read in dictionary file for USAIPOGNS1991-122025; April 11, 1991 - April 14, 1991)
infile using DictionaryFiles\aipogns1991-122025.dct

*The sample size in the codebook - 1,007 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1991-122025"

*Create a variable for survey year
gen svy_yr = 1991

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID_orig == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = . if race_orig == 4 | race_orig == 5

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19910204.dta, replace

clear


****1991 Q3: Gallup News Service Survey # 1991-222008: Work and Family****

*Read in dictionary file for USAIPOGNS1991-222008; July 25, 1991 - July 28, 1991)
infile using DictionaryFiles\aipogns1991-222008.dct

*The sample size in the codebook - 1,215 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1991-222008"

*Create a variable for survey year
gen svy_yr = 1991

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 3 if race_orig == 4
replace race = . if race_orig == 5 | race_orig == 6

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19910307.dta, replace

clear


****1991 Q4: Gallup News Service Survey: October Omnibus, Wave 2****

*Read in dictionary file for USAIPOGNS1991-222019; October 10, 1991 - October 13, 1991)
infile using DictionaryFiles\aipogns1991-222019.dct

*The sample size in the codebook - 1,000 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1991-222019"

*Create a variable for survey year
gen svy_yr = 1991

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 3 if race_orig == 4
replace race = . if race_orig == 5 | race_orig == 6

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19910410.dta, replace

clear


****1992 Q1: Gallup News Service Survey # 1992-222035: Politics/Abortion/Alcohol/SuperBowl****

*Read in dictionary file for USAIPOGNS1992-222035; January 16, 1992 - January 19, 1992)
infile using DictionaryFiles\aipogns1992-222035.dct

*The sample size in the codebook - 1,001 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1992-222035"

*Create a variable for survey year
gen svy_yr = 1992

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 3 if race_orig == 4
replace race = . if race_orig == 5 | race_orig == 6

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19920101.dta, replace

clear


****1992 Q2: Gallup News Service Poll # 1992-222049: Presidential Election/Former Soviet Union/Population Growth/Religion****

*Read in dictionary file for USAIPOGNS1992-222049; April 9, 1992 - April 12, 1992)
infile using DictionaryFiles\aipogns1992-222049.dct

*The sample size in the codebook - 1,002 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1992-222049"

*Create a variable for survey year
gen svy_yr = 1992

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 3 if race_orig == 4
replace race = . if race_orig == 5 | race_orig == 6

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19920204.dta, replace

clear


****1992 Q3: Gallup News Service Survey: July, 1992 - Wave 1****

*Read in dictionary file for USAIPOGNS1992-322010; July 24, 1992 - July 26, 1992)
infile using DictionaryFiles\aipogns1992-322010.dct

*The sample size in the codebook - 1,000 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1992-322010"

*Create a variable for survey year
gen svy_yr = 1992

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we check the variable by obtaining its frequencies directly from the Roper site.
tab poliPartyID_orig

*The frequencies displayed on the Roper site -- 27% Republican, 35% Democrat, 34% Independent, 1% Other, 4% Don't Know/Refused -- are close to those in the dataset but do not match exactly; the frequencies of the response options in the dataset are: 28% Republican, 34% Democrat, 34% Independent, 0.4% Other, 3% Don't Know/Refused. (Note, too, that the percentages change after appending, i.e., once we set "Don't Know" to missing, but since Roper used "Don't Know" in its total question N, we use the original variable in comparison with the Roper site.)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check race - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 3 if race_orig == 4
replace race = . if race_orig == 5 | race_orig == 6

*Check sex - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab sex_orig

*There are no unexpected response options/observations

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (which is included in the dictionary file -- where available -- only if there are no other means to check the variable, such as a frequency table)
tab age_sum

*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook; drop the age_sum variable -- it is no longer necessary
drop age_sum

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19920307.dta, replace

clear


****1992 Q4: Post Election Survey****

*Read in dictionary file for USAIPOGNS1992-322032; November 10, 1992 - November 11, 1992)
infile using DictionaryFiles\aipogns1992-322032.dct

*The sample size in the codebook - 1,004 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1992-322032"

*Create a variable for survey year
gen svy_yr = 1992

*Create a variable for survey month
gen svy_month = "November"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 3 if race_orig == 4
replace race = . if race_orig == 5 | race_orig == 6

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19920411.dta, replace

clear


****1993 Q1: Gallup/CNN/USA Today Poll: Bush Review/The State of the Nation****

*Read in dictionary file for USAIPOCNUS1993-322039; January 8, 1993 - January 11, 1993)
infile using DictionaryFiles\aipocnus1993-322039.dct

*The sample size in the codebook - 1,000 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1993-322039"

*Create a variable for survey year
gen svy_yr = 1993

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 3 if race_orig == 4
replace race = . if race_orig == 5 | race_orig == 6

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19930101.dta, replace

clear


****1993 Q2: Gallup/CNN/USA Today Poll: Clinton's First 100 Days****

*Read in dictionary file for USAIPOCNUS1993-322054; April 22, 1993 - April 24, 1993)
infile using DictionaryFiles\aipocnus1993-322054.dct

*The sample size in the codebook - 1,005 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1993-322054"

*Create a variable for survey year
gen svy_yr = 1993

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 3 if race_orig == 4
replace race = . if race_orig == 5 | race_orig == 6

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19930204.dta, replace

clear


****1993 Q3: Gallup/CNN/USA Today Poll: July Wave 1****

*Read in dictionary file for USAIPOCNUS1993-422003; July 19, 1993 - July 21, 1993)
infile using DictionaryFiles\aipocnus1993-422003.dct

*The sample size in the codebook - 1,011 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1993-422003"

*Create a variable for survey year
gen svy_yr = 1993

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we check the variable by obtaining its frequencies directly from the Roper site.
tab poliPartyID_orig

*The frequencies displayed on the Roper site -- 30% Republican, 33% Democrat, 34% Independent, 1% Other, 3% Don't Know/Refused -- are close to those in the dataset but do not match exactly; the frequencies of the response options in the dataset are: 30% Republican, 32% Democrat, 35% Independent, 1% Other, 3% Don't Know/Refused. (Note, too, that the percentages change after appending, i.e., once we set "Don't Know" to missing, but since Roper used "Don't Know" in its total question N, we use the original variable in comparison with the Roper site.)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check race - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 3 if race_orig == 4
replace race = . if race_orig == 5 | race_orig == 6

*Check sex - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab sex_orig

*There are no unexpected response options/observations

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (which is included in the dictionary file -- where available -- only if there are no other means to check the variable, such as a frequency table)
tab age_sum

*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook; drop the age_sum variable -- it is no longer necessary
drop age_sum

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19930307.dta, replace

clear


****1993 Q4: Gallup/CNN/USA Today Poll: October Wave 1****

*Read in dictionary file for USAIPOCNUS1993-422017A; October 8, 1993 - October 10, 1993)
infile using DictionaryFiles\aipocnus1993-422017A.dct

*The sample size in the codebook - 1,019 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1993-422017A"

*Create a variable for survey year
gen svy_yr = 1993

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 3 if race_orig == 4
replace race = . if race_orig == 5 | race_orig == 6

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19930410.dta, replace

clear


****1994 Q1: Gallup/CNN/USA Today Poll: January, 1994, Wave I****

*Read in dictionary file for USAIPOCNUS1994-422027; January 6, 1994 - January 8, 1994)
infile using DictionaryFiles\aipocnus1994-422027.dct

*The sample size in the codebook - 1,023 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1994-422027"

*Create a variable for survey year
gen svy_yr = 1994

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 3 if race_orig == 4
replace race = . if race_orig == 5 | race_orig == 6

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19940101.dta, replace

clear


****1994 Q2: Gallup/CNN/USA Today Poll: April Wave I****

*Read in dictionary file for USAIPOCNUS1994-422044; April 16, 1994 - April 18, 1994)
infile using DictionaryFiles\aipocnus1994-422044.dct

*The sample size in the codebook - 1,002 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1994-422044"

*Create a variable for survey year
gen svy_yr = 1994

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19940204.dta, replace

clear


****1994 Q3: Gallup/CNN/USA Today Poll: Clinton Report Card #6****

*Read in dictionary file for USAIPOCNUS1994-00807016; July 15, 1994 - July 17, 1994)
infile using DictionaryFiles\aipocnus1994-00807016.dct

*The sample size in the codebook - 1,001 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1994-00807016"

*Create a variable for survey year
gen svy_yr = 1994

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19940307.dta, replace

clear


****1994 Q4: Gallup/CNN/USA Today Poll: October Wave I****

*Read in dictionary file for USAIPOCNUS1994-00807028; October 22, 1994 - October 25, 1994)
infile using DictionaryFiles\aipocnus1994-00807028.dct

*The sample size in the codebook - 1,007 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1994-00807028"

*Create a variable for survey year
gen svy_yr = 1994

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19940410.dta, replace

clear


****1995 Q1: Gallup/CNN/USA Today Poll: January Wave I****

*Read in dictionary file for USAIPOCNUS1995-5001007; January 16, 1995 - January 18, 1995)
infile using DictionaryFiles\aipocnus1995-5001007.dct

*The sample size in the codebook - 1,002 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1995-5001007"

*Create a variable for survey year
gen svy_yr = 1995

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19950101.dta, replace

clear


****1995 Q2: Gallup/CNN/USA Today Poll: April Wave I****

*Read in dictionary file for USAIPOCNUS1995-5001017; April 17, 1995 - April 19, 1995)
infile using DictionaryFiles\aipocnus1995-5001017.dct

*The sample size in the codebook - 1,007 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1995-5001017"

*Create a variable for survey year
gen svy_yr = 1995

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19950204.dta, replace

clear


****1995 Q3: Gallup/CNN/USA Today Poll: News Media****

*Read in dictionary file for USAIPOCNUS1995-9508009; August 11, 1995 - August 14, 1995)
*Note that there is an observation in the party variable that contains an odd character (an asterisk). Since no other variable has this problem, and it is limited to the one observation, we do not necessarily assume this is a binary file that requires exclusion. Rather, to address the issue, we read in the party variable in the dictionary file as a string, and in the harmonization section below, we set the observation to missing and then convert the variable to numeric.
infile using DictionaryFiles\aipocnus1995-9508009.dct

*The sample size in the codebook - 1,006 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1995-9508009"

*Create a variable for survey year
gen svy_yr = 1995

*Create a variable for survey month
gen svy_month = "August"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Prior to checking the variable, we address the observation with the odd character by setting the observation to missing and then converting the variable to numeric

*Set observations with odd characters to missing
replace poliPartyID_orig = "" if poliPartyID_orig == "*"

*Convert the variable to numeric
destring poliPartyID_orig, replace

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook (note that the frequency table shows that there is an "Other" observation in the party variable, which likely refers to the asterisk)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19950308.dta, replace

clear


****1995 Q4: Gallup/CNN/USA Today Poll: 1996 Election / Republican Proposals****

*Read in dictionary file for USAIPOCNUS1995-9510018; November 6, 1995 - November 8, 1995)
infile using DictionaryFiles\aipocnus1995-9510018.dct

*The sample size in the codebook - 931 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1995-9510018"

*Create a variable for survey year
gen svy_yr = 1995

*Create a variable for survey month
gen svy_month = "November"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19950411.dta, replace

clear


****1996 Q1: Gallup/CNN/USA Today Poll: 1996 Election/Budget Impasse****

*Read in dictionary file for USAIPOCNUS1996-9601001; January 5, 1996 - January 7, 1996)
infile using DictionaryFiles\aipocnus1996-9601001.dct

*The sample size in the codebook - 1,000 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1996-9601001"

*Create a variable for survey year
gen svy_yr = 1996

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19960101.dta, replace

clear


****1996 Q2: Gallup/CNN/USA Today Poll: Congress / 1996 Election****

*Read in dictionary file for USAIPOCNUS1996-9604009; April 9, 1996 - April 10, 1996)
infile using DictionaryFiles\aipocnus1996-9604009.dct

*The sample size in the codebook - 1,010 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1996-9604009"

*Create a variable for survey year
gen svy_yr = 1996

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19960204.dta, replace

clear


****1996 Q3: Gallup/CNN/USA Today: 1996 Election****

*Read in dictionary file for USAIPOCNUS1996-9607018; July 18, 1996 - July 21, 1996)
infile using DictionaryFiles\aipocnus1996-9607018.dct

*The sample size in the codebook - 1,010 - matches the number of observations read into Stata. However, note that the total N for each variable as shown in the frequency table is 885 (or less). Thus, we will not use the frequency table to check variables.

*Create a variable for survey code
gen svy = "1996-9607018"

*Create a variable for survey year
gen svy_yr = 1996

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and the latter appears incorrect, so we check the variable by obtaining its frequencies directly from the Roper site.
tab poliPartyID_orig

*The frequencies displayed on the Roper site -- 32% Republican, 35% Democrat, 29% Independent, 0% Other, 3% Don't Know/Refused -- are close to those in the dataset but do not match exactly; the frequencies of the response options in the dataset are: 33% Republican, 35% Democrat, 28% Independent, 5% Other, 3% Don't Know/Refused. (Note, too, that the percentages change after appending, i.e., once we set "Don't Know" to missing, but since Roper used "Don't Know" in its total question N, we use the original variable in comparison with the Roper site.)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check race - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and the latter appears incorrect, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check sex - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and the latter appears incorrect, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab sex_orig

*There are no unexpected response options/observations

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary variable (which is included in the dictionary file -- where available -- only if there are no other means to check the variable, such as a frequency table)
tab age_sum

*18-24 years
tab age_orig if age_orig>17 & age_orig<25
*25-34 years
tab age_orig if age_orig>24 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55
*NO CODE OR NO DATA
tab age_orig if age_orig == 0

*The frequency distribution for this variable matches that in the codebook; drop the age_sum variable -- it is no longer necessary
drop age_sum

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and the latter appears incorrect, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19960307.dta, replace

clear


****1996 Q4: Gallup News Service Poll: Clinton/Presidential Campaigns/Military****

*Read in dictionary file for USAIPOGNS1996-9611036; November 21, 1996 - November 24, 1996)
infile using DictionaryFiles\aipogns1996-9611036.dct

*The sample size in the codebook - 1,003 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1996-9611036"

*Create a variable for survey year
gen svy_yr = 1996

*Create a variable for survey month
gen svy_month = "November"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19960411.dta, replace

clear


****1997 Q1: Gallup/CNN/USA Today Poll: Newt Gingrich/Euthanasia****

*Read in dictionary file for USAIPOCNUS1997-9701001; January 3, 1997 - January 5, 1997)
infile using DictionaryFiles\aipocnus1997-9701001.dct

*The sample size in the codebook - 1,022 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1997-9701001"

*Create a variable for survey year
gen svy_yr = 1997

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19970101.dta, replace

clear


****1997 Q2: Gallup/CNN/USA Today Poll: Political Issues****

*Read in dictionary file for USAIPOCNUS1997-9704008; April 11, 1997 - April 13, 1997)
infile using DictionaryFiles\aipocnus1997-9704008.dct

*The sample size in the codebook - 1,003 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1997-9704008"

*Create a variable for survey year
gen svy_yr = 1997

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19970204.dta, replace

clear


****1997 Q3: Gallup/CNN/USA Today Poll # 1997-9707017: Confidence in Institutes/Stock Market****

*Read in dictionary file for USAIPOCNUS1997-9707017; July 25, 1997 - July 27, 1997)
infile using DictionaryFiles\aipocnus1997-9707017.dct

*The sample size in the codebook - 1,004 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1997-9707017"

*Create a variable for survey year
gen svy_yr = 1997

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19970307.dta, replace

clear


****1997 Q4: Gallup/CNN/USA Today Poll: Politics/Parties****

*Read in dictionary file for USAIPOCNUS1997-9710026; October 27, 1997 - October 29, 1997)
infile using DictionaryFiles\aipocnus1997-9710026.dct

*The sample size in the codebook - 1,008 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1997-9710026"

*Create a variable for survey year
gen svy_yr = 1997

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19970410.dta, replace

clear


****1998 Q1: Gallup/CNN/USA Today Poll #9801001: Budget Deficit****

*Read in dictionary file for USAIPOCNUS1998-9801001; January 6, 1998 - January 7, 1998)
infile using DictionaryFiles\aipocnus1998-9801001.dct

*The sample size in the codebook - 1,015 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1998-9801001"

*Create a variable for survey year
gen svy_yr = 1998

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we check the variable by obtaining its frequencies directly from the Roper site.
tab poliPartyID_orig

*The frequencies displayed on the Roper site -- 31% Republican, 31% Democrat, 33% Independent, 1% Other, 5% Don't Know/Refused -- are close to those in the dataset but do not match exactly; the frequencies of the response options in the dataset are: 31% Republican, 30% Democrat, 34% Independent, 1% Other, 4% Don't Know/Refused. (Note, too, that the percentages change after appending, i.e., once we set "Don't Know" to missing, but since Roper used "Don't Know" in its total question N, we use the original variable in comparison with the Roper site.)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check race - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check sex - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab sex_orig

*There are no unexpected response options/observations

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, nor does it provide a frequency table in the back of the codebook, so we cannot double-check the variable by identifying frequencies by column and then comparing against the table.

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19980101.dta, replace

clear


****1998 Q2: Gallup/CNN/USA Today Poll #9804015: 1998 Election/Political Parties****

*Read in dictionary file for USAIPOCNUS1998-9804015; April 17, 1998 - April 19, 1998)
infile using DictionaryFiles\aipocnus1998-9804015.dct

*The sample size in the codebook - 1,007 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1998-9804015"

*Create a variable for survey year
gen svy_yr = 1998

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we check the variable by obtaining its frequencies directly from the Roper site.
tab poliPartyID_orig

*The frequencies displayed on the Roper site -- 32% Republican, 32% Democrat, 33% Independent, 0% Other, 2% Don't Know/Refused -- are close to those in the dataset but do not match exactly; the frequencies of the response options in the dataset are: 32% Republican, 33% Democrat, 33% Independent, 1% Other, 2% Don't Know/Refused. (Note, too, that the percentages change after appending, i.e., once we set "Don't Know" to missing, but since Roper used "Don't Know" in its total question N, we use the original variable in comparison with the Roper site.)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check race - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check sex - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab sex_orig

*There are no unexpected response options/observations

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, nor does it provide a frequency table in the back of the codebook, so we cannot double-check the variable by identifying frequencies by column and then comparing against the table.

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19980204.dta, replace

clear


****1998 Q3: Gallup/CNN/USA Today Poll #9807019: Parenting/Politics****

*Read in dictionary file for USAIPOCNUS1998-9807019; July 7, 1998 - July 8, 1998)
infile using DictionaryFiles\aipocnus1998-9807019.dct

*The sample size in the codebook - 1,035 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1998-9807019"

*Create a variable for survey year
gen svy_yr = 1998

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we check the variable by obtaining its frequencies directly from the Roper site.
tab poliPartyID_orig

*The frequencies displayed on the Roper site -- 30% Republican, 34% Democrat, 32% Independent, 0% Other, 4% Don't Know/Refused -- are close to those in the dataset but do not match exactly; the frequencies of the response options in the dataset are: 30% Republican, 33% Democrat, 33% Independent, 0.5% Other, 3% Don't Know/Refused. (Note, too, that the percentages change after appending, i.e., once we set "Don't Know" to missing, but since Roper used "Don't Know" in its total question N, we use the original variable in comparison with the Roper site.)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check race - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check sex - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab sex_orig

*There is an unexpected response option of 9 in the sex variable, and the codebook does not indicate that such an observation should be included or whether 9 means missing. Gallup Brain shows an N of 1034 for the question (total sample is 1035), so we infer that 9 does mean missing (it will be set to missing after appending).

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, nor does it provide a frequency table in the back of the codebook, so we cannot double-check the variable by identifying frequencies by column and then comparing against the table.

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19980307.dta, replace

clear


****1998 Q4: CNN/USA Today/Gallup Poll # 1998-9810039: Election/Politics/Sports****

*Read in dictionary file for USAIPOCNUS1998-9810039; October 9, 1998 - October 12, 1998)
infile using DictionaryFiles\aipocnus1998-9810039.dct

*The sample size in the codebook - 1,004 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1998-9810039"

*Create a variable for survey year
gen svy_yr = 1998

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19980410.dta, replace

clear


****1999 Q2: Gallup/CNN/USA Today # 9904020****

*Read in dictionary file for USAIPOCNUS1999-9904020; April 6, 1999 - April 7, 1999)
infile using DictionaryFiles\aipocnus1999-9904020.dct

*The sample size in the codebook - 1,055 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1999-9904020"

*Create a variable for survey year
gen svy_yr = 1999

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we check the variable by obtaining its frequencies directly from the Roper site.
tab poliPartyID_orig

*The frequencies displayed on the Roper site -- 29% Republican, 33% Democrat, 33% Independent, 1% Other, 4% Don't Know/Refused -- match the frequencies of the response options in the dataset. (Note, too, that the percentages change after appending, i.e., once we set "Don't Know" to missing, but since Roper used "Don't Know" in its total question N, we use the original variable in comparison with the Roper site.)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check race - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check sex - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab sex_orig

*There is an unexpected response option of 9 in the sex variable, and the codebook does not indicate that such an observation should be included or whether 9 means missing. Gallup Brain shows an N of 1034 for the question (total sample is 1035), so we infer that 9 does mean missing (it will be set to missing after appending).

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, nor does it provide a frequency table in the back of the codebook, so we cannot double-check the variable by identifying frequencies by column and then comparing against the table.

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither, so we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19990204.dta, replace

clear


****1999 Q3: Gallup/CNN/USA Today Poll # 1999-9907034: Government Spending/Vacations/School Integration****

*Read in dictionary file for USAIPOCNUS1999-9907034; July 16, 1999 - July 18, 1999)
infile using DictionaryFiles\aipocnus1999-9907034.dct

*The sample size in the codebook - 1,031 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1999-9907034"

*Create a variable for survey year
gen svy_yr = 1999

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19990307.dta, replace

clear


****1999 Q4: Gallup/CNN/USA Today Poll # 1999-9910042: 2000 Election/Test Ban Treaty/Halloween****

*Read in dictionary file for USAIPOCNUS1999-9910042; October 21, 1999 - October 24, 1999)
infile using DictionaryFiles\aipocnus1999-9910042.dct

*The sample size in the codebook - 1,005 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1999-9910042"

*Create a variable for survey year
gen svy_yr = 1999

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable - tab it and compare with frequency table in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - tab it and compare with frequency table in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - tab it and compare with frequency table in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Normally, we would compare the age frequencies by category to either the age distribution chart or the age deciles variable (depending on which version the codebook uses). However, this codebook provides neither, though it does provide a frequency table in the back of the codebook, so we can double-check the variable by identifying frequencies by column and then comparing against the table.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\19990410.dta, replace

clear


****2000 Q1: Gallup/CNN/USA Today Poll # 2000-02: Election 2000/Guns/Taxes/Defense****

*Read in data file for USAIPOCNUS2000-02; January 13, 2000 - January 16, 2000)
use RawData\aipocnus2000-02.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,027 - matches the number of observations read into Stata

*Keep the relevant variables
keep Q2 D4A D1 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename Q2 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename D1 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2000-02"

*Create a variable for survey year
gen svy_yr = 2000

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab poliPartyID_orig

*The frequency distribution for this variable matches that on the Roper site (note that only Republican, Democrat, and Independent can be checked; "Other" and "Don't Know/Refused" not displayed)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab race_orig

*The frequency distribution for this variable matches that on the Roper site (note that only black and white can be checked; other races and "Don't Know/Refused" not displayed)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-29 years
tab age_orig if age_orig>17 & age_orig<30
*30-49 years
tab age_orig if age_orig>29 & age_orig<50
*50-64 years
tab age_orig if age_orig>49 & age_orig<65
*65 years and over
tab age_orig if age_orig>=65

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20000101.dta, replace

clear


****2000 Q2: CNN/USA Today/Gallup Poll # 2000-16: Education/Guns****

*Read in data file for USAIPOCNUS2000-16; April 7, 2000 - April 9, 2000); note that this is a multi-form file, but since there is a single data file, the form variable is not used
use RawData\aipocnus2000-16.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,006 - matches the number of observations read into Stata

*Keep the relevant variables
keep D7 D4A D1 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D7 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename D1 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2000-16"

*Create a variable for survey year
gen svy_yr = 2000

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab poliPartyID_orig

*The frequency distribution for this variable matches that on the Roper site  (note that only Republican, Democrat, and Independent can be checked; "Other" and "Don't Know/Refused" not displayed)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and race cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-34 years
tab age_orig if age_orig>17 & age_orig<35
*35-44 years
tab age_orig if age_orig>34 & age_orig<45
*45-54 years
tab age_orig if age_orig>44 & age_orig<55
*55 years and over
tab age_orig if age_orig>=55

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20000204.dta, replace

clear


****2000 Q3: Gallup News Service Poll # 2000-27: Confidence in Government/Middle East****

*Read in data file for USAIPOGNS2000-27; July 6, 2000 - July 9, 2000)
use RawData\aipogns2000-27.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,001 - matches the number of observations read into Stata

*Keep the relevant variables
keep D7 D4A D1 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D7 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename D1 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2000-27"

*Create a variable for survey year
gen svy_yr = 2000

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab poliPartyID_orig

*The frequency distribution for this variable matches that on the Roper site

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither the former nor the latter, and the variable is not available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-29 years
tab age_orig if age_orig>17 & age_orig<30
*30-49 years
tab age_orig if age_orig>29 & age_orig<50
*50-64 years
tab age_orig if age_orig>49 & age_orig<65
*65 years and over
tab age_orig if age_orig>=65

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook provides neither the former nor the latter, and the variable is not available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20000307.dta, replace

clear


****2000 Q4: Gallup News Service Poll # 49: November Wave 1****

*Read in data file for USAIPOGNS2000-49; November 13, 2000 - November 15, 2000); note that this is a multi-form file, but since there is a single data file, the form variable is not used
use RawData\aipogns2000-49.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,028 - matches the number of observations read into Stata

*Keep the relevant variables
keep D7 D4A D1 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D7 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename D1 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2000-49"

*Create a variable for survey year
gen svy_yr = 2000

*Create a variable for survey month
gen svy_month = "November"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab poliPartyID_orig

*The frequency distribution for this variable matches that on the Roper site (note that only Republican, Democrat, and Independent can be checked; "Other" and "Don't Know/Refused" not displayed)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and race cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-29 years
tab age_orig if age_orig>17 & age_orig<30
*30-49 years
tab age_orig if age_orig>29 & age_orig<50
*50-64 years
tab age_orig if age_orig>49 & age_orig<65
*65 years and over
tab age_orig if age_orig>=65

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20000411.dta, replace

clear


****2001 Q1: Gallup/CNN/USA Today Poll # 02: January Wave 1****

*Read in data file for USAIPOCNUS2001-02; January 5, 2001 - January 7, 2001); note that this is a multi-form file, but since there is a single data file, the form variable is not used
use RawData\aipocnus2001-02.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,018 - matches the number of observations read into Stata

*Keep the relevant variables
keep PARTY1 RACE1 gr age state wtfctr EDUC1

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Rename and label the variables

*Education
rename EDUC1 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename PARTY1 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename RACE1 race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename gr sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename age age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2001-02"

*Create a variable for survey year
gen svy_yr = 2001

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question); actual amounts not available, just percentages
tab poliPartyID_orig

*The frequencies displayed on the Roper site -- 31% Republican, 34% Democrat, 33% Independent, * Other, 1% Don't Know/Refused -- are close to those in the dataset but do not match exactly; the frequencies of the response options in the dataset are: 33% Republican, 32% Democrat, 33% Independent, 0% Other, 1% Don't Know. (Note, too, that the percentages change after appending, i.e., once we set "Don't Know" to missing, but since Roper used "Don't Know" in its total question N, we use the original variable in comparison with the Roper site.)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, race cannot be matched to the latter, and the variable is not available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, sex cannot be matched to the latter, and the variable is not available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab sex_orig

*There are no unexpected response options/observations

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the age variable - normally, we would compare the age frequencies by category to either the age distribution chart, the age deciles variable (depending on which version the codebook uses), or the frequency table in the back of the codebook (by identifying frequencies by column and then comparing against the table). However, this codebook does not provide frequencies by category for age; age cannot be matched to the frequency table; and the age summary variable is not available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20010101.dta, replace

clear


****2001 Q2: Gallup/CNN/USA Today Poll # 15: Bush at 100****

*Read in data file for USAIPOCNUS2001-15; April 20, 2001 - April 22, 2001); note that this is a multi-form file, but since there is a single data file, the form variable is not used
use RawData\aipocnus2001-15.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,015 - matches the number of observations read into Stata

*Keep the relevant variables
keep D7 D4A S3 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D7 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename S3 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2001-15"

*Create a variable for survey year
gen svy_yr = 2001

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab poliPartyID_orig

*The frequency distribution for this variable matches that on the Roper site (note that only Republican, Democrat, and Independent can be checked; "Other" and "Don't Know/Refused" not displayed)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and race cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-29 years
tab age_orig if age_orig>17 & age_orig<30
*30-49 years
tab age_orig if age_orig>29 & age_orig<50
*50-64 years
tab age_orig if age_orig>49 & age_orig<65
*65 years and over
tab age_orig if age_orig>=65

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20010204.dta, replace

clear


****2001 Q3: Gallup/CNN/USA Today Poll # 27: Energy Problems/2004 Election/Stem Cell Research****

*Read in data file for USAIPOCNUS2001-27; August 3, 2001 - August 5, 2001)
use RawData\aipocnus2001-27.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,017 - matches the number of observations read into Stata

*Keep the relevant variables
keep D7 D4A D1 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Some of the variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each available on the Roper site

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D7 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename D1 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2001-27"

*Create a variable for survey year
gen svy_yr = 2001

*Create a variable for survey month
gen svy_month = "August"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab poliPartyID_orig

*The frequency distribution for this variable matches that on the Roper site (note that only Republican, Democrat, and Independent can be checked; "Other" and "Don't Know/Refused" not displayed)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and race cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-29 years
tab age_orig if age_orig>17 & age_orig<30
*30-49 years
tab age_orig if age_orig>29 & age_orig<50
*50-64 years
tab age_orig if age_orig>49 & age_orig<65
*65 years and over
tab age_orig if age_orig>=65

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20010308.dta, replace

clear


****2001 Q4: Terrorism, Anthrax, Halloween****

*Read in data file for USAIPOCNUS2001-40; October 19, 2001 - October 21, 2001)
use RawData\aipocnus2001-40.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,006 - matches the number of observations read into Stata

*Keep the relevant variables
keep D7 D4A D1 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Some of the variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each available on the Roper site

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D7 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename D1 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2001-40"

*Create a variable for survey year
gen svy_yr = 2001

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question); actual amounts not available, just percentages
tab poliPartyID_orig

*The frequencies displayed on the Roper site -- 32% Republican, 33% Democrat, 31% Independent, 1% Other, 4% Don't Know/Refused -- are close to those in the dataset but do not match exactly; the frequencies of the response options in the dataset are: 34% Republican, 33% Democrat, 30% Independent, 1% Other, 3% Don't Know/Refused. (Note, too, that the percentages change after appending, i.e., once we set "Don't Know" to missing, but since Roper used "Don't Know" in its total question N, we use the original variable in comparison with the Roper site.)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and race cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-29 years
tab age_orig if age_orig>17 & age_orig<30
*30-49 years
tab age_orig if age_orig>29 & age_orig<50
*50-64 years
tab age_orig if age_orig>49 & age_orig<65
*65 years and over
tab age_orig if age_orig>=65

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations. However, note that the Gallup codebook does not provide the state codes. Below, we use numlabel and then tab the state variable to identify the state codes in the using dataset.
numlabel, add
tab state

*Numlabel is no longer necessary
numlabel, remove

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20010410.dta, replace

clear


****2002 Q1: January Wave 1: Economy/War on Terrorism****

*Read in data file for USAIPOCNUS2002-02; January 11, 2002 - January 14, 2002)
use RawData\aipocnus2002-02.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,008 - matches the number of observations read into Stata

*Keep the relevant variables
keep D7 D4A S3 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Some of the variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each available on the Roper site

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D7 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename S3 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2002-02"

*Create a variable for survey year
gen svy_yr = 2002

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab poliPartyID_orig

*The frequency distribution for this variable matches that on the Roper site (note that only Republican, Democrat, and Independent can be checked; "Other" and "Don't Know/Refused" not displayed)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and race cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-29 years
tab age_orig if age_orig>17 & age_orig<30
*30-49 years
tab age_orig if age_orig>29 & age_orig<50
*50-64 years
tab age_orig if age_orig>49 & age_orig<65
*65 years and over
tab age_orig if age_orig>=65

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20020101.dta, replace

clear


****2002 Q2: Gallup/CNN/USA Today Poll # 13: Congress/Mideast/2004 Presidential Election/Taxes****

*Read in data file for USAIPOCNUS2002-13; April 5, 2002 - April 7, 2002)
use RawData\aipocnus2002-13.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,009 - matches the number of observations read into Stata

*Keep the relevant variables
keep D7 D4A S3 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Some of the variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each available on the Roper site

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D7 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename S3 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2002-13"

*Create a variable for survey year
gen svy_yr = 2002

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab poliPartyID_orig

*The frequency distribution for this variable matches that on the Roper site (note that only Republican, Democrat, and Independent can be checked; "Other" and "Don't Know/Refused" not displayed)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID_orig == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and race cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-29 years
tab age_orig if age_orig>17 & age_orig<30
*30-49 years
tab age_orig if age_orig>29 & age_orig<50
*50-64 years
tab age_orig if age_orig>49 & age_orig<65
*65 years and over
tab age_orig if age_orig>=65

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20020204.dta, replace

clear


****2002 Q3: Terrorism/Trust/Business/Finances/Abortion****

*Read in data file for USAIPOCNUS2002-27; July 5, 2002 - July 8, 2002)
use RawData\aipocnus2002-27.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,013 - matches the number of observations read into Stata

*Keep the relevant variables
keep D7 D4A S3 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Some of the variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each available on the Roper site

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D7 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename S3 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2002-27"

*Create a variable for survey year
gen svy_yr = 2002

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab poliPartyID_orig

*The frequency distribution for this variable matches that on the Roper site (note that only Republican, Democrat, and Independent can be checked; "Other" and "Don't Know/Refused" not displayed)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID_orig == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and race cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-29 years
tab age_orig if age_orig>17 & age_orig<30
*30-49 years
tab age_orig if age_orig>29 & age_orig<50
*50-64 years
tab age_orig if age_orig>49 & age_orig<65
*65 years and over
tab age_orig if age_orig>=65

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20020307.dta, replace

clear


****2002 Q4: Gallup/Cable News Network/USA Today Poll # 43: Mid-term Pre-election Poll****

*Read in data file for USAIPOCNUS2002-43; October 31, 2002 - November 3, 2002)
use RawData\aipocnus2002-43.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,221 - matches the number of observations read into Stata

*Keep the relevant variables
keep D7 D4A S3 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Some of the variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each available on the Roper site

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D7 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename S3 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2002-43"

*Create a variable for survey year
gen svy_yr = 2002

*Create a variable for survey month
gen svy_month = "October-November"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question); actual amounts not available, just percentages
tab poliPartyID_orig

*The frequencies displayed on the Roper site -- 34% Republican, 34% Democrat, 27% Independent, 1% Other, 4% Don't Know, 1% Refused -- are close to those in the dataset but do not match exactly; the frequencies of the response options in the dataset are: 35% Republican, 33% Democrat, 28% Independent, 1% Other, 2% Don't Know, 1% Refused. (Note, too, that the percentages change after appending, i.e., once we set "Don't Know" to missing, but since Roper used "Don't Know" in its total question N, we use the original variable in comparison with the Roper site.)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID_orig == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and race cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, sex cannot be matched to the latter, and the variable is not available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab sex_orig

*There are no unexpected response options/observations

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the age variable - normally, we would compare the age frequencies by category to either the age distribution chart, the age deciles variable (depending on which version the codebook uses), or the frequency table in the back of the codebook (by identifying frequencies by column and then comparing against the table). However, this codebook does not provide frequencies by category for age; age cannot be matched to the frequency table; and the age summary variable is not available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20020410-11.dta, replace

clear


****2003 Q1: Gallup/CNN/USA Today Poll # 2003-01: Congress/War on Terrorism/North Korea/2004 Presidential Election/Economy/Title Nine****

*Read in data file for USAIPOCNUS2003-01; January 3, 2003 - January 5, 2003)
use RawData\aipocnus2003-01.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,000 - matches the number of observations read into Stata

*Keep the relevant variables
keep D7 D4A S3 D2 state wtfctr D3
 
*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Some of the variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each available on the Roper site

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D7 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename S3 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2003-01"

*Create a variable for survey year
gen svy_yr = 2003

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab poliPartyID_orig

*The frequency distribution for this variable matches that on the Roper site (note that only Republican, Democrat, and Independent can be checked; "Other" and "Don't Know/Refused" not displayed)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID_orig == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and race cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-29 years
tab age_orig if age_orig>17 & age_orig<30
*30-49 years
tab age_orig if age_orig>29 & age_orig<50
*50-64 years
tab age_orig if age_orig>49 & age_orig<65
*65 years and over
tab age_orig if age_orig>=65

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20030101.dta, replace

clear


****2003 Q3: Gallup News Service Poll # 2003-37: Terrorism/Homosexual Civil Unions/Iraq/Children/College/Dangerous Drivers****

*Read in data file for USAIPOGNS2003-37; July 18, 2003 - July 20, 2003)
use RawData\aipogns2003-37.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,003 - matches the number of observations read into Stata

*Keep the relevant variables
keep D7 D4A S3 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Some of the variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each available on the Roper site

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D7 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename S3 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2003-37"

*Create a variable for survey year
gen svy_yr = 2003

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab poliPartyID_orig

*The frequency distribution for this variable only partially matches that on the Roper site (note that only Republican, Democrat, and Independent can be checked; "Other" and "Don't Know/Refused" not displayed): while Republican is consistent across Roper and the dataset, Roper shows 338 Democrats and 324 Independents, and this is reversed in the dataset itself (i.e., 324 Democrats and 338 Independents). I did not recode to conform with the Roper site, as there was no apparent error in how it was coded initially (based on the codebook).

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID_orig == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and race cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-29 years
tab age_orig if age_orig>17 & age_orig<30
*30-49 years
tab age_orig if age_orig>29 & age_orig<50
*50-64 years
tab age_orig if age_orig>49 & age_orig<65
*65 years and over
tab age_orig if age_orig>=65

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20030307.dta, replace

clear


****2003 Q4: Gallup/CNN/USA Today Poll # 2003-46: 2004 Elections/Iraq/California Governor Recall/Pope John Paul II/Baseball****

*Read in data file for USAIPOCNUS2003-46; October 10, 2003 - October 12, 2003)
use RawData\aipocnus2003-46.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,004 - matches the number of observations read into Stata

*Keep the relevant variables
keep D7 D4A S3 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Some of the variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each available on the Roper site

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D7 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename S3 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2003-46"

*Create a variable for survey year
gen svy_yr = 2003

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab poliPartyID_orig

*The frequency distribution for this variable matches that on the Roper site (note that only Republican, Democrat, and Independent can be checked; "Other" and "Don't Know/Refused" not displayed)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID_orig == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and race cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-29 years
tab age_orig if age_orig>17 & age_orig<30
*30-49 years
tab age_orig if age_orig>29 & age_orig<50
*50-64 years
tab age_orig if age_orig>49 & age_orig<65
*65 years and over
tab age_orig if age_orig>=65

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20030410.dta, replace

clear


****2004 Q1: Gallup/CNN/USA Today Poll # 2004-01: Election Benchmark I****

*Read in data file for USAIPOCNUS2004-01; January 2, 2004 - January 5, 2004)
use RawData\aipocnus2004-01.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,029 - matches the number of observations read into Stata

*Keep the relevant variables
keep D09 D04A S2 D02 state wtfctr D03

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Some of the variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each available on the Roper site

*Rename and label the variables

*Education
rename D03 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D09 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D04A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename S2 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D02 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2004-01"

*Create a variable for survey year
gen svy_yr = 2004

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab poliPartyID_orig

*The frequency distribution for this variable only partially matches that on the Roper site (note that only Republican, Democrat, and Independent can be checked; "Other" and "Don't Know/Refused" not displayed): while Republican and Democrat are consistent across Roper and the dataset, Roper shows 385 Independents, and the dataset shows 386. I did not recode to conform with the Roper site, as there was no apparent error in how it was coded initially (based on the codebook).

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID_orig == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and race cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-29 years
tab age_orig if age_orig>17 & age_orig<30
*30-49 years
tab age_orig if age_orig>29 & age_orig<50
*50-64 years
tab age_orig if age_orig>49 & age_orig<65
*65 years and over
tab age_orig if age_orig>=65

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20040101.dta, replace

clear


****2004 Q2: Gallup/CNN/USA Today Poll # 2004-15: 2004 Presidential Election/War in Iraq****

*Read in data file for USAIPOCNUS2004-15; April 16, 2004 - April 18, 2004)
use RawData\aipocnus2004-15.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,003 - matches the number of observations read into Stata

*Keep the relevant variables
keep D9 D4A S2 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Some of the variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each available on the Roper site

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D9 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename S2 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2004-15"

*Create a variable for survey year
gen svy_yr = 2004

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question); actual amounts not available, just percentages
tab poliPartyID_orig

*The frequencies displayed on the Roper site -- 32% Republican, 34% Democrat, 30% Independent, 1% Other, 1% Don't Know, 1% Refused -- are close to those in the dataset but do not match exactly; the frequencies of the response options in the dataset are: 35% Republican, 32% Democrat, 29% Independent, 1% Other, 1% Don't Know, 1% Refused. (Note, too, that the percentages change after appending, i.e., once we set "Don't Know" to missing, but since Roper used "Don't Know" in its total question N, we use the original variable in comparison with the Roper site.)

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, race cannot be matched to the latter, and the variable is not available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the sex variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, sex cannot be matched to the latter, and the variable is not available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab sex_orig

*There are no unexpected response options/observations

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the age variable - normally, we would compare the age frequencies by category to either the age distribution chart, the age deciles variable (depending on which version the codebook uses), or the frequency table in the back of the codebook (by identifying frequencies by column and then comparing against the table). However, this codebook does not provide frequencies by category for age; age cannot be matched to the frequency table; and the age summary variable is not available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20040204.dta, replace

clear


****2004 Q3: Gallup/CNN/USA Today Poll # 2004-24: 2004 Presidential Election/Terrorism/Same-Sex Marriages****

*Read in data file for USAIPOCNUS2004-24; July 19, 2004 - July 21, 2004)
use RawData\aipocnus2004-24.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,005 - matches the number of observations read into Stata

*Keep the relevant variables
keep D9 D4A S2 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Some of the variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each available on the Roper site

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D9 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename S2 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2004-24"

*Create a variable for survey year
gen svy_yr = 2004

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab poliPartyID_orig

*The frequency distribution for this variable only partially matches that on the Roper site (note that only Republican, Democrat, and Independent can be checked; "Other" and "Don't Know/Refused" not displayed): while Republican and Democrat are consistent across Roper and the dataset, Roper shows 255 Independents, and the dataset shows 258. I did not recode to conform with the Roper site, as there was no apparent error in how it was coded initially (based on the codebook).

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID_orig == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the race variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and race cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for this survey. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable using the frequencies available through the Roper site (in a cross-tab for the party question)
tab sex_orig

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Check the variable further - tab each age category and compare with the age summary available through the Roper site (in a cross-tab for the party question)
*18-29 years
tab age_orig if age_orig>17 & age_orig<30
*30-49 years
tab age_orig if age_orig>29 & age_orig<50
*50-64 years
tab age_orig if age_orig>49 & age_orig<65
*65 years and over
tab age_orig if age_orig>=65

*The frequency distribution for this variable matches that on the Roper site

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - normally, we would check the variable by comparing it with the frequencies displayed next to the variable in the codebook or with the frequency table in the back of the codebook. However, this codebook does not provide the former, and state cannot be matched to the latter, nor is the variable available through the Roper site in a cross-tab for the party question. Thus, we just eyeball the variable to ensure that the response options match those in the codebook and that there are no unexpected observations.
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20040307.dta, replace

clear


****2004 Q4: Gallup/CNN/USA Today Poll # 2004-32: 2004 Presidential Election/Iraq/Presidential Debates****


*IMPORTANT NOTE: This entire survey dataset is unchecked for three reasons: (1) frequencies are not displayed next to each variable; (2) the columns in the frequency table cannot be matched to the variables accurately; and (3) the frequencies available through the Roper site (in a cross-tab for the party question) are for a partial sample (83%), so the frequencies don't correspond. However, we eyeball the variables to ensure that the response options match those in the codebook and that there are no unexpected observations.


*Read in data file for USAIPOCNUS2004-32; October 1, 2004 - October 3, 2004)
use RawData\aipocnus2004-32.dta

*Count observations in the dataset
count

*The sample size in the codebook - 1,016 - matches the number of observations read into Stata

*Keep the relevant variables
keep D9 D4A S2 D2 state wtfctr D3

*Describe the variables to ensure that correct variables were retained, as we will rename and label the variables below, as well as drop value labels
d

*Some of the variables are not labeled in the using dataset, but we will confirm that the correct variables were retained when we check the frequencies of each available on the Roper site

*Rename and label the variables

*Education
rename D3 educ_orig

*PARTY ID IN POLITICS TODAY (poliPartyID)
rename D9 poliPartyID_orig
label variable poliPartyID_orig "ORIGINAL PARTY ID IN POLITICS TODAY VARIABLE"

*RACE OF THE RESPONDENT (race)
rename D4A race_orig
label variable race_orig "ORIGINAL RACE OF THE RESPONDENT VARIABLE"

*GENDER OF THE RESPONDENT (sex)
rename S2 sex_orig
label variable sex_orig "ORIGINAL GENDER OF THE RESPONDENT VARIABLE"

*AGE OF THE RESPONDENT (age)
rename D2 age_orig
label variable age_orig "ORIGINAL AGE OF THE RESPONDENT VARIABLE"

*STATE THE RESPONDENT LIVES IN (state)
rename state state_orig
label variable state_orig "ORIGINAL STATE THE RESPONDENT LIVES IN VARIABLE"

*WEIGHT (wgt)
rename wtfctr wgt

*Drop preexisting value labels
label drop _all

*Create a variable for survey code
gen svy = "2004-32"

*Create a variable for survey year
gen svy_yr = 2004

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY (poliPartyID)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 " NONE." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?"

*Check the variable
tab poliPartyID_orig

*There are no unexpected response options/observations, though the total question N of 839 -- even before setting "Don't Know" and "Refused" to missing -- is quite a bit less than the sample size of 1,016.

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = . if poliPartyID_orig == 5 | poliPartyID == 6


*RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys, with variations and combinations of "No Answer," "Don't Know," "NA," and "Refused" treated as missing, and Asians, Hispanics, and Native Americans coded as "OTHER." After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and sex are in two variables for this survey

*Check the variable
tab race_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 1 if race_orig == 6
replace race = 2 if race_orig == 7
replace race = 3 if race_orig == 1 | race_orig == 8 | race_orig == 9 | race_orig == 10
replace race = . if race_orig == 2 | race_orig == 3

*Check the variable
tab sex_orig

*There are no unexpected response options/observations

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*AGE OF THE RESPONDENT (age)

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Perform basic check: tabulate the variable to ensure that there are no unexpected observations (i.e., those outside of possible ages for Gallup respondents)
tab age_orig

*There are no unexpected observations

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*STATE THE RESPONDENT LIVES IN (state)

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable
tab state_orig

*There are no unexpected response options/observations

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 61 if state_orig == 71
replace state = 62 if state_orig == 72
replace state = 63 if state_orig == 73
replace state = 64 if state_orig == 74
replace state = 65 if state_orig == 75
replace state = 66 if state_orig == 76
replace state = 67 if state_orig == 77
replace state = 68 if state_orig == 78
replace state = 71 if state_orig == 81
replace state = 72 if state_orig == 82
replace state = 73 if state_orig == 83
replace state = 74 if state_orig == 84
replace state = 75 if state_orig == 85
replace state = 81 if state_orig == 61
replace state = 82 if state_orig == 62
replace state = 83 if state_orig == 63
replace state = 84 if state_orig == 64


*WEIGHT (wgt)

*Harmonization Plan: Check the variable by summing it to ensure that weights make sense (these codebooks typically do not provide frequencies for weight, so the more specific check is not possible in most cases); no additional adjustments, e.g., variable name synchronization, recoding, labeling, etc., are required.

sum wgt

*There are no unexpected observations


*Save the data
saveold FormattedData\20040410.dta, replace

clear



********APPEND FILES AND FINALIZE DATASET********

use FormattedData\19810101.dta
append using FormattedData\19810204.dta
append using FormattedData\19810307-08.dta
append using FormattedData\19810410.dta
append using FormattedData\19820101.dta
append using FormattedData\19820204.dta
append using FormattedData\19820307.dta
append using FormattedData\19820410.dta
append using FormattedData\19830204.dta
append using FormattedData\19830307.dta
append using FormattedData\19830410.dta
append using FormattedData\19840101.dta
append using FormattedData\19840204.dta
append using FormattedData\19840410.dta
append using FormattedData\19850101.dta
append using FormattedData\19850204.dta
append using FormattedData\19850307.dta
append using FormattedData\19850410.dta
append using FormattedData\19860101.dta
append using FormattedData\19860204.dta
append using FormattedData\19860307.dta
append using FormattedData\19860410.dta
append using FormattedData\19870101.dta
append using FormattedData\19870204.dta
append using FormattedData\19870412.dta
append using FormattedData\19880103.dta
append using FormattedData\19880307.dta
append using FormattedData\19890101.dta
append using FormattedData\19890206.dta
append using FormattedData\19890308.dta
append using FormattedData\19890410.dta
append using FormattedData\19900101.dta
append using FormattedData\19900206.dta
append using FormattedData\19900308.dta
append using FormattedData\19900411.dta
append using FormattedData\19910102.dta
append using FormattedData\19910204.dta
append using FormattedData\19910307.dta
append using FormattedData\19910410.dta
append using FormattedData\19920101.dta
append using FormattedData\19920204.dta
append using FormattedData\19920307.dta
append using FormattedData\19920411.dta
append using FormattedData\19930101.dta
append using FormattedData\19930204.dta
append using FormattedData\19930307.dta
append using FormattedData\19930410.dta
append using FormattedData\19940101.dta
append using FormattedData\19940204.dta
append using FormattedData\19940307.dta
append using FormattedData\19940410.dta
append using FormattedData\19950101.dta
append using FormattedData\19950204.dta
append using FormattedData\19950308.dta
append using FormattedData\19950411.dta
append using FormattedData\19960101.dta
append using FormattedData\19960204.dta
append using FormattedData\19960307.dta
append using FormattedData\19960411.dta
append using FormattedData\19970101.dta
append using FormattedData\19970204.dta
append using FormattedData\19970307.dta
append using FormattedData\19970410.dta
append using FormattedData\19980101.dta
append using FormattedData\19980204.dta
append using FormattedData\19980307.dta
append using FormattedData\19980410.dta
append using FormattedData\19990204.dta
append using FormattedData\19990307.dta
append using FormattedData\19990410.dta
append using FormattedData\20000101.dta
append using FormattedData\20000204.dta
append using FormattedData\20000307.dta
append using FormattedData\20000411.dta
append using FormattedData\20010101.dta
append using FormattedData\20010204.dta
append using FormattedData\20010308.dta
append using FormattedData\20010410.dta
append using FormattedData\20020101.dta
append using FormattedData\20020204.dta
append using FormattedData\20020307.dta
append using FormattedData\20020410-11.dta
append using FormattedData\20030101.dta
append using FormattedData\20030307.dta
append using FormattedData\20030410.dta
append using FormattedData\20040101.dta
append using FormattedData\20040204.dta
append using FormattedData\20040307.dta
append using FormattedData\20040410.dta

*Recode those variables requiring adjustments

*Replace observations set to 0 ("NO CODE OR NO DATA") or 9 ("INAPPLICABLE") with missing values per relevant harmonization plan(s)
replace poliPartyID = . if poliPartyID == 0 | poliPartyID == 9
replace raceSex = . if raceSex == 0 | raceSex == 9
replace race = . if race == 0 | race == 9
replace sex = . if sex == 0 | sex == 9
replace age = . if age == 0 | age == 9
replace state = . if state == 0 | state == 9

*Label variables, define values, and assign values to variables

label variable svy "SURVEY CODE"

label variable svy_yr "SURVEY YEAR"

label variable svy_month "SURVEY MONTH(S)"

label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY" 5 "NONE"
label values poliPartyID lb_poliPartyID

label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"
label values raceSex lb_raceSex

label variable race "RACE OF THE RESPONDENT"
label define lb_race 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE"
label values race lb_race

label variable sex "GENDER OF THE RESPONDENT"
label define lb_sex 1 "MALE" 2 "FEMALE"
label values sex lb_sex

label variable age "AGE OF THE RESPONDENT"

label variable state "STATE THE RESPONDENT LIVES IN"
label define lb_state 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"
label values state lb_state

gen educ=educ_orig
replace educ = 1 if (educ_orig == 1 | educ_orig == 2 | educ_orig == 3) //None or Grade 1-8
replace educ = 4 if (educ_orig == 4) //HS Incomplete
replace educ = 5 if (educ_orig == 5) //HS Grad
replace educ = 6 if (educ_orig == 6) //Technical, Trade or Business
replace educ = 7 if (educ_orig == 7) //College, Uni., Incomplete
replace educ = 8 if (educ_orig == 8) //College, Uni., Graduate
replace educ = 0 if (educ_orig == 0 | educ_orig==9) //No Code
label variable educ "EDUCATION OF THE RESPONDENT"
label define lb_edu 1 "NONE, OR GRADES 1-8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE" 9 "POST-GRAD" 0 "NO CODE OR NO DATA"
label values educ lb_edu

*Check the data

*Count observations in the dataset
count

*Check each variable
bys svy: tab svy_yr
bys svy: tab svy_month
bys svy: tab poliPartyID
bys svy: tab raceSex
bys svy: tab race
bys svy: tab sex
bys svy: sum age
bys svy: tab state
bys svy: sum wgt

*Sort the data
sort svy

*Order the variables
order svy svy_yr svy_month poliPartyID poliPartyID_orig raceSex raceSex_orig race race_orig sex sex_orig age age_orig educ educ_orig state state_orig wgt 

*Compress data in memory
compress

*Rename educ so that I can merge it later
rename educ eduHarmonized

*Save the data
saveold PartyID_1981-2004.11.17.2014.dta, replace

log close

exit, clear
