

log using PresidentialApprovalQuestionsEisenhower6.18.2016.log, replace

set more off

*Change directory so others can use the do file
cd "/Users/`c(username)'/Dropbox/southern_strategy/Gallup&GSS/PresidentialApprovalEisenhower"

*FILE DESCRIPTION: This document harmonizes variables on presidential approval and respondent's party identification in Gallup Polls that are repeated over the Eisenhower years (1953-1961) obtained from Roper's iPoll website (available at: http://www.ropercenter.uconn.edu/CFIDE/cf/action/ipoll/index.cfm). In addition, it includes a variable for the following question related to tax levels that is available for four surveys in this time frame: "Do you consider the amount of federal income tax which you have to pay as too high, too low, or about right?" (Variations on the wording of this question may be found in the spreadsheet "Roper Survey Questions on Tax Levels and Redistribution 8.13.2014.xlsx.) Note that the do file "AdditionalTaxQuestions9.8.2014" harmonizes this tax variable and a redistribution variable obtained from the Roper site for the time frame 1950-1980, excluding the years for the Eisenhower and Kennedy Administrations, and with 1973 serving as the last year of availability for the tax question; the variable for this tax question asked during the Kennedy Administration is harmonized in the do file "PresidentialApprovalQuestionsKennedy8.24.2014." The do file "Redistribution Survey Questions Harmonization 1984-2012 6.24.2014" harmonizes variables for a separate question on redistribution, beginning with the Reagan Administration in 1984. It also includes a variable on whether or not the poll tax should be abolished for the one survey in which it's asked during the Eisenhower years. Lastly, it includes a variable for the following question that is available in one survey in this same time frame: "In your opinion, which presidential candidate--Eisenhower or Stevenson--will work hardest to get colored students admitted to white schools in the South?"

*IMPORTANT NOTE: Variables for presidential approval and/or respondent's party identification in Eisenhower-era Gallup surveys are available in additional files on the Roper site that are not included here. They are files that were converted from binary, resulting in several data problems that have not been resolved by Roper, so they are omitted entirely. Only files that could be read into Stata from ASCII are included in this do file. For a list of all Gallup surveys conducted during the Eisenhower Administration that contain variables for presidential approval and/or respondent's party identification, see "Survey Questions on Presidential Approval and Party ID–Eisenhower 8.31.2014." This spreadsheet indicates whether or not a given survey was converted from binary and thus excluded  from this do file.

/*


PROCESS/PROCEDURE

This do file proceeds in two main parts: (1) variable creation, adjustments, and harmonization; and (2) appending the data/finalizing the dataset.

Part 1: We recode the variables in each survey file so that when the files are appended, we ensure that the variables are coded consistently. As necessary, we also create new variables and/or make adjustments to preexisting variables. The section is organized by survey dataset. For each survey, we first read in the ASCII data using a dictionary file, and then we create variables for survey code, survey year, and survey month to serve as unique identifiers for the file. We then implement preestablished harmonization plans to achieve conformity across the following variables: approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, age of the respondent, and level of personal federal income tax (if available).

Part 2: This section appends together the individual survey files and then proceeds to make adjustments to the complete dataset. First, we recode several variables in which the whole dataset needed to be in place prior to doing so; this includes replacing observations set to 0 ("NO CODE OR NO DATA") or 9 ("INAPPLICABLE") with missing values per relevant harmonization plan(s). Second, we label variables, define values, and assign values to variables. Lastly, we finalize the dataset by checking each of the variables and sorting/organizing the data.


HARMONIZATION PLANS

1. APPROVAL OF CURRENT PRESIDENT (presApprovala): Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

2. PARTY ID IN POLITICS TODAY (poliPartyID): Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

3. RACE AND GENDER OF THE RESPONDENT (raceSex or race and sex): Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

4. STATE THE RESPONDENT LIVES IN (state): Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

5. AGE OF THE RESPONDENT (age): Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

6. LEVEL OF PERSONAL FEDERAL INCOME TAX (fedIncomeTax): Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is only included in USAIPO1953-0511 (February 1, 1953 - February 5, 1953), USAIPO1956-0560 (February 16, 1956 - February 21, 1956), USAIPO1957-0581 (April 6, 1957 - April 11, 1957), and USAIPO1959-0611 (March 4, 1959 - March 9, 1959).

7. POLL TAX (pollTax): Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO" 3 "NO OPINION." Note that surveys USAIPO1948-0414 (March 5, 1948 - March 10, 1948) and USAIPO1949-0439 (March 19, 1949 - March 24, 1949) use "Yes/No/No Opinion" as response options, while surveys USAIPO1949-0450 (November 27, 1949 - December 2, 1949) and USAIPO1953-0511 (February 1, 1953 - February 5, 1953) use "Should/Should Not/No Opinion" as response options. Thus, in the latter two surveys, "Should" is treated as "Yes," and "Should Not" is treated as "No." Note that this variable is only included here in USAIPO1953-0511 (February 1, 1953 - February 5, 1953).

8. PRESIDENTIAL CANDIDATE (EISENHOWER/STEVENSON) WHO WILL WORK HARDEST TO GET COLORED STUDENTS ADMITTED TO WHITE SCHOOLS IN THE SOUTH (candidateSchIntegration): Synchronization of variable name and recoding of values for consistency process is unnecessary, as this question appears in only one survey, USAIPO1956-0571 (September 20, 1956 - September 25, 1956). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "EISENHOWER" 2 "STEVENSON" 3 "NO DIFFERENCE" 4 "NO OPINION"


INDIVIDUAL FILES: ROPER IDENTIFICATION NUMBERS AND MISCELLANEOUS ISSUES

This section itemizes each survey that contains the presidential approval and/or respondent's party identification. It identifies available variables in included files, as well as details reasons for exclusions, as necessary.

1. USAIPO1953-0511 (February 1, 1953 - February 5, 1953): Included variables are approval of current president, party ID in politics today (plus the indicator for party ID not having been taken from the standard party variable), race of the respondent, gender of the respondent, state the respondent lives in, age of the respondent, level of personal federal income tax, and poll tax. Presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South was not available for this survey

2. USAIPO1953-0513 (March 28, 1953 - April 2, 1953): Included variables are approval of current president, party ID in politics today (plus the indicator for party ID not having been taken from the standard party variable), race of the respondent, gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

3. USAIPO1953-0519 (August 15, 1953 - August 20, 1953): Included variables are approval of current president, party ID in politics today (plus the indicator for party ID not having been taken from the standard party variable), race of the respondent, gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

4. USAIPO1953-0521 (October 9, 1953 - October 14, 1953): Included variables are approval of current president, party ID in politics today (plus the indicator for party ID not having been taken from the standard party variable), race of the respondent, gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

5. USAIPO1953-0522 (November 1, 1953 - November 5, 1953): Included variables are approval of current president, party ID in politics today (plus the indicator for party ID not having been taken from the standard party variable), race of the respondent, gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

6. USAIPO1954-0529 (April 8, 1954 - April 13, 1954): Included variables are approval of current president, party ID in politics today (plus the indicator for party ID not having been taken from the standard party variable), race of the respondent, gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

7. USAIPO1954-0531 (May 21, 1954 - May 26, 1954): Included variables are approval of current president, party ID in politics today (plus the indicator for party ID not having been taken from the standard party variable), race of the respondent, gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

8. USAIPO1954-0532 (June 12, 1954 - June 17, 1954): Included variables are approval of current president, party ID in politics today (plus the indicator for party ID not having been taken from the standard party variable), race of the respondent, gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey. Note that the frequency distribution for the state variable does not match that in the codebook for observations with numeric codes in the 20s (Middle Atlantic states) and Connecticut. For example, the state with a code of 23 in the Stata tabulation (126 observations) is shown in the codebook as state code 22 (also 126 observations); the state with a code of 24 in the Stata tabulation (26 observations) is shown in the codebook as state code 23 (also 24 observations); etc. The frequencies appear to have been assigned incorrectly in the codebook, rather than the data, so we will simply label these values after appending but otherwise leave as-is, given that the Middle Atlantic states and Connecticut are not central to the analysis; in a future analysis, however, we may want to drop these observations entirely. 

9. USAIPO1954-0534 (July 16, 1954 - July 21, 1954): Included variables are approval of current president, party ID in politics today (plus the indicator for party ID not having been taken from the standard party variable), race of the respondent, gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

10. USAIPO1954-0537 (September 16, 1954 - September 21, 1954): Included variables are approval of current president, party ID in politics today, race of the respondent, gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

11. USAIPO1955-0541 (December 31, 1954 - January 5, 1955): Included variables are approval of current president, party ID in politics today, race of the respondent, gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

12. USAIPO1955-0546 (April 14, 1955 - April 19, 1955): Included variables are approval of current president, party ID in politics today, race of the respondent, gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

13. USAIPO1955-0547 (May 12, 1955 - May 17, 1955): Included variables are approval of current president, party ID in politics today, race of the respondent, gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

14. USAIPO1955-0556 (November 17, 1955 - November 22, 1955): Included variables are approval of current president, party ID in politics today, race of the respondent, gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

15. USAIPO1956-0560 (February 16, 1956 - February 21, 1956): Included variables are approval of current president, party ID in politics today, race of the respondent, gender of the respondent, state the respondent lives in, age of the respondent, and level of personal federal income tax. Presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South and poll tax were not available for this survey.

16. USAIPO1956-0562 (March 29, 1956 - April 3, 1956): Included variables are approval of current president, party ID in politics today, race of the respondent, gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

17. USAIPO1956-0569 (August 23, 1956 - August 28, 1956): Included variables are party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Presidential approval, level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

18. USAIPO1956-0570 (September 9, 1956 - September 14, 1956): Included variables are party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Presidential approval, level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

19. USAIPO1956-0571 (September 20, 1956 - September 25, 1956): Included variables are party ID in politics today, race and gender of the respondent, state the respondent lives in, age of the respondent, and presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South. Presidential approval, level of personal federal income tax, and poll tax were not available for this survey. Note that the number of observations for two states -- Florida and Virginia -- did not match the frequencies displayed next to them in the codebook.

20. USAIPO1956-0576 (December 14, 1956 - December 19, 1956): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

21. USAIPO1957-0577 (January 17, 1957 - January 22, 1957): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey. Note that the number of observations for four states -- Arkansas, Missouri, Texas, and Wisconsin -- did not match the frequencies displayed next to them in the codebook.

22. USAIPO1957-0578 (February 5, 1957 - February 12, 1957): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

23. USAIPO1957-0579 (February 28, 1957 - March 5, 1957): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

24. USAIPO1957-0580 (March 15, 1957 - March 20, 1957): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

25. USAIPO1957-0581 (April 6, 1957 - April 11, 1957): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, age of the respondent, and level of personal federal income tax. Presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South and poll tax were not available for this survey.

26. USAIPO1957-0582 (April 25, 1957 - April 30, 1957): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

27. USAIPO1957-0584 (June 6, 1957 - June 11, 1957): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

28. USAIPO1957-0586 (July 18, 1957 - July 23, 1957): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

29. USAIPO1957-0588 (August 29, 1957 - September 4, 1957): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

30. USAIPO1957-0589 (September 19, 1957 - September 24, 1957): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

31. USAIPO1957-0590 (October 10, 1957 - October 15, 1957): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

32. USAIPO1957-0591 (November 7, 1957 - November 12, 1957): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

33. USAIPO1958-0595 (February 14, 1958 - February 19, 1958): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

34. USAIPO1958-0599 (May 7, 1958 - May 12, 1958): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

35. USAIPO1958-0602 (July 30, 1958 - August 4, 1958): This file contains the presidential approval and respondent's party identification question, but it was read in/harmonized as a separate part of the study by Josephine Gantois. It is excluded here to avoid redundancy. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

36. USAIPO1958-0603 (August 20, 1958 - August 25, 1958): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

37. USAIPO1958-0604 (September 10, 1958 - September 15, 1958): This file contains the presidential approval and respondent's party identification question, but it was read in/harmonized as a separate part of the study by Josephine Gantois. It is excluded here to avoid redundancy. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

38. USAIPO1958-0605 (September 24, 1958 - September 29, 1958): This file contains the presidential approval and respondent's party identification question, but it was read in/harmonized as a separate part of the study by Josephine Gantois. It is excluded here to avoid redundancy. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

39. USAIPO1958-0607 (November 7, 1958 - November 12, 1958): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey. Note that the usage notes on the first page of the codebook do not state that there are two records per respondent, but this is indicated elsewhere in the codebook.

40. USAIPO1958-0608 (December 3, 1958 - December 8, 1958): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

41. USAIPO1959-0609 (January 7, 1959 - January 12, 1959): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

42. USAIPO1959-0610 (February 4, 1959 - February 9, 1959): This file contains the presidential approval and respondent's party identification question, but it was read in/harmonized as a separate part of the study by Josephine Gantois. It is excluded here to avoid redundancy. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

43. USAIPO1959-0611 (March 4, 1959 - March 9, 1959): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, age of the respondent, and level of personal federal income tax. Presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South and poll tax were not available for this survey.

44. USAIPO1959-0614 (May 29, 1959 - June 3, 1959): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey. Note that the state variable includes observations for Colorado (state code 63), but Colorado is missing from the tabulation of the state variable in the codebook.

45. USAIPO1959-0615 (June 25, 1959 - June 30, 1959): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey. Note that the frequency distribution for the state variable does not match that in the codebook for observations with numeric codes in the 60s (Rocky Mountain states). For example, the state with a code of 62 in the Stata tabulation (20 observations) is shown in the codebook as state code 61 (also 20 observations); the state with a code of 68 in the Stata tabulation (25 observations) is shown in the codebook as state code 67 (also 25 observations); etc. The frequencies appear to have been assigned incorrectly in the codebook, rather than the data, so we will simply label these values after appending but otherwise leave as-is, given that the Rocky Mountain states are not central to the analysis; in a future analysis, however, we may want to drop these observations entirely.

46. USAIPO1959-0616 (July 23, 1959 - July 28, 1959): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

47. USAIPO1959-0621 (December 3, 1959 - December 8, 1959): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

48. USAIPO1959-0622 (December 10, 1959 - December 15, 1959): This file contains the presidential approval and respondent's party identification question, but it was read in/harmonized as a separate part of the study by Josephine Gantois. It is excluded here to avoid redundancy. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

49. USAIPO1960-0623 (January 6, 1960 - January 11, 1960): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey. Note that the sample size shown on the front page of the codebook - 2,607 - does not match the number of observations read into Stata (2,595). However, the sample size indicated on page 2 of the codebook (i.e., 2 of 25 in the PDF) matches the number of observations read into Stata.

50. USAIPO1960-0624 (February 4, 1960 - February 9, 1960): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey. Note that the usage notes on the first page of the codebook do not state that there are two records per respondent, but this is indicated elsewhere in the codebook. Also note that the sample size shown on the front page of the codebook - 3,149 - does not match the number of observations read into Stata (3,135). However, the sample size indicated on page 3 of the codebook (i.e., 3 of 26 in the PDF) matches the number of observations read into Stata.

51. USAIPO1960-0625 (March 2, 1960 - March 7, 1960): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey. Note that the usage notes on the first page of the codebook do not state that there are two records per respondent, but this is indicated elsewhere in the codebook. Also note that the sample size shown on the front page of the codebook - 2,999 - does not match the number of observations read into Stata (2,985). However, the sample size indicated on page 3 of the codebook (i.e., 3 of 28 in the PDF) matches the number of observations read into Stata.

52. USAIPO1960-0634 (August 25, 1960 - August 30, 1960): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.

53. USAIPO1960-0635 (September 9, 1960 - September 14, 1960): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey. Note that the usage notes on the first page of the codebook do not state that there are two records per respondent, but this is indicated elsewhere in the codebook.

54. USAIPO1960-0637 (October 18, 1960 - October 23, 1960): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey. Note that the sample size shown on the front page of the codebook - 2,987 - does not match the number of observations read into Stata (2,988). However, the sample size indicated on page 2 of the codebook (i.e., 2 of 34 in the PDF) matches the number of observations read into Stata.

55. USAIPO1960-0638 (November 17, 1960 - November 22, 1960): Included variables are approval of current president, party ID in politics today, race and gender of the respondent, state the respondent lives in, and age of the respondent. Level of personal federal income tax, presidential candidate (Eisenhower/Stevenson) who will work hardest to get colored students admitted to white schools in the South, and poll tax were not available for this survey.


*/


********VARIABLE CREATION, ADJUSTMENT, AND HARMONIZATION********

****USAIPO1953-0511****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1953-0511; February 1, 1953 - February 5, 1953)
infile using DictionaryFiles\aipo1953-0511.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,599 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1953-0511"

*Create a variable for survey year
gen svy_yr = 1953

*Create a variable for survey month
gen svy_month = "February"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 1 if poliPartyID_orig == 2
replace poliPartyID = 2 if poliPartyID_orig == 1
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3

*Create indicator for non-standard question wording
gen nonStandPartyVar = 1


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 0 if race == 3

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig

*Replace values
replace sex = 0 if sex == 3


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 53 if state_orig == 81
replace state = 54 if state_orig == 82
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 53
replace state = 57 if state_orig == 54
replace state = 58 if state_orig == 83
replace state = 59 if state_orig == 84
replace state = 81 if state_orig == 86
replace state = 82 if state_orig == 85
replace state = 83 if state_orig == 55
replace state = 84 if state_orig == 56


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1953-0511" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1953-0511" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1953-0511" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1953-0511" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1953-0511" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1953-0511" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1953-0511" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1953-0511" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1953-0511" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1953-0511" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is only included in USAIPO1953-0511 (February 1, 1953 - February 5, 1953), USAIPO1956-0560 (February 16, 1956 - February 21, 1956), USAIPO1957-0581 (April 6, 1957 - April 11, 1957), and USAIPO1959-0611 (March 4, 1959 - March 9, 1959).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab fedIncomeTax_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen fedIncomeTax = fedIncomeTax_orig

*Replace values
replace fedIncomeTax = 2 if fedIncomeTax_orig == 3
replace fedIncomeTax = 3 if fedIncomeTax_orig == 2


*POLL TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "YES" 2 "NO" 3 "NO OPINION." Note that surveys USAIPO1948-0414 (March 5, 1948 - March 10, 1948) and USAIPO1949-0439 (March 19, 1949 - March 24, 1949) use "Yes/No/No Opinion" as response options, while surveys USAIPO1949-0450 (November 27, 1949 - December 2, 1949) and USAIPO1953-0511 (February 1, 1953 - February 5, 1953) use "Should/Should Not/No Opinion" as response options. Thus, in the latter two surveys, "Should" is treated as "Yes," and "Should Not" is treated as "No." Note that this variable is only included here in USAIPO1953-0511 (February 1, 1953 - February 5, 1953), i.e., this survey.

*Check the variable - tab it and compare with frequency distribution in the codebook
tab pollTax_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen pollTax = pollTax_orig


*Save the data
saveold FormattedData\1953-0511.dta, replace

clear


****USAIPO1953-0513****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1953-0513; March 28-April 2, 1953)
infile using DictionaryFiles\aipo1953-0513.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,602 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1953-0513"

*Create a variable for survey year
gen svy_yr = 1953

*Create a variable for survey month
gen svy_month = "March-April"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 1 if poliPartyID_orig == 2
replace poliPartyID = 2 if poliPartyID_orig == 1
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3

*Create indicator for non-standard question wording
gen nonStandPartyVar = 1


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 53 if state_orig == 81
replace state = 54 if state_orig == 82
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 53
replace state = 57 if state_orig == 54
replace state = 58 if state_orig == 83
replace state = 59 if state_orig == 84
replace state = 81 if state_orig == 86
replace state = 82 if state_orig == 85
replace state = 83 if state_orig == 55
replace state = 84 if state_orig == 56


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1953-0513" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1953-0513" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1953-0513" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1953-0513" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1953-0513" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1953-0513" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1953-0513" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1953-0513" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1953-0513" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1953-0513" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1953-0513.dta, replace

clear


****USAIPO1953-0519****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1953-0519; August 15, 1953 - August 20, 1953)
infile using DictionaryFiles\aipo1953-0519.dct


****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,613 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1953-0519"

*Create a variable for survey year
gen svy_yr = 1953

*Create a variable for survey month
gen svy_month = "August"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 1 if poliPartyID_orig == 2
replace poliPartyID = 2 if poliPartyID_orig == 1
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3

*Create indicator for non-standard question wording
gen nonStandPartyVar = 1


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 53 if state_orig == 81
replace state = 54 if state_orig == 82
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 53
replace state = 57 if state_orig == 54
replace state = 58 if state_orig == 83
replace state = 59 if state_orig == 84
replace state = 81 if state_orig == 86
replace state = 82 if state_orig == 85
replace state = 83 if state_orig == 55
replace state = 84 if state_orig == 56


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1953-0519" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1953-0519" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1953-0519" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1953-0519" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1953-0519" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1953-0519" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1953-0519" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1953-0519" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1953-0519" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1953-0519" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1953-0519.dta, replace

clear


****USAIPO1953-0521****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1953-0521; October 9, 1953 - October 14, 1953)
infile using DictionaryFiles\aipo1953-0521.dct


****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,488 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1953-0521"

*Create a variable for survey year
gen svy_yr = 1953

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 1 if poliPartyID_orig == 2
replace poliPartyID = 2 if poliPartyID_orig == 1
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3

*Create indicator for non-standard question wording
gen nonStandPartyVar = 1


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 0 if race_orig == 3

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig

*Replace values
replace sex = 0 if sex_orig == 3


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 53 if state_orig == 81
replace state = 54 if state_orig == 82
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 53
replace state = 57 if state_orig == 54
replace state = 58 if state_orig == 83
replace state = 59 if state_orig == 84
replace state = 81 if state_orig == 86
replace state = 82 if state_orig == 85
replace state = 83 if state_orig == 55
replace state = 84 if state_orig == 56


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1953-0521" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1953-0521" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1953-0521" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1953-0521" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1953-0521" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1953-0521" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1953-0521" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1953-0521" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1953-0521" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1953-0521" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1953-0521.dta, replace

clear


****USAIPO1953-0522****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1953-0522; November 1, 1953 - November 5, 1953)
infile using DictionaryFiles\aipo1953-0522.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,498 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1953-0522"

*Create a variable for survey year
gen svy_yr = 1953

*Create a variable for survey month
gen svy_month = "November"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 1 if poliPartyID_orig == 2
replace poliPartyID = 2 if poliPartyID_orig == 1
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3

*Create indicator for non-standard question wording
gen nonStandPartyVar = 1


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 53 if state_orig == 81
replace state = 54 if state_orig == 82
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 53
replace state = 57 if state_orig == 54
replace state = 58 if state_orig == 83
replace state = 59 if state_orig == 84
replace state = 81 if state_orig == 86
replace state = 82 if state_orig == 85
replace state = 83 if state_orig == 55
replace state = 84 if state_orig == 56


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1953-0522" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1953-0522" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1953-0522" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1953-0522" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1953-0522" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1953-0522" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1953-0522" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1953-0522" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1953-0522" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1953-0522" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1953-0522.dta, replace

clear


****USAIPO1954-0529****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1954-0529; April 8, 1954 - April 13, 1954)
infile using DictionaryFiles\aipo1954-0529.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,482 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1954-0529"

*Create a variable for survey year
gen svy_yr = 1954

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 1 if poliPartyID_orig == 2
replace poliPartyID = 2 if poliPartyID_orig == 1
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3

*Create indicator for non-standard question wording
gen nonStandPartyVar = 1


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 53 if state_orig == 81
replace state = 54 if state_orig == 82
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 53
replace state = 57 if state_orig == 54
replace state = 58 if state_orig == 83
replace state = 59 if state_orig == 84
replace state = 81 if state_orig == 86
replace state = 82 if state_orig == 85
replace state = 83 if state_orig == 55
replace state = 84 if state_orig == 56


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1954-0529" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1954-0529" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1954-0529" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1954-0529" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1954-0529" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1954-0529" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1954-0529" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1954-0529" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1954-0529" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1954-0529" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1954-0529.dta, replace

clear


****USAIPO1954-0531****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1954-0531; May 21, 1954 - May 26, 1954)
infile using DictionaryFiles\aipo1954-0531.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,416 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1954-0531"

*Create a variable for survey year
gen svy_yr = 1954

*Create a variable for survey month
gen svy_month = "May"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 1 if poliPartyID_orig == 2
replace poliPartyID = 2 if poliPartyID_orig == 1
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3

*Create indicator for non-standard question wording
gen nonStandPartyVar = 1


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 53 if state_orig == 81
replace state = 54 if state_orig == 82
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 53
replace state = 57 if state_orig == 54
replace state = 58 if state_orig == 83
replace state = 59 if state_orig == 84
replace state = 81 if state_orig == 86
replace state = 82 if state_orig == 85
replace state = 83 if state_orig == 55
replace state = 84 if state_orig == 56


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1954-0531" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1954-0531" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1954-0531" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1954-0531" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1954-0531" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1954-0531" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1954-0531" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1954-0531" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1954-0531" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1954-0531" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1954-0531.dta, replace

clear


****USAIPO1954-0532****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1954-0532; June 12, 1954 - June 17, 1954)
infile using DictionaryFiles\aipo1954-0532.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,435 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1954-0532"

*Create a variable for survey year
gen svy_yr = 1954

*Create a variable for survey month
gen svy_month = "June"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 1 if poliPartyID_orig == 2
replace poliPartyID = 2 if poliPartyID_orig == 1
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3

*Create indicator for non-standard question wording
gen nonStandPartyVar = 1


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable does not match that in the codebook for observations with numeric codes in the 20s (Middle Atlantic states) and Connecticut. For example, the state with a code of 23 in the Stata tabulation (126 observations) is shown in the codebook as state code 22 (also 126 observations); the state with a code of 24 in the Stata tabulation (26 observations) is shown in the codebook as state code 23 (also 24 observations); etc.

*As there is no frequency table in the back of the codebook, we cannot double-check the variable (i.e., ensure that the dictionary file was read in correctly) by identifying frequencies by column and then comparing against the table.

*The frequencies appear to have been assigned incorrectly in the codebook, rather than the data, so we will simply label these values after appending but otherwise leave as-is, given that the Middle Atlantic states and Connecticut are not central to the analysis; in a future analysis, however, we may want to drop these observations entirely.

*Other values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 53 if state_orig == 81
replace state = 54 if state_orig == 82
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 53
replace state = 57 if state_orig == 54
replace state = 58 if state_orig == 83
replace state = 59 if state_orig == 84
replace state = 81 if state_orig == 86
replace state = 82 if state_orig == 85
replace state = 83 if state_orig == 55
replace state = 84 if state_orig == 56


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1954-0532" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1954-0532" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1954-0532" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1954-0532" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1954-0532" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1954-0532" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1954-0532" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1954-0532" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1954-0532" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1954-0532" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1954-0532.dta, replace

clear


****USAIPO1954-0534****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1954-0534; July 16, 1954 - July 21, 1954)
infile using DictionaryFiles\aipo1954-0534.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,530 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1954-0534"

*Create a variable for survey year
gen svy_yr = 1954

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3

*Create indicator for non-standard question wording
gen nonStandPartyVar = 1


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 53 if state_orig == 81
replace state = 54 if state_orig == 82
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 53
replace state = 57 if state_orig == 54
replace state = 58 if state_orig == 83
replace state = 59 if state_orig == 84
replace state = 81 if state_orig == 86
replace state = 82 if state_orig == 85
replace state = 83 if state_orig == 55
replace state = 84 if state_orig == 56
replace state = 0 if state_orig == 90


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1954-0534" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1954-0534" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1954-0534" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1954-0534" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1954-0534" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1954-0534" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1954-0534" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1954-0534" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1954-0534" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1954-0534" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1954-0534.dta, replace

clear


****USAIPO1954-0537****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1954-0537; September 16, 1954 - September 21, 1954)
infile using DictionaryFiles\aipo1954-0537.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,466 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1954-0537"

*Create a variable for survey year
gen svy_yr = 1954

*Create a variable for survey month
gen svy_month = "September"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

replace race = 0 if race_orig == 3

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig

replace sex = 0 if sex_orig == 3


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 53 if state_orig == 81
replace state = 54 if state_orig == 82
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 53
replace state = 57 if state_orig == 54
replace state = 58 if state_orig == 83
replace state = 59 if state_orig == 84
replace state = 81 if state_orig == 86
replace state = 82 if state_orig == 85
replace state = 83 if state_orig == 55
replace state = 84 if state_orig == 56


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1954-0537" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1954-0537" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1954-0537" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1954-0537" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1954-0537" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1954-0537" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1954-0537" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1954-0537" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1954-0537" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1954-0537" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1954-0537.dta, replace

clear


****USAIPO1955-0541****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1955-0541; December 31, 1954 - January 5, 1955)
infile using DictionaryFiles\aipo1955-0541.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,446 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1955-0541"

*Create a variable for survey year
gen svy_yr = 1955

*Create a variable for survey month
gen svy_month = "December-January"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 4 if race_orig == 2

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 53 if state_orig == 81
replace state = 54 if state_orig == 82
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 53
replace state = 57 if state_orig == 54
replace state = 58 if state_orig == 83
replace state = 59 if state_orig == 84
replace state = 81 if state_orig == 86
replace state = 82 if state_orig == 85
replace state = 83 if state_orig == 55
replace state = 84 if state_orig == 56


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1955-0541" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1955-0541" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1955-0541" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1955-0541" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1955-0541" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1955-0541" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1955-0541" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1955-0541" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1955-0541" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1955-0541" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1955-0541.dta, replace

clear


****USAIPO1955-0546****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1955-0546; April 14, 1955 - April 19, 1955)
infile using DictionaryFiles\aipo1955-0546.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,531 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1955-0546"

*Create a variable for survey year
gen svy_yr = 1955

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 4 if race_orig == 2

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 53 if state_orig == 81
replace state = 54 if state_orig == 82
replace state = 55 if state_orig == 57
replace state = 56 if state_orig == 53
replace state = 57 if state_orig == 54
replace state = 58 if state_orig == 83
replace state = 59 if state_orig == 84
replace state = 81 if state_orig == 86
replace state = 82 if state_orig == 85
replace state = 83 if state_orig == 55
replace state = 84 if state_orig == 56


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1955-0546" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1955-0546" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1955-0546" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1955-0546" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1955-0546" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1955-0546" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1955-0546" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1955-0546" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1955-0546" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1955-0546" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1955-0546.dta, replace

clear


****USAIPO1955-0547****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1955-0547; May 12, 1955 - May 17, 1955)
infile using DictionaryFiles\aipo1955-0547.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,504 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1955-0547"

*Create a variable for survey year
gen svy_yr = 1955

*Create a variable for survey month
gen svy_month = "May"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 4 if race_orig == 2
replace race = 0 if race_orig == 3

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1955-0547" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1955-0547" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1955-0547" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1955-0547" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1955-0547" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1955-0547" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1955-0547" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1955-0547" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1955-0547" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1955-0547" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1955-0547.dta, replace

clear


****USAIPO1955-0556****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1955-0556; November 17, 1955 - November 22, 1955)
infile using DictionaryFiles\aipo1955-0556.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,545 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1955-0556"

*Create a variable for survey year
gen svy_yr = 1955

*Create a variable for survey month
gen svy_month = "November"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 4 if race_orig == 2

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1955-0556" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1955-0556" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1955-0556" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1955-0556" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1955-0556" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1955-0556" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1955-0556" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1955-0556" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1955-0556" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1955-0556" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1955-0556.dta, replace

clear


****USAIPO1956-0560****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1956-0560; February 16, 1956 - February 21, 1956)
infile using DictionaryFiles\aipo1956-0560.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 2,031 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1956-0560"

*Create a variable for survey year
gen svy_yr = 1956

*Create a variable for survey month
gen svy_month = "February"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 4 if race_orig == 2

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1956-0560" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1956-0560" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1956-0560" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1956-0560" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1956-0560" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1956-0560" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1956-0560" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1956-0560" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1956-0560" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1956-0560" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is only included in USAIPO1953-0511 (February 1, 1953 - February 5, 1953), USAIPO1956-0560 (February 16, 1956 - February 21, 1956), USAIPO1957-0581 (April 6, 1957 - April 11, 1957), and USAIPO1959-0611 (March 4, 1959 - March 9, 1959).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab fedIncomeTax_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen fedIncomeTax = fedIncomeTax_orig


*Save the data
saveold FormattedData\1956-0560.dta, replace

clear


****USAIPO1956-0562****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1956-0562; March 29, 1956 - April 3, 1956)
infile using DictionaryFiles\aipo1956-0562.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 2,000 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1956-0562"

*Create a variable for survey year
gen svy_yr = 1956

*Create a variable for survey month
gen svy_month = "March-April"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in two variables for this survey

*Check the race variable - tab it and compare with frequency distribution in the codebook
tab race_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen race = race_orig

*Replace values
replace race = 4 if race_orig == 2

*Check the sex variable - tab it and compare with frequency distribution in the codebook
tab sex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen sex = sex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1956-0562" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1956-0562" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1956-0562" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1956-0562" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1956-0562" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1956-0562" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1956-0562" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1956-0562" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1956-0562" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1956-0562" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1956-0562.dta, replace

clear


****USAIPO1956-0569****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1956-0569; August 23, 1956 - August 28, 1956)
infile using DictionaryFiles\aipo1956-0569.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 2,254 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1956-0569"

*Create a variable for survey year
gen svy_yr = 1956

*Create a variable for survey month
gen svy_month = "August"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1956-0569" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1956-0569" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1956-0569" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1956-0569" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1956-0569" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1956-0569" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1956-0569" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1956-0569" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1956-0569" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1956-0569" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1956-0569.dta, replace

clear


****USAIPO1956-0570****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1956-0570; September 9, 1956 - September 14, 1956)
infile using DictionaryFiles\aipo1956-0570.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,979 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1956-0570"

*Create a variable for survey year
gen svy_yr = 1956

*Create a variable for survey month
gen svy_month = "September"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1956-0570" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1956-0570" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1956-0570" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1956-0570" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1956-0570" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1956-0570" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1956-0570" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1956-0570" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1956-0570" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1956-0570" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1956-0570.dta, replace

clear


****USAIPO1956-0571****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1956-0571; September 20, 1956 - September 25, 1956)
infile using DictionaryFiles\aipo1956-0571.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 2,207 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1956-0571"

*Create a variable for survey year
gen svy_yr = 1956

*Create a variable for survey month
gen svy_month = "September"


*Begin harmonization of variables

*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4
replace raceSex = 0 if raceSex_orig == 5


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*With the exception of two states -- Florida and Virginia -- the frequency distribution displayed next to the variable in the codebook matches the tabulated variable; compare the variable to frequency table in the back of the codebook to ensure that the dictionary file was read in correctly.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1956-0571" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1956-0571" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1956-0571" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1956-0571" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1956-0571" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1956-0571" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1956-0571" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1956-0571" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1956-0571" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1956-0571" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*PRESIDENTIAL CANDIDATE (EISENHOWER/STEVENSON) WHO WILL WORK HARDEST TO GET COLORED STUDENTS ADMITTED TO WHITE SCHOOLS IN THE SOUTH: Synchronization of variable name and recoding of values for consistency process is unnecessary, as this question appears in only this survey, USAIPO1956-0571 (September 20, 1956 - September 25, 1956). After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "EISENHOWER" 2 "STEVENSON" 3 "NO DIFFERENCE" 4 "NO OPINION"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab candidateSchIntegration_orig

*The frequency distribution for this variable matches that in the codebook

*Variable is only in this survey, so no need to recode values for consistency with a harmonization plan

*Generate a new variable name for comparability with other variable names
gen candidateSchIntegration = candidateSchIntegration_orig


*Save the data
saveold FormattedData\1956-0571.dta, replace

clear


****USAIPO1956-0576****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1956-0576; December 14, 1956 - December 19, 1956)
infile using DictionaryFiles\aipo1956-0576.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,543 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1956-0576"

*Create a variable for survey year
gen svy_yr = 1956

*Create a variable for survey month
gen svy_month = "December"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1956-0576" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1956-0576" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1956-0576" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1956-0576" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1956-0576" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1956-0576" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1956-0576" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1956-0576" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1956-0576" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1956-0576" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1956-0576.dta, replace

clear


****USAIPO1957-0577****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1957-0577; January 17, 1957 - January 22, 1957)
infile using DictionaryFiles\aipo1957-0577.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,494 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1957-0577"

*Create a variable for survey year
gen svy_yr = 1957

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*With the exception of four states -- Arkansas, Missouri, Texas, and Wisconsin -- the frequency distribution displayed next to the variable in the codebook matches the tabulated variable; compare the variable to frequency table in the back of the codebook to ensure that the dictionary file was read in correctly.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1957-0577" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1957-0577" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1957-0577" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1957-0577" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1957-0577" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1957-0577" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1957-0577" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1957-0577" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1957-0577" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1957-0577" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1957-0577.dta, replace

clear


****USAIPO1957-0578****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1957-0578; February 5, 1957 - February 12, 1957)
infile using DictionaryFiles\aipo1957-0578.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,507 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1957-0578"

*Create a variable for survey year
gen svy_yr = 1957

*Create a variable for survey month
gen svy_month = "February"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1957-0578" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1957-0578" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1957-0578" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1957-0578" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1957-0578" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1957-0578" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1957-0578" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1957-0578" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1957-0578" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1957-0578" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1957-0578.dta, replace

clear


****USAIPO1957-0579****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1957-0579; February 28, 1957 - March 5, 1957)
infile using DictionaryFiles\aipo1957-0579.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,531 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1957-0579"

*Create a variable for survey year
gen svy_yr = 1957

*Create a variable for survey month
gen svy_month = "February-March"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1957-0579" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1957-0579" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1957-0579" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1957-0579" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1957-0579" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1957-0579" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1957-0579" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1957-0579" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1957-0579" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1957-0579" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1957-0579.dta, replace

clear


****USAIPO1957-0580****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1957-0580; March 15, 1957 - March 20, 1957)
infile using DictionaryFiles\aipo1957-0580.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,627 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1957-0580"

*Create a variable for survey year
gen svy_yr = 1957

*Create a variable for survey month
gen svy_month = "March"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1957-0580" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1957-0580" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1957-0580" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1957-0580" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1957-0580" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1957-0580" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1957-0580" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1957-0580" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1957-0580" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1957-0580" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1957-0580.dta, replace

clear


****USAIPO1957-0581****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1957-0581; April 6, 1957 - April 11, 1957)
infile using DictionaryFiles\aipo1957-0581.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,654 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1957-0581"

*Create a variable for survey year
gen svy_yr = 1957

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1957-0581" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1957-0581" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1957-0581" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1957-0581" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1957-0581" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1957-0581" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1957-0581" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1957-0581" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1957-0581" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1957-0581" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is only included in USAIPO1953-0511 (February 1, 1953 - February 5, 1953), USAIPO1956-0560 (February 16, 1956 - February 21, 1956), USAIPO1957-0581 (April 6, 1957 - April 11, 1957), and USAIPO1959-0611 (March 4, 1959 - March 9, 1959).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab fedIncomeTax_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen fedIncomeTax = fedIncomeTax_orig


*Save the data
saveold FormattedData\1957-0581.dta, replace

clear


****USAIPO1957-0582****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1957-0582; April 25, 1957 - April 30, 1957)
infile using DictionaryFiles\aipo1957-0582.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,659 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1957-0582"

*Create a variable for survey year
gen svy_yr = 1957

*Create a variable for survey month
gen svy_month = "April"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

*Replace values
replace presApprovala = 0 if presApprovala_orig == 4


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1957-0582" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1957-0582" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1957-0582" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1957-0582" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1957-0582" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1957-0582" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1957-0582" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1957-0582" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1957-0582" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1957-0582" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1957-0582.dta, replace

clear


****USAIPO1957-0584****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1957-0584; June 6, 1957 - June 11, 1957)
infile using DictionaryFiles\aipo1957-0584.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,393 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1957-0584"

*Create a variable for survey year
gen svy_yr = 1957

*Create a variable for survey month
gen svy_month = "June"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1957-0584" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1957-0584" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1957-0584" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1957-0584" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1957-0584" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1957-0584" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1957-0584" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1957-0584" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1957-0584" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1957-0584" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1957-0584.dta, replace

clear


****USAIPO1957-0586****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1957-0586; July 18, 1957 - July 23, 1957)
infile using DictionaryFiles\aipo1957-0586.dct

*The sample size in the codebook - 1,534 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1957-0586"

*Create a variable for survey year
gen svy_yr = 1957

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1957-0586" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1957-0586" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1957-0586" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1957-0586" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1957-0586" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1957-0586" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1957-0586" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1957-0586" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1957-0586" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1957-0586" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1957-0586.dta, replace

clear


****USAIPO1957-0588****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1957-0588; August 29, 1957 - September 4, 1957)
infile using DictionaryFiles\aipo1957-0588.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,528 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1957-0588"

*Create a variable for survey year
gen svy_yr = 1957

*Create a variable for survey month
gen svy_month = "August-September"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1957-0588" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1957-0588" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1957-0588" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1957-0588" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1957-0588" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1957-0588" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1957-0588" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1957-0588" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1957-0588" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1957-0588" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1957-0588.dta, replace

clear


****USAIPO1957-0589****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1957-0589; September 19, 1957 - September 24, 1957)
infile using DictionaryFiles\aipo1957-0589.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,530 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1957-0589"

*Create a variable for survey year
gen svy_yr = 1957

*Create a variable for survey month
gen svy_month = "September"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1957-0589" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1957-0589" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1957-0589" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1957-0589" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1957-0589" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1957-0589" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1957-0589" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1957-0589" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1957-0589" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1957-0589" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1957-0589.dta, replace

clear


****USAIPO1957-0590****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1957-0590; October 10, 1957 - October 15, 1957)
infile using DictionaryFiles\aipo1957-0590.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,573 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1957-0590"

*Create a variable for survey year
gen svy_yr = 1957

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1957-0590" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1957-0590" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1957-0590" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1957-0590" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1957-0590" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1957-0590" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1957-0590" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1957-0590" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1957-0590" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1957-0590" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1957-0590.dta, replace

clear


****USAIPO1957-0591****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1957-0591; November 7, 1957 - November 12, 1957)
infile using DictionaryFiles\aipo1957-0591.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
replace educ = 7 if educ_orig == 8
replace educ = 8 if educ_orig == 9
replace educ = 9 if educ_orig == 10
tab educ

*The sample size in the codebook - 1,505 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1957-0591"

*Create a variable for survey year
gen svy_yr = 1957

*Create a variable for survey month
gen svy_month = "November"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

*Replace values
replace presApprovala = 3 if presApprovala_orig == 4
replace presApprovala = 4 if presApprovala_orig == 3


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1957-0591" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1957-0591" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1957-0591" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1957-0591" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1957-0591" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1957-0591" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1957-0591" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1957-0591" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1957-0591" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1957-0591" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1957-0591.dta, replace

clear


****USAIPO1958-0595****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1958-0595; February 14, 1958 - February 19, 1958)
infile using DictionaryFiles\aipo1958-0595.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7

replace educ = 10 if educ_orig ==6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size in the codebook - 1,482 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1958-0595"

*Create a variable for survey year
gen svy_yr = 1958

*Create a variable for survey month
gen svy_month = "February"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig

*Replace values
replace raceSex = 7 if raceSex_orig == 3
replace raceSex = 8 if raceSex_orig == 4


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1958-0595" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1958-0595" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1958-0595" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1958-0595" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1958-0595" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1958-0595" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1958-0595" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1958-0595" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1958-0595" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1958-0595" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1958-0595.dta, replace

clear


****USAIPO1958-0603****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1958-0603; August 20, 1958 - August 25, 1958)
infile using DictionaryFiles\aipo1958-0603.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 10 if educ_orig == 5
replace educ = 5 if educ_orig == 6
replace educ = 6 if educ_orig == 7
tab educ

*The sample size in the codebook - 1,563 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1958-0603"

*Create a variable for survey year
gen svy_yr = 1958

*Create a variable for survey month
gen svy_month = "August"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1958-0603" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1958-0603" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1958-0603" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1958-0603" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1958-0603" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1958-0603" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1958-0603" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1958-0603" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1958-0603" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1958-0603" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1958-0603.dta, replace

clear


****USAIPO1958-0607****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1958-0607; November 7, 1958 - November 12, 1958); note that the usage notes on the first page of the codebook do not state that there are two records per respondent, but this is indicated elsewhere in the codebook.
infile using DictionaryFiles\aipo1958-0607.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 9
tab educ

*The sample size in the codebook - 1,499 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1958-0607"

*Create a variable for survey year
gen svy_yr = 1958

*Create a variable for survey month
gen svy_month = "November"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1958-0607" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1958-0607" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1958-0607" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1958-0607" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1958-0607" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1958-0607" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1958-0607" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1958-0607" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1958-0607" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1958-0607" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1958-0607.dta, replace

clear


****USAIPO1958-0608****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1958-0608; December 3, 1958 - December 8, 1958)
infile using DictionaryFiles\aipo1958-0608.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size in the codebook - 1,509 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1958-0608"

*Create a variable for survey year
gen svy_yr = 1958

*Create a variable for survey month
gen svy_month = "December"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1958-0608" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1958-0608" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1958-0608" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1958-0608" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1958-0608" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1958-0608" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1958-0608" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1958-0608" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1958-0608" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1958-0608" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1958-0608.dta, replace

clear


****USAIPO1959-0609****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1959-0609; January 7, 1959 - January 12, 1959)
infile using DictionaryFiles\aipo1959-0609.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size in the codebook - 1,591 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1959-0609"

*Create a variable for survey year
gen svy_yr = 1959

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1959-0609" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1959-0609" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1959-0609" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1959-0609" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1959-0609" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1959-0609" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1959-0609" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1959-0609" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1959-0609" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1959-0609" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1959-0609.dta, replace

clear


****USAIPO1959-0611****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1959-0611; March 4, 1959 - March 9, 1959)
infile using DictionaryFiles\aipo1959-0611.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size in the codebook - 1,534 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1959-0611"

*Create a variable for survey year
gen svy_yr = 1959

*Create a variable for survey month
gen svy_month = "March"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 
*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig == 4
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*With the exception of two states -- Pennsylvania and South Carolina -- the frequency distribution displayed next to the variable in the codebook matches the tabulated variable. As there is no frequency table in the back of the codebook, we cannot double-check the variable by identifying frequencies by column and then comparing against the table.

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1959-0611" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1959-0611" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1959-0611" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1959-0611" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1959-0611" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1959-0611" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1959-0611" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1959-0611" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1959-0611" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1959-0611" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*LEVEL OF PERSONAL FEDERAL INCOME TAX

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION." Note that this variable is only included in USAIPO1953-0511 (February 1, 1953 - February 5, 1953), USAIPO1956-0560 (February 16, 1956 - February 21, 1956), USAIPO1957-0581 (April 6, 1957 - April 11, 1957), and USAIPO1959-0611 (March 4, 1959 - March 9, 1959).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab fedIncomeTax_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen fedIncomeTax = fedIncomeTax_orig


*Save the data
saveold FormattedData\1959-0611.dta, replace

clear


****USAIPO1959-0614****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1959-0614; May 29, 1959 - June 3, 1959)
infile using DictionaryFiles\aipo1959-0614.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size in the codebook - 1,536 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1959-0614"

*Create a variable for survey year
gen svy_yr = 1959

*Create a variable for survey month
gen svy_month = "May-June"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook, with the exception of Colorado (state code 63), which is included in the dataset but not displayed in the tabulation of the state variable in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1959-0614" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1959-0614" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1959-0614" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1959-0614" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1959-0614" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1959-0614" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1959-0614" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1959-0614" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1959-0614" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1959-0614" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1959-0614.dta, replace

clear


****USAIPO1959-0615****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1959-0615; June 25, 1959 - June 30, 1959)
infile using DictionaryFiles\aipo1959-0615.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size in the codebook - 2,771 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1959-0615"

*Create a variable for survey year
gen svy_yr = 1959

*Create a variable for survey month
gen svy_month = "June"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable does not match that in the codebook for observations with numeric codes in the 60s (Rocky Mountain states). For example, the state with a code of 62 in the Stata tabulation (20 observations) is shown in the codebook as state code 61 (also 20 observations); the state with a code of 68 in the Stata tabulation (25 observations) is shown in the codebook as state code 67 (also 25 observations); etc.

*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook to ensure that the dictionary file was read in correctly
gen first = int(state_orig/10)
gen second = state_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*The frequencies appear to have been assigned incorrectly in the codebook, rather than the data, so we will simply label these values after appending but otherwise leave as-is, given that the Rocky Mountain states are not central to the analysis; in a future analysis, however, we may want to drop these observations entirely.

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1959-0615" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1959-0615" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1959-0615" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1959-0615" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1959-0615" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1959-0615" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1959-0615" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1959-0615" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1959-0615" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1959-0615" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1959-0615.dta, replace

clear

****USAIPO1959-0616****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1959-0616; July 23, 1959 - July 28, 1959)
infile using DictionaryFiles\aipo1959-0616.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size in the codebook - 1,538 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1959-0616"

*Create a variable for survey year
gen svy_yr = 1959

*Create a variable for survey month
gen svy_month = "July"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook, with the exception of Colorado (state code 63), which is included in the dataset but not displayed in the tabulation of the state variable in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1959-0616" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1959-0616" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1959-0616" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1959-0616" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1959-0616" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1959-0616" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1959-0616" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1959-0616" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1959-0616" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1959-0616" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1959-0616.dta, replace

clear


****USAIPO1959-0621****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1959-0621; December 3, 1959 - December 8, 1959)
infile using DictionaryFiles\aipo1959-0621.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size in the codebook - 1,560 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1959-0621"

*Create a variable for survey year
gen svy_yr = 1959

*Create a variable for survey month
gen svy_month = "December"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook, with the exception of Colorado (state code 63), which is included in the dataset but not displayed in the tabulation of the state variable in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1959-0621" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1959-0621" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1959-0621" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1959-0621" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1959-0621" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1959-0621" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1959-0621" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1959-0621" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1959-0621" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1959-0621" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1959-0621.dta, replace

clear


****USAIPO1960-0623****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1960-0623; January 6, 1960 - January 11, 1960)
infile using DictionaryFiles\aipo1960-0623.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size shown on the front page of the codebook - 2,607 - does not match the number of observations read into Stata (2,595). However, the sample size indicated on page 2 of the codebook (i.e., 2 of 25 in the PDF) matches the number of observations read into Stata.

*Create a variable for survey code
gen svy = "1960-0623"

*Create a variable for survey year
gen svy_yr = 1960

*Create a variable for survey month
gen svy_month = "January"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook, with the exception of Colorado (state code 63), which is included in the dataset but not displayed in the tabulation of the state variable in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1960-0623" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1960-0623" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1960-0623" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1960-0623" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1960-0623" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1960-0623" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1960-0623" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1960-0623" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1960-0623" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1960-0623" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1960-0623.dta, replace

clear


****USAIPO1960-0624****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1960-0624; February 4, 1960 - February 9, 1960); note that the usage notes on the first page of the codebook do not state that there are two records per respondent, but this is indicated elsewhere in the codebook.
infile using DictionaryFiles\aipo1960-0624.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size shown on the front page of the codebook - 3,149 - does not match the number of observations read into Stata (3,135). However, the sample size indicated on page 3 of the codebook (i.e., 3 of 26 in the PDF) matches the number of observations read into Stata.

*Create a variable for survey code
gen svy = "1960-0624"

*Create a variable for survey year
gen svy_yr = 1960

*Create a variable for survey month
gen svy_month = "February"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook, with the exception of Colorado (state code 63), which is included in the dataset but not displayed in the tabulation of the state variable in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1960-0624" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1960-0624" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1960-0624" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1960-0624" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1960-0624" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1960-0624" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1960-0624" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1960-0624" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1960-0624" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1960-0624" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1960-0624.dta, replace

clear


****USAIPO1960-0625****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1960-0625; March 2, 1960 - March 7, 1960); note that the usage notes on the first page of the codebook do not state that there are two records per respondent, but this is indicated elsewhere in the codebook.
infile using DictionaryFiles\aipo1960-0625.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size shown on the front page of the codebook - 2,999 - does not match the number of observations read into Stata (2,985). However, the sample size indicated on page 3 of the codebook (i.e., 3 of 28 in the PDF) matches the number of observations read into Stata.

*Create a variable for survey code
gen svy = "1960-0625"

*Create a variable for survey year
gen svy_yr = 1960

*Create a variable for survey month
gen svy_month = "March"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook, with the exception of Colorado (state code 63), which is included in the dataset but not displayed in the tabulation of the state variable in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1960-0625" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1960-0625" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1960-0625" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1960-0625" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1960-0625" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1960-0625" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1960-0625" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1960-0625" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1960-0625" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1960-0625" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1960-0625.dta, replace

clear


****USAIPO1960-0634****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1960-0634; August 25, 1960 - August 30, 1960)
infile using DictionaryFiles\aipo1960-0634.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size in the codebook - 3,337 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1960-0634"

*Create a variable for survey year
gen svy_yr = 1960

*Create a variable for survey month
gen svy_month = "August"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

*Replace values
replace presApprovala = 0 if presApprovala == 4


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook, with the exception of Colorado (state code 63), which is included in the dataset but not displayed in the tabulation of the state variable in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1960-0634" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1960-0634" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1960-0634" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1960-0634" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1960-0634" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1960-0634" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1960-0634" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1960-0634" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1960-0634" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1960-0634" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1960-0634.dta, replace

clear


****USAIPO1960-0635****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1960-0635; September 9, 1960 - September 14, 1960); note that the usage notes on the first page of the codebook do not state that there are two records per respondent, but this is indicated elsewhere in the codebook.
infile using DictionaryFiles\aipo1960-0635.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size in the codebook - 2,906 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1960-0635"

*Create a variable for survey year
gen svy_yr = 1960

*Create a variable for survey month
gen svy_month = "September"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 4 & poliPartyID_orig <= 8
replace poliPartyID = 4 if poliPartyID_orig == 3


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook, with the exception of Colorado (state code 63), which is included in the dataset but not displayed in the tabulation of the state variable in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1960-0635" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1960-0635" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1960-0635" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1960-0635" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1960-0635" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1960-0635" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1960-0635" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1960-0635" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1960-0635" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1960-0635" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1960-0635.dta, replace

clear


****USAIPO1960-0637****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1960-0637; October 18, 1960 - October 23, 1960)
infile using DictionaryFiles\aipo1960-0637.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size shown on the front page of the codebook - 2,987 - does not match the number of observations read into Stata (2,988). However, the sample size indicated on page 2 of the codebook (i.e., 2 of 34 in the PDF) matches the number of observations read into Stata.

*Create a variable for survey code
gen svy = "1960-0637"

*Create a variable for survey year
gen svy_yr = 1960

*Create a variable for survey month
gen svy_month = "October"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook, with the exception of Colorado (state code 63), which is included in the dataset but not displayed in the tabulation of the state variable in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab each age category and compare with the age distribution table in the codebook
*18-20 years
tab age_orig if svy == "1960-0637" & age_orig>17 & age_orig<21
*21-29 years
tab age_orig if svy == "1960-0637" & age_orig>20 & age_orig<30
*30-39 years
tab age_orig if svy == "1960-0637" & age_orig>29 & age_orig<40
*40-49 years
tab age_orig if svy == "1960-0637" & age_orig>39 & age_orig<50
*50-59 years
tab age_orig if svy == "1960-0637" & age_orig>49 & age_orig<60
*60-69 years
tab age_orig if svy == "1960-0637" & age_orig>59 & age_orig<70
*70-79 years
tab age_orig if svy == "1960-0637" & age_orig>69 & age_orig<80
*80-89 years
tab age_orig if svy == "1960-0637" & age_orig>79 & age_orig<90
*90 years and over
tab age_orig if svy == "1960-0637" & age_orig>=90
*NO CODE OR NO DATA
tab age_orig if svy == "1960-0637" & age_orig == 0

*The frequency distribution for this variable matches that in the codebook

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1960-0637.dta, replace

clear


****USAIPO1960-0638****

clear

*Read in dictionary file for Gallup Poll (AIPO) question on presidential approval (Gallup Poll (AIPO); USAIPO1960-0638; November 17, 1960 - November 22, 1960)
infile using DictionaryFiles\aipo1960-0638.dct

****** EDUC ******
tab educ_orig
gen educ = educ_orig
replace educ = 2 if educ_orig == 3
replace educ = 3 if educ_orig == 4
replace educ = 4 if educ_orig == 5
replace educ = 5 if educ_orig == 7
replace educ = 10 if educ_orig == 6
replace educ = 6 if educ_orig == 8
*replace educ = 8 if educ == 10
tab educ

*The sample size in the codebook - 3,123 - matches the number of observations read into Stata

*Create a variable for survey code
gen svy = "1960-0638"

*Create a variable for survey year
gen svy_yr = 1960

*Create a variable for survey month
gen svy_month = "November"


*Begin harmonization of variables

*APPROVAL OF CURRENT PRESIDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH." This variable is not available in USAIPO1956-0569 (August 23, 1956 - August 28, 1956), USAIPO1956-0570 (September 9, 1956 - September 14, 1956), and USAIPO1956-0571 (September 20, 1956 - September 25, 1956).

*Check the variable - tab it and compare with frequency distribution in the codebook
tab presApprovala_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen presApprovala = presApprovala_orig

*Replace values
replace presApprovala = 3 if presApprovala_orig == 0


*PARTY ID IN POLITICS TODAY

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. For files in which the main party question is combined with a second question (i.e., coded in a single variable) that asks whether Independents lean more toward the Democratic Party or the Republican Party, all Independent responses -- such as Independent, lean toward the Democratic Party and Independent, lean toward the Republican Party -- will be coded in a single category of Independents. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY." Note that the standard form of question on which the variable is based reads, "In politics, as of today, do you consider yourself a Republican, Democrat, or Independent?" However, some surveys use a variation on this wording (e.g., "Democrat" precedes "Republican" in the question prompt). If a survey does not use the standard wording, we will create an indicator called "nonStandPartyVar" beneath the "Party ID in Politics Today" variable for the given survey; observations for this variable will be missing in all individual survey files where the standard wording is used. After appending the files, we will label this variable. Only files from USAIPO1953-0511 (February 1, 1953 - February 5, 1953) through USAIPO1954-0534 (July 16, 1954 - July 21, 1954), inclusive chronologically, contain the non-standard indicator; the rest of the surveys use the standard question text. 

*Check the variable - tab it and compare with frequency distribution in the codebook
tab poliPartyID_orig

*The frequency distribution for this variable matches that in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen poliPartyID = poliPartyID_orig

*Replace values
replace poliPartyID = 3 if poliPartyID_orig >= 5 & poliPartyID_orig <= 8
replace poliPartyID = 0 if poliPartyID_orig == 9


*RACE AND GENDER OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. (Note that some surveys split race and gender into two variables, while others use a single variable.) After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN" for the single variable. If race and gender are separate, the variables will be defined as follows -- race: 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE" / gender: 1 "MALE" 2 "FEMALE"

*Race and gender are in one variable for this survey

*Check the variable - tab it and compare with frequency distribution in the codebook
tab raceSex_orig

*The frequency distribution for this variable matches that in the codebook

*Values are coded consistently with harmonization plan, so no need to recode

*Generate a new variable to ensure synchronization of variable name across surveys
gen raceSex = raceSex_orig


*STATE THE RESPONDENT LIVES IN

*Harmonization Plan: Survey-by-survey synchronization of variable name and recoding of values for consistency across surveys. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA," and we will define value labels and assign to variable. Label will be defined as: 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab state_orig

*The frequency distribution for this variable matches that in the codebook, with the exception of Colorado (state code 63), which is included in the dataset but not displayed in the tabulation of the state variable in the codebook

*Values are not coded consistently with harmonization plan; recode variable

*Generate a new variable to ensure synchronization of variable name across surveys
gen state = state_orig

*Replace values
replace state = 81 if state_orig == 50
replace state = 82 if state_orig == 74
replace state = 83 if state_orig == 75
replace state = 84 if state_orig == 76


*AGE OF THE RESPONDENT

*Harmonization Plan: Survey-by-survey synchronization of variable name. After appending files, we will set values to missing where the observation is set to "NO CODE OR NO DATA"

*Check the variable - tab it and compare with frequency distribution in the codebook
tab age_orig

*The variable age_orig does not have frequencies displayed next to it in the codebook
*Create two new variables to be dropped (subsequent to the check) that will allow us to identify frequencies by column and compare to the frequency table in the back of the codebook
gen first = int(age_orig/10)
gen second = age_orig - (first*10)
tab first
tab second

*The frequency distribution for this variable matches that in the codebook; drop the unnecessary variables
drop first second

*Generate a new variable to ensure synchronization of variable name across surveys
gen age = age_orig


*Save the data
saveold FormattedData\1960-0638.dta, replace

clear



********APPEND FILES AND FINALIZE DATASET********

use FormattedData\1953-0511.dta
append using FormattedData\1953-0513.dta
append using FormattedData\1953-0519.dta
append using FormattedData\1953-0521.dta
append using FormattedData\1953-0522.dta
append using FormattedData\1954-0529.dta
append using FormattedData\1954-0531.dta
append using FormattedData\1954-0532.dta
append using FormattedData\1954-0534.dta
append using FormattedData\1954-0537.dta
append using FormattedData\1955-0541.dta
append using FormattedData\1955-0546.dta
append using FormattedData\1955-0547.dta
append using FormattedData\1955-0556.dta
append using FormattedData\1956-0560.dta
append using FormattedData\1956-0562.dta
append using FormattedData\1956-0569.dta
append using FormattedData\1956-0570.dta
append using FormattedData\1956-0571.dta
append using FormattedData\1956-0576.dta
append using FormattedData\1957-0577.dta
append using FormattedData\1957-0578.dta
append using FormattedData\1957-0579.dta
append using FormattedData\1957-0580.dta
append using FormattedData\1957-0581.dta
append using FormattedData\1957-0582.dta
append using FormattedData\1957-0584.dta
append using FormattedData\1957-0586.dta
append using FormattedData\1957-0588.dta
append using FormattedData\1957-0589.dta
append using FormattedData\1957-0590.dta
append using FormattedData\1957-0591.dta
append using FormattedData\1958-0595.dta
append using FormattedData\1958-0603.dta
append using FormattedData\1958-0607.dta
append using FormattedData\1958-0608.dta
append using FormattedData\1959-0609.dta
append using FormattedData\1959-0611.dta
append using FormattedData\1959-0614.dta
append using FormattedData\1959-0615.dta
append using FormattedData\1959-0616.dta
append using FormattedData\1959-0621.dta
append using FormattedData\1960-0623.dta
append using FormattedData\1960-0624.dta
append using FormattedData\1960-0625.dta
append using FormattedData\1960-0634.dta
append using FormattedData\1960-0635.dta
append using FormattedData\1960-0637.dta
append using FormattedData\1960-0638.dta

*Recode those variables requiring adjustments

*Replace observations set to 0 ("NO CODE OR NO DATA") or 9 ("INAPPLICABLE") with missing values per relevant harmonization plan(s)
replace presApprovala = . if presApprovala == 0 | presApprovala == 9
replace poliPartyID = . if poliPartyID == 0 | poliPartyID == 9
replace raceSex = . if raceSex == 0 | raceSex == 9
replace race = . if race == 0 | race == 9
replace sex = . if sex == 0 | sex == 9
replace state = . if state == 0 | state == 9
replace age = . if age == 0 | age == 9
replace fedIncomeTax = . if fedIncomeTax == 0 | fedIncomeTax == 9
replace pollTax = . if pollTax == 0 | pollTax == 9
replace candidateSchIntegration = . if candidateSchIntegration == 0 | candidateSchIntegration == 9

*Label variables, define values, and assign values to variables

label variable svy "SURVEY CODE"

label variable svy_yr "SURVEY YEAR"

label variable svy_month "SURVEY MONTH(S)"

label variable presApprovala "APPROVAL OF CURRENT PRESIDENT"
label define lb_presApprovala 1 "APPROVE" 2 "DISAPPROVE" 3 "NO OPINION" 4 "BOTH"
label values presApprovala lb_presApprovala

label variable poliPartyID "PARTY ID IN POLITICS TODAY"
label define lb_poliPartyID 1 "REPUBLICAN" 2 "DEMOCRAT" 3 "INDEPENDENT" 4 "OTHER PARTY"
label values poliPartyID lb_poliPartyID

label variable nonStandPartyVar "INDICATOR FOR PARTY ID NOT TAKEN FROM OUR STANDARD PARTY VARIABLE"

label variable raceSex "RACE AND GENDER OF THE RESPONDENT"
label define lb_raceSex 1 "WHITE MAN" 2 "WHITE WOMAN" 3 "BLACK MAN" 4 "BLACK WOMAN" 5 "OTHER MAN" 6 "OTHER WOMAN" 7 "NON-WHITE MAN" 8 "NON-WHITE WOMAN"
label values raceSex lb_raceSex

label variable race "RACE OF THE RESPONDENT"
label define lb_race 1 "WHITE" 2 "BLACK" 3 "OTHER" 4 "NON-WHITE"
label values race lb_race

label variable sex "GENDER OF THE RESPONDENT"
label define lb_sex 1 "MALE" 2 "FEMALE"
label values sex lb_sex

label variable state "STATE THE RESPONDENT LIVES IN"
label define lb_state 11 "MAINE" 12 "NEW HAMPSHIRE" 13 "VERMONT" 14 "MASSACHUSETTS" 15 "RHODE ISLAND" 16 "CONNECTICUT" 21 "NEW YORK" 22 "NEW JERSEY" 23 "PENNSYLVANIA" 24 "MARYLAND" 25 "DELAWARE" 26 "WEST VIRGINIA" 27 "D.C." 31 "OHIO" 32 "MICHIGAN" 33 "INDIANA" 34 "ILLINOIS" 41 "WISCONSIN" 42 "MINNESOTA" 43 "IOWA" 44 "MISSOURI" 45 "NORTH DAKOTA" 46 "SOUTH DAKOTA" 47 "NEBRASKA" 48 "KANSAS" 51 "VIRGINIA" 52 "NORTH CAROLINA" 53 "SOUTH CAROLINA" 54 "GEORGIA" 55 "FLORIDA" 56 "KENTUCKY" 57 "TENNESSEE" 58 "ALABAMA" 59 "MISSISSIPPI" 81 "ARKANSAS" 82 "LOUISIANA" 83 "OKLAHOMA" 84 "TEXAS" 61 "MONTANA" 62 "ARIZONA" 63 "COLORADO" 64 "IDAHO" 65 "WYOMING" 66 "UTAH" 67 "NEVADA" 68 "NEW MEXICO" 71 "CALIFORNIA" 72 "OREGON" 73 "WASHINGTON" 74 "HAWAII" 75 "ALASKA"
label values state lb_state

label variable age "AGE OF THE RESPONDENT"

label variable fedIncomeTax "LEVEL OF PERSONAL FEDERAL INCOME TAX"
label define lb_fedIncomeTax 1 "TOO HIGH" 2 "ABOUT RIGHT" 3 "TOO LOW" 4 "DON'T KNOW/NO OPINION"
label values fedIncomeTax lb_fedIncomeTax

label variable pollTax "SHOULD POLL TAX BE ABOLISHED"
label define lb_pollTax 1 "YES" 2 "NO" 3 "NO OPINION"
label values pollTax lb_pollTax

label variable candidateSchIntegration "EISENHOWER/STEVENSON WORK HARDEST BLKS ADMITTED WHT SCHOOLS IN SOUTH"
label define lb_candidateSchIntegration 1 "EISENHOWER" 2 "STEVENSON" 3 "NO DIFFERENCE" 4 "NO OPINION"
label values candidateSchIntegration lb_candidateSchIntegration

gen educ2=educ
replace educ2 = 1 if (educ == 1 | educ == 2) //None or Grade 1-8
replace educ2 = 4 if (educ == 3) //HS Incomplete
replace educ2 = 5 if (educ == 4) //HS Grad
replace educ2 = 6 if (educ == 7 | educ ==8 | educ==9 | educ==10) //Technical, Trade or Business
replace educ2 = 7 if (educ == 5) //College, Uni., Incomplete
replace educ2 = 8 if (educ == 6) //College, Uni., Graduate
replace educ2 = 0 if (educ == 0) //No Code
drop educ
rename educ2 educ
label variable educ "EDUCATION OF THE RESPONDENT"
label define lb_edu 1 "NONE, OR GRADES 1-8" 4 "HIGH SCHOOL INCOMPLETE (GRADES 9-11)" 5 "HIGH SCHOOL GRADUATE (GRADE 12)" 6 "TECHNICAL, TRADE, OR BUSINESS" 7 "COLLEGE, UNIVERSITY, INCOMPLETE" 8 "COLLEGE, UNIVERSITY, GRADUATE" 9 "POST-GRAD" 0 "NO CODE OR NO DATA"
label values educ lb_edu

/*label variable educ "EDUCATION"
label define lb_educ 	01 "NO SCHOOLING" ///
						02 "GRAMMAR SCHOOL (GRADES 1-8)" ///
						03 "HIGH SCHOOL, INCOMPLETE (9TH, 10TH, OR 11TH GRADE)" ///
						04 "HIGH SCHOOL, GRADUATED (12TH GRADE)" ///
						05 "HIGH SCHOOL, GRADUATED, YES, COLLEGE, INCOMPLETE" ///
						06 "HIGH SCHOOL, GRADUATED, YES, COLLEGE, GRADUATED" ///
						07 "HIGH SCHOOL, GRADUATED, YES, NURSES TRAINING" ///
						08 "HIGH SCHOOL, GRADUATED, YES, TRADE SCHOOL, BEAUTY SCHOOL" ///
						09 "HIGH SCHOOL, GRADUATED, YES, BUSINESS SCHOOL, BUSINESS COLLEGE" ///
						10 "TECHNICAL, TRADE, OR BUSINESS SCHOOL" ///
						00 "NO CODE OR NO DATA"
label values educ lb_educ*/

*Check the data

*Count observations in the dataset
count

*Add numeric values to value labels to help check the data
numlabel, add

*Check each variable
bys svy: tab svy_yr
bys svy: tab svy_month
bys svy: tab presApprovala
bys svy: tab poliPartyID
bys svy: tab nonStandPartyVar
bys svy: tab raceSex
bys svy: tab race
bys svy: tab sex
bys svy: tab state
bys svy: tab age
bys svy: sum age
bys svy: tab fedIncomeTax
bys svy: tab pollTax
bys svy: tab candidateSchIntegration

*Remove the numeric values from value labels
numlabel, remove

*Sort the data
sort svy

*Order the variables
order svy svy_yr svy_month state state_orig presApprovala presApprovala_orig poliPartyID poliPartyID_orig nonStandPartyVar raceSex raceSex_orig race race_orig sex sex_orig age age_orig educ educ_orig fedIncomeTax fedIncomeTax_orig pollTax pollTax_orig candidateSchIntegration candidateSchIntegration_orig

*Compress data in memory
compress

*Rename educ so that I can merge it later
rename educ eduHarmonized

*Save the data
saveold PresidentialApprovalQuestionsEisenhower6.18.2016.dta, replace

log close

exit, clear
